@@ -3,29 +3,85 @@
 # Copyright 2009 TK Soh <teekaysoh@gmail.com>
 #
 # This software may be used and distributed according to the terms of the
-# GNU General Public License version 2, incorporated herein by reference.
+# GNU General Public License version 2 or any later version.
 
 # Creates a task-bar icon.  Run from Python.exe to see the
 # messages printed. Takes an optional logfile as first command
 # line parameter
 
-from __future__ import print_function
+from __future__ import annotations
 
 import os
 import sys
 
 if hasattr(sys, "frozen"):
-    class BlackHole(object):
-        closed = True
-        softspace = 0
-        def write(self, data):
-            pass
-        def close(self):
-            pass
-        def flush(self):
-            pass
-    sys.stdout = BlackHole()
-    sys.stderr = BlackHole()
+    if sys.frozen == 'windows_exe':
+        # sys.stdin is invalid, should be None.  Fixes svn, git subrepos
+        sys.stdin = None
+
+        # py2exe blackholes stdout with a custom class to prevent random
+        # exceptions when writing to it, but doesn't provide the ``.buffer``
+        # attribute that mercurial.utils.procutil wants.  As of 0.11.1.0, it
+        # also doesn't return the number of bytes written, and therefore
+        # violates the interface contract.  For details, see:
+        # https://github.com/py2exe/py2exe/blob/af0e841bffcf9c64abce6204718fecad17a59506/py2exe/boot_common.py#L3
+        #
+        # TODO: upstream write() return value and PROGRAMDATA usage in py2exe,
+        #  and then most or all of this can go away.
+        sys.stdout = open(os.devnull, "w")
+
+        # py2exe writes its redirected stderr log file next to the executable
+        # (so typically in %PROGRAMFILES%), but UAC blocks that when it is
+        # enabled.  Replacing stderr with our own log file to an always
+        # writeable area prevents that, fixes the missing write() return value,
+        # and provides the `.buffer` attribute that procutil assumes is present.
+        program_data = os.environ.get("PROGRAMDATA")
+
+        if program_data is not None:
+            import atexit, ctypes
+
+            dir_name = os.path.join(program_data, "TortoiseHg")
+            log_name = os.path.join(
+                dir_name,
+                os.path.splitext(
+                    os.path.basename(sys.executable)
+                )[0] + '.log'
+            )
+
+            try:
+                os.makedirs(dir_name, exist_ok=True)
+                sys.stderr = open(log_name, 'a', buffering=1)
+            except Exception as details:
+                sys.stderr = sys.stdout  # blackhole messages
+                ctypes.windll.user32.MessageBoxW(
+                    0,
+                    "The logfile '%s' could not be opened:\n %s" % (
+                        log_name, details,
+                    ),
+                    "Errors in %r" % os.path.basename(sys.executable),
+                    0
+                )
+            else:
+                orig_size = sys.stderr.seek(0, os.SEEK_END)
+
+                def exit_check():
+                    log_size = sys.stderr.tell()
+
+                    if orig_size != log_size:
+                        ctypes.windll.user32.MessageBoxW(
+                            0,
+                            "See the logfile '%s' for details" % log_name,
+                            "Errors in %r" % os.path.basename(sys.executable),
+                            0,
+                        )
+
+                atexit.register(exit_check)
+        else:
+            # py2exe messages come through sys.stderr; mercurial.ui.error()
+            # messages come through sys.stderr.buffer.  Drop everything for the
+            # *w.exe executable if the log file cannot be created, in order to
+            # prevent various issues mentioned above.
+            sys.stderr = sys.stdout
 
 import errno
 import time
@@ -53,12 +109,23 @@ demandimport.enable()
 from mercurial import (
     error,
     pycompat,
+    util,
 )
 
 from mercurial.windows import posixfile, unlink, rename
-from tortoisehg.util.i18n import agettext as _
+from tortoisehg.util.i18n import _
 from tortoisehg.util import hglib, thread2, paths, shlib, version
 
+if hglib.TYPE_CHECKING:
+    from typing import (
+        Iterable,
+        List,
+        Set,
+        Text,
+        Tuple,
+    )
+
+
 APP_TITLE = _('TortoiseHg Overlay Icon Server')
 
 EXIT_CMD = 1025
@@ -67,21 +134,21 @@ class Logger:
     def __init__(self):
         self.file = None
 
-    def setfile(self, name):
+    def setfile(self, name: Text) -> None:
         oname = name + '.old'
         try:
-            rename(name, oname)
+            rename(hglib.fromunicode(name), hglib.fromunicode(oname))
         except:
             pass
-        self.file = posixfile(name, b'wb')
+        self.file = posixfile(hglib.fromunicode(name), b'wb')
         self.msg('%s, Version %s' % (APP_TITLE, version.version()))
         self.msg('Logging to file started')
 
-    def msg(self, msg):
+    def msg(self, msg: Text) -> None:
         ts = '[%s] ' % time.strftime('%c')
         f = self.file
         if f:
-            f.write(ts + msg + '\n')
+            f.write(hglib.fromunicode(ts + msg) + b'\n')
             f.flush()
             os.fsync(f.fileno())
             print('L' + ts + msg)
@@ -92,7 +159,7 @@ logger = Logger()
 
 iconcache = {}
 
-def load_icon(name):
+def load_icon(name: Text):
     from tortoisehg.util.paths import get_tortoise_icon
     iconPathName = get_tortoise_icon(name)
     if iconPathName and os.path.isfile(iconPathName):
@@ -103,14 +170,14 @@ def load_icon(name):
         hicon = LoadIcon(0, win32con.IDI_APPLICATION)
     return hicon
 
-def get_icon(name):
+def get_icon(name: Text):
     try:
         return iconcache[name]
     except KeyError:
         iconcache[name] = load_icon(name)
         return iconcache[name]
 
-def SetIcon(hwnd, name, add=False):
+def SetIcon(hwnd, name: Text, add: bool = False) -> None:
     # Try and find a custom icon
     if '--noicon' in sys.argv:
         return
@@ -209,7 +276,7 @@ class MainWindow:
 
     def stop_pipe_server(self):
         logger.msg("MainWindow.stop_pipe_server")
-        if not self.pipethread.isAlive():
+        if not self.pipethread.is_alive():
             logger.msg("pipethread is not alive")
             return True
 
@@ -218,20 +285,20 @@ class MainWindow:
 
         max_try = 10
         cnt = 1
-        while cnt <= max_try and self.pipethread.isAlive():
+        while cnt <= max_try and self.pipethread.is_alive():
             print("testing pipe [try %d] ..." % cnt)
             try:
                 try:
                     self.pipethread.terminate()
                 except ValueError:
                     pass
-                win32pipe.CallNamedPipe(PIPENAME, '', PIPEBUFSIZE, 0)
+                win32pipe.CallNamedPipe(PIPENAME, b'', PIPEBUFSIZE, 0)
             except:
                 logger.msg(traceback.format_exc())
                 pass
             cnt += 1
 
-        if self.pipethread.isAlive():
+        if self.pipethread.is_alive():
             msg = "WARNING: unable to stop server after %d trys." % max_try
             logger.msg(msg)
             return False
@@ -255,7 +322,7 @@ PIPENAME += GetUserName()
 
 PIPEBUFSIZE = 4096
 
-def getrepos(batch):
+def getrepos(batch: Iterable[Text]) -> Tuple[Set[Text], Set[Text]]:
     roots = set()
     notifypaths = set()
     for path in batch:
@@ -270,13 +337,13 @@ def getrepos(batch):
             except Exception as e:
                 # This exception raises in case of fixutf8 extension enabled
                 # and folder name contains '0x5c'(backslash).
-                logger.msg('Failed listdir %s (%s)' % (path, str(e)))
+                logger.msg('Failed listdir %s (%s)' % (path, hglib.exception_str(e)))
         else:
             roots.add(r)
             notifypaths.add(path)
     return roots, notifypaths
 
-def update_batch(batch):
+def update_batch(batch: Iterable[Text]) -> None:
     '''updates thgstatus for all paths in batch'''
     roots, notifypaths = getrepos(batch)
     if roots:
@@ -287,7 +354,7 @@ def update_batch(batch):
         # TODO: Figure out if this hack for py2exe is still needed, and possibly
         #       wrap this to handle unicode on py3
         if not pycompat.ispy3:
-            errorstream = pycompat.bytesio()
+            errorstream = util.bytesio()
             sys.stderr = errorstream
         try:
             # Ensure that all unset dirstate entries can be updated.
@@ -295,9 +362,11 @@ def update_batch(batch):
             updated_any = False
             for r in sorted(roots):
                 try:
-                    if shlib.update_thgstatus(_ui, r, wait=False):
+                    if shlib.update_thgstatus(
+                        _ui, hglib.fromunicode(r), wait=False
+                    ):
                         updated_any = True
-                    shlib.shell_notify([r], noassoc=True)
+                    shlib.shell_notify([hglib.fromunicode(r)], noassoc=True)
                     logger.msg('Updated ' + r)
                 except (IOError, OSError):
                     print("IOError or OSError on updating %s (check permissions)" % r)
@@ -305,11 +374,14 @@ def update_batch(batch):
                     failedroots.add(r)
                 except (error.Abort, error.ConfigError, error.RepoError,
                         error.RevlogError, ImportError) as e:
-                    logger.msg('Failed updating %s (%s)' % (r, str(e)))
+                    logger.msg('Failed updating %s (%s)' % (r, hglib.exception_str(e)))
                     failedroots.add(r)
             notifypaths -= failedroots
             if notifypaths:
-                shlib.shell_notify(list(notifypaths), noassoc=not updated_any)
+                shlib.shell_notify(
+                    [hglib.fromunicode(p) for p in notifypaths],
+                    noassoc=not updated_any
+                )
                 logger.msg('Shell notified')
             if not pycompat.ispy3:
                 errmsg = errorstream.getvalue()
@@ -330,38 +402,40 @@ def get_config():
         OpenKey = winreg.OpenKey
         QueryValueEx = winreg.QueryValueEx
 
-        hkey = OpenKey(HKEY_CURRENT_USER, r'Software\TortoiseHg')
-        t = ('1', 'True')
-        try: show_taskbaricon = QueryValueEx(hkey, 'ShowTaskbarIcon')[0] in t
-        except EnvironmentError: pass
-        try: hgighlight_taskbaricon = QueryValueEx(hkey, 'HighlightTaskbarIcon')[0] in t
-        except EnvironmentError: pass
+        with OpenKey(HKEY_CURRENT_USER, r'Software\TortoiseHg') as hkey:
+            t = ('1', 'True')
+            try: show_taskbaricon = QueryValueEx(hkey, 'ShowTaskbarIcon')[0] in t
+            except OSError: pass
+            try: hgighlight_taskbaricon = QueryValueEx(hkey, 'HighlightTaskbarIcon')[0] in t
+            except OSError: pass
 
-        # Upgrade user's context menu, once per major release
-        try: version2cmenu = QueryValueEx(hkey, 'ContextMenuVersion')[0] == '2'
-        except EnvironmentError: pass
-        try:
-            if not version2cmenu:
-                CreateKey = winreg.CreateKey
-                SetValueEx = winreg.SetValueEx
-                REG_SZ = winreg.REG_SZ
+            # Upgrade user's context menu, once per major release
+            try: version2cmenu = QueryValueEx(hkey, 'ContextMenuVersion')[0] == '2'
+            except OSError: pass
 
-                try: promoted = QueryValueEx(hkey, 'PromotedItems')[0]
-                except EnvironmentError: promoted = ''
-                plist = [i.strip() for i in promoted.split(',')]
-                hkey = CreateKey(HKEY_CURRENT_USER, r'Software\TortoiseHg')
-                if u'log' in plist:
-                    idx = plist.index(u'log')
-                    plist[idx] = u'workbench'
-                    SetValueEx(hkey, 'PromotedItems', 0, REG_SZ, ','.join(plist))
-                SetValueEx(hkey, 'ContextMenuVersion', 0, REG_SZ, '2')
-        except EnvironmentError:
-            pass
-    except (ImportError, WindowsError):
+            try:
+                if not version2cmenu:
+                    CreateKey = winreg.CreateKey
+                    SetValueEx = winreg.SetValueEx
+                    REG_SZ = winreg.REG_SZ
+
+                    try: promoted = QueryValueEx(hkey, 'PromotedItems')[0]
+                    except OSError: promoted = ''
+                    plist = [i.strip() for i in promoted.split(',')]
+
+                    with CreateKey(HKEY_CURRENT_USER, r'Software\TortoiseHg') as hkey2:
+                        if u'log' in plist:
+                            idx = plist.index(u'log')
+                            plist[idx] = u'workbench'
+                            SetValueEx(hkey2, 'PromotedItems', 0, REG_SZ, ','.join(plist))
+                        SetValueEx(hkey2, 'ContextMenuVersion', 0, REG_SZ, '2')
+            except OSError:
+                pass
+    except (ImportError, OSError):
         pass
     return show_taskbaricon, hgighlight_taskbaricon
 
-def update(args, hwnd):
+def update(args: List[Text], hwnd) -> None:
     batch = []
     r = args[0]
     print("got update request %s (first in batch)" % r)
@@ -392,26 +466,27 @@ def update(args, hwnd):
     if show and highlight:
         SetIcon(hwnd, "hg.ico")
 
-def remove(args):
+def remove(args: List[Text]) -> None:
     path = args[0]
     logger.msg('Removing ' + path)
     roots, notifypaths = getrepos([path])
     if roots:
         for r in sorted(roots):
             tfn = os.path.join(r, '.hg', 'thgstatus')
+            fn = hglib.fromunicode(tfn)
             try:
-                f = posixfile(tfn, b'rb')
+                f = posixfile(fn, b'rb')
                 e = f.readline()
                 f.close()
-                if not e.startswith('@@noicons'):
-                    unlink(tfn)
+                if not e.startswith(b'@@noicons'):
+                    unlink(fn)
             except (IOError, OSError) as e:
                 if e.errno != errno.ENOENT:
                     logger.msg("Error while trying to remove %s (%s)" % (tfn, e))
         if notifypaths:
-            shlib.shell_notify(list(notifypaths))
+            shlib.shell_notify([hglib.fromunicode(p) for p in notifypaths])
 
-def dispatch(req, cmd, args, hwnd):
+def dispatch(req, cmd: Text, args: List[Text], hwnd) -> None:
     print("dispatch(%s)" % req)
     if cmd == 'update':
         update(args, hwnd)
@@ -514,7 +589,7 @@ class PipeServer:
                     continue
 
                 try:
-                    requests.put(data)
+                    requests.put(hglib.tounicode(data))
                     if data == 'terminate|':
                         logger.msg('PipeServer received terminate from pipe')
                         PostMessage(self.hwnd, win32con.WM_COMMAND, EXIT_CMD, 0)
