@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 this_file = __file__.rsplit('.', 1)[0]
 if this_file.endswith('caja-thg'):
     from gi.repository import Caja as Nautilus  # pytype: disable=import-error
@@ -80,10 +82,11 @@ demandimport.disable()
 nofilecmds = 'about serve synch repoconfig userconfig merge unmerge'.split()
 
 class HgExtensionDefault(GObject.GObject):
+    allvfs: Dict[Text, Any]
 
     def __init__(self):
         self.scanStack = []
-        self.allvfs = {}  # type: Dict[Text, Any]
+        self.allvfs = {}
         self.inv_dirs = set()
 
         self.hgtk = paths.find_in_path(thg_main)
@@ -110,12 +113,12 @@ class HgExtensionDefault(GObject.GObject):
         self.gmon = Gio.file_new_for_path(self.notify).monitor(Gio.FileMonitorFlags.NONE, None)
         self.gmon.connect('changed', self.notified)
 
-    def icon(self, iname):
-        # type: (Text) -> Optional[Text]
+    def icon(self, iname: Text) -> Optional[Text]:
         return paths.get_tortoise_icon(iname)
 
-    def get_path_for_vfs_file(self, vfs_file, store=True):
-        # type: (Any, bool) -> Optional[Text]
+    def get_path_for_vfs_file(self,
+                              vfs_file,
+                              store: bool = True) -> Optional[Text]:
         if vfs_file.get_uri_scheme() != 'file':
             return None
         # TODO: is get_uri returing unicode?
@@ -127,16 +130,15 @@ class HgExtensionDefault(GObject.GObject):
             self.allvfs[path] = vfs_file
         return path
 
-    def get_vfs(self, path):
-        # type: (Text) -> Any
+    def get_vfs(self, path: Text):
         vfs = self.allvfs.get(path, None)
         if vfs and vfs.is_gone():
             del self.allvfs[path]
             return None
         return vfs
 
-    def get_repo_for_path(self, path):
-        # type: (Text) -> Optional[localrepo.localrepository]
+    def get_repo_for_path(self,
+                          path: Text) -> Optional[localrepo.localrepository]:
         '''
         Find mercurial repository for vfs_file
         Returns hg.repo
@@ -152,8 +154,11 @@ class HgExtensionDefault(GObject.GObject):
             debugf(e)
             return None
 
-    def run_dialog(self, menuitem, hgtkcmd, cwd = None, files = None):
-        # type: (Any, Text, Optional[Text], List[Text]) -> None
+    def run_dialog(self,
+                   menuitem,
+                   hgtkcmd: Text,
+                   cwd: Optional[Text] = None,
+                   files: Optional[List[Text]] = None) -> None:
         '''
         hgtkcmd - hgtk subcommand
         '''
@@ -200,8 +205,9 @@ class HgExtensionDefault(GObject.GObject):
         self.cwd = cwd
         return self._buildMenu(menus, files)
 
-    def _buildMenu(self, menus, files):
-        # type: (menuthg.thg_menu, List[Text]) -> List[Nautilus.MenuItem]
+    def _buildMenu(self,
+                   menus: menuthg.thg_menu,
+                   files: List[Text]) -> List[Nautilus.MenuItem]:
         '''Build one level of a menu'''
         items = []
         if files:
@@ -257,8 +263,9 @@ class HgExtensionDefault(GObject.GObject):
                                "Hg Status",
                                "Version control status"),
 
-    def _get_file_status(self, localpath, repo=None):
-        # type: (Text, Optional[localrepo.localrepository]) -> Any
+    def _get_file_status(self,
+                         localpath: Text,
+                         repo: Optional[localrepo.localrepository] = None):
         cachestate = cachethg.get_state(localpath, repo)
         cache2state = {cachethg.UNCHANGED:   ('default',   'clean'),
                        cachethg.ADDED:       ('list-add',  'added'),
@@ -290,8 +297,7 @@ class HgExtensionDefault(GObject.GObject):
         if root:
             self.invalidate(files, root)
 
-    def invalidate(self, paths, root = ''):
-        # type: (List[Text], Text) -> None
+    def invalidate(self, paths: List[Text], root: Text = '') -> None:
         started = bool(self.inv_dirs)
         if cachethg.cache_pdir == root and root not in self.inv_dirs:
             cachethg.overlay_cache.clear()
@@ -319,8 +325,7 @@ class HgExtensionDefault(GObject.GObject):
         self.inv_dirs.clear()
 
     # property page borrowed from http://www.gnome.org/~gpoo/hg/nautilus-hg/
-    def __add_row(self, row, label_item, label_value):
-        # type: (Any, Text, Text) -> None
+    def __add_row(self, row, label_item: Text, label_value: Text) -> None:
         label = Gtk.Label(label_item)
         label.set_use_markup(True)
         label.set_alignment(1, 0)
