@@ -1,6 +1,6 @@
 """Helper functions or classes imported from test case"""
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import os
 import re
@@ -8,15 +8,21 @@ import sys
 import time
 from collections import defaultdict
 
-from tortoisehg.hgqt.qtcore import (
-    QTextCodec,
-)
+try:
+    from tortoisehg.hgqt.qtcore import (
+        QTextCodec,
+    )
+except ImportError:
+    # QStringConverter is supposed to be the replacement on Qt6, but is missing
+    # a lot of stuff.
+    QTextCodec = None
 
 from mercurial import (
     dispatch,
     encoding as encodingmod,
     error,
     pycompat,
+    util,
 )
 
 from tortoisehg.util import hglib
@@ -158,8 +164,8 @@ class HgClient(object):
         origwd = os.getcwd()
         ui = hglib.loadui()
         ui.setconfig(b'ui', b'strict', True)
-        ui.fout = pycompat.bytesio()
-        ui.ferr = pycompat.bytesio()
+        ui.fout = util.bytesio()
+        ui.ferr = util.bytesio()
         args = list(args)
         req = dispatch.request(args, ui=ui)
         options = dispatch._earlyparseopts(ui, args)
@@ -528,7 +534,7 @@ class GraphBuilder(object):
             self._runcmd(self.hg.debugobsolete, n, *succ)
 
 def buildgraph(path, textgraph):
-    """create test repostory with dag specified by graphlog like format
+    r"""create test repostory with dag specified by graphlog like format
 
     Example:
         buildgraph('./testrepo', r'''
