@@ -1,6 +1,6 @@
-from __future__ import absolute_import
+from __future__ import annotations
 
-import mock
+from unittest import mock
 import os
 import sys
 import unittest
@@ -159,8 +159,8 @@ class ManifestModelTest(unittest.TestCase):
     def test_drag_flag(self):
         m = self.new_model(0)
         # only files are drag enabled
-        self.assertTrue(m.flags(m.indexFromPath('foo')) & Qt.ItemIsDragEnabled)
-        self.assertFalse(m.flags(m.indexFromPath('baz')) & Qt.ItemIsDragEnabled)
+        self.assertTrue(m.flags(m.indexFromPath('foo')) & Qt.ItemFlag.ItemIsDragEnabled)
+        self.assertFalse(m.flags(m.indexFromPath('baz')) & Qt.ItemFlag.ItemIsDragEnabled)
 
     def test_isdir(self):
         m = self.new_model(3)
@@ -455,7 +455,7 @@ class ManifestModelTest(unittest.TestCase):
         m.setRawContext(repo[1])
         self.assertEqual(1, m.rev())
         # should not fall back to patch handler
-        self.assertTrue(m.flags(m.indexFromPath('foo')) & Qt.ItemIsDragEnabled)
+        self.assertTrue(m.flags(m.indexFromPath('foo')) & Qt.ItemFlag.ItemIsDragEnabled)
 
     def test_change_base_rev(self):
         m = self.new_model(10)
@@ -535,7 +535,7 @@ class ManifestModelPatchTest(unittest.TestCase):
 
     def test_no_drag_flag(self):
         m = self.new_model(b'patch0.diff')
-        self.assertFalse(m.flags(m.indexFromPath('foo')) & Qt.ItemIsDragEnabled)
+        self.assertFalse(m.flags(m.indexFromPath('foo')) & Qt.ItemFlag.ItemIsDragEnabled)
 
     def test_status(self):
         m = self.new_model(b'patch0.diff')
@@ -684,7 +684,11 @@ class ManifestModelEucjpTest(unittest.TestCase):
     def setUpClass(cls):
         # TODO: make this compatible with binary-unsafe filesystem
         if os.name != 'posix' or sys.platform == 'darwin':
-            raise SkipTest
+            raise unittest.SkipTest
+        # TODO: figure out the replacement for QTextCodec on Qt6
+        if helpers.QTextCodec is None:
+            raise unittest.SkipTest
+
         cls.encodingpatch = helpers.patchencoding('euc-jp')
 
         # include non-ascii char in repo path to test concatenation
