@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -79,8 +79,11 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
     _archive_content_touched_files = 1
     _archive_content_touched_since = 2
 
-    def __init__(self, repoagent, rev, parent=None, minrev=None):
-        # type: (thgrepo.RepoAgent, Optional[Text], Optional[QWidget], Optional[Text]) -> None
+    def __init__(self,
+                 repoagent: thgrepo.RepoAgent,
+                 rev: Optional[Text],
+                 parent: Optional[QWidget] = None,
+                 minrev: Optional[Text] = None) -> None:
         super(ArchiveWidget, self).__init__(parent)
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._repoagent = repoagent
@@ -206,13 +209,11 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def rev_combo_changed(self):
-        # type: () -> None
+    def rev_combo_changed(self) -> None:
         self.subrepos_chk.setChecked(self.get_subrepos_present())
         self.update_path()
 
-    def browse_clicked(self):
-        # type: () -> None
+    def browse_clicked(self) -> None:
         """Select the destination directory or file"""
         dest = self.dest_edit.text()
         if not os.path.exists(dest):
@@ -233,8 +234,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             self.dest_edit.setText(response)
             self.update_path()
 
-    def get_subrepos_present(self):
-        # type: () -> bool
+    def get_subrepos_present(self) -> bool:
         rev = self.get_selected_rev()
         try:
             ctx = hglib.revsymbol(self.repo, rev)
@@ -242,8 +242,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             return False
         return b'.hgsubstate' in ctx
 
-    def get_selected_rev(self):
-        # type: () -> bytes
+    def get_selected_rev(self) -> bytes:
         rev = self.rev_combo.currentText()
         if rev == WD_PARENT:
             rev = b'.'
@@ -251,28 +250,23 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             rev = hglib.fromunicode(rev)
         return rev
 
-    def get_selected_rootrev(self):
-        # type: () -> bytes
+    def get_selected_rootrev(self) -> bytes:
         rev = self.rootrev_combo.currentText()
         return hglib.fromunicode(rev)
 
-    def get_selected_archive_type(self):
-        # type: () -> Dict[Text, Text]
+    def get_selected_archive_type(self) -> Dict[Text, Text]:
         """Return a dictionary describing the selected archive type"""
         return _ARCHIVE_TYPES[self._typesradios.checkedId()]
 
-    def update_path(self):
-        # type: () -> None
+    def update_path(self) -> None:
 
         # pytype: disable=redundant-function-type-comment
-        def remove_ext(path):
-            # type: (Text) -> Text
+        def remove_ext(path: Text) -> Text:
             for ext in ('.tar', '.tar.bz2', '.tar.gz', '.zip'):
                 if path.endswith(ext):
                     return path.replace(ext, '')
             return path
-        def remove_rev(path):
-            # type: (Text) -> Text
+        def remove_rev(path: Text) -> Text:
             l = ''
             for i in pycompat.xrange(self.rev_combo.count() - 1):
                 l += self.rev_combo.itemText(i)
@@ -284,11 +278,9 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
                 if path.endswith(rev):
                     return path.replace(rev, '')
             return path
-        def add_rev(path, rev):
-            # type: (Text, Text) -> Text
+        def add_rev(path: Text, rev: Text) -> Text:
             return '%s_%s' % (path, rev)
-        def add_ext(path):
-            # type: (Text) -> Text
+        def add_ext(path: Text) -> Text:
             select = self.get_selected_archive_type()
             if select['type'] != 'files':
                 path += select['ext']
@@ -318,8 +310,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         self.compose_command()
 
     @pyqtSlot()
-    def compose_command(self):
-        # type: () -> List[Text]
+    def compose_command(self) -> List[Text]:
         content = self.content_mode.checkedId()
         targetrev = hglib.tounicode(self.get_selected_rev())
         if content == self._archive_content_all_files:
@@ -340,8 +331,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         self.commandChanged.emit()
         return cmdline
 
-    def canRunCommand(self):
-        # type: () -> bool
+    def canRunCommand(self) -> bool:
         rev = self.get_selected_rev()
         if not rev or not self.dest_edit.text():
             return False
@@ -351,8 +341,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             # ambiguous changeid
             return False
 
-    def runCommand(self):
-        # type: () -> cmdcore.CmdSession
+    def runCommand(self) -> cmdcore.CmdSession:
         # verify input
         type = self.get_selected_archive_type()['type']
         dest = self.dest_edit.text()
@@ -386,8 +375,10 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         return self._repoagent.runCommand(cmdline, self)
 
 
-def createArchiveDialog(repoagent, rev=None, parent=None, minrev=None):
-    # type: (thgrepo.RepoAgent, Optional[Text], Optional[QWidget], Optional[Text]) -> cmdui.CmdControlDialog
+def createArchiveDialog(repoagent: thgrepo.RepoAgent,
+                        rev: Optional[Text] = None,
+                        parent: Optional[QWidget] = None,
+                        minrev: Optional[Text] = None) -> cmdui.CmdControlDialog:
     dlg = cmdui.CmdControlDialog(parent)
     dlg.setWindowTitle(_('Archive - %s') % repoagent.displayName())
     dlg.setWindowIcon(qtlib.geticon('hg-archive'))
