@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 from .qtcore import (
     QSettings,
     QSize,
@@ -42,7 +44,6 @@ from . import (
 
 if hglib.TYPE_CHECKING:
     from typing import (
-        Any,
         Optional,
         Text,
     )
@@ -60,8 +61,7 @@ if hglib.TYPE_CHECKING:
     )
 
 
-def checkrev(repo, rev):
-    # type: (localrepo.localrepository, int) -> Optional[Text]
+def checkrev(repo: localrepo.localrepository, rev: int) -> Optional[Text]:
     op1, op2 = repo.dirstate.parents()
     if op1 is None:
         return _('Backout requires a parent revision')
@@ -74,8 +74,10 @@ def checkrev(repo, rev):
 
 class BackoutDialog(QWizard):
 
-    def __init__(self, repoagent, rev, parent=None):
-        # type: (RepoAgent, int, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 rev: int,
+                 parent: Optional[QWidget] = None) -> None:
         super(BackoutDialog, self).__init__(parent)
         self._repoagent = repoagent
         f = self.windowFlags()
@@ -103,8 +105,7 @@ class BackoutDialog(QWizard):
 
         self._readSettings()
 
-    def _readSettings(self):
-        # type: () -> None
+    def _readSettings(self) -> None:
         qs = QSettings()
         qs.beginGroup('backout')
         for n in ['autoadvance', 'skiplast']:
@@ -116,8 +117,7 @@ class BackoutDialog(QWizard):
                                        qtlib.readBool(qs, n, True)))
         qs.endGroup()
 
-    def _writeSettings(self):
-        # type: () -> None
+    def _writeSettings(self) -> None:
         qs = QSettings()
         qs.beginGroup('backout')
         for n in ['autoadvance', 'autoresolve', 'skiplast']:
@@ -125,75 +125,67 @@ class BackoutDialog(QWizard):
         qs.endGroup()
 
     @pyqtSlot()
-    def repositoryChanged(self):
-        # type: () -> None
+    def repositoryChanged(self) -> None:
         self.currentPage().repositoryChanged()
 
     @pyqtSlot()
-    def configChanged(self):
-        # type: () -> None
+    def configChanged(self) -> None:
         self.currentPage().configChanged()
 
-    def pageChanged(self, id):
-        # type: (int) -> None
+    def pageChanged(self, id: int) -> None:
         if id != -1:
             self.currentPage().currentPage()
 
-    def reject(self):
-        # type: () -> None
+    def reject(self) -> None:
         if self.currentPage().canExit():
             super(BackoutDialog, self).reject()
 
-    def done(self, r):
-        # type: (int) -> None
+    def done(self, r: int) -> None:
         self._writeSettings()
         super(BackoutDialog, self).done(r)
 
 
 class BasePage(QWizardPage):
-    def __init__(self, repoagent, parent):
-        # type: (RepoAgent, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 parent: Optional[QWidget]) -> None:
         super(BasePage, self).__init__(parent)
         self._repoagent = repoagent
 
     @property
-    def repo(self):
-        # type: () -> localrepo.localrepository
+    def repo(self) -> localrepo.localrepository:
         return self._repoagent.rawRepo()
 
-    def validatePage(self):
-        # type: () -> bool
+    def validatePage(self) -> bool:
         'user pressed NEXT button, can we proceed?'
         return True
 
-    def isComplete(self):
-        # type: () -> bool
+    def isComplete(self) -> bool:
         'should NEXT button be sensitive?'
         return True
 
-    def repositoryChanged(self):
-        # type: () -> None
+    def repositoryChanged(self) -> None:
         'repository has detected a change to changelog or parents'
         pass
 
-    def configChanged(self):
-        # type: () -> None
+    def configChanged(self) -> None:
         'repository has detected a change to config files'
         pass
 
-    def currentPage(self):
-        # type: () -> None
+    def currentPage(self) -> None:
         pass
 
-    def canExit(self):
-        # type: () -> bool
+    def canExit(self) -> bool:
         return True
 
 
 class SummaryPage(BasePage):
 
-    def __init__(self, repoagent, backoutrev, parentbackout, parent):
-        # type: (RepoAgent, int, bool, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 backoutrev: int,
+                 parentbackout: bool,
+                 parent: Optional[QWidget]) -> None:
         super(SummaryPage, self).__init__(repoagent, parent)
         self._wctxcleaner = wctxcleaner.WctxCleaner(repoagent, self)
         self._wctxcleaner.checkStarted.connect(self._onCheckStarted)
@@ -270,40 +262,33 @@ class SummaryPage(BasePage):
         self.layout().addWidget(autoresolve_chk)
         self.groups.set_visible(False, 'dirty')
 
-    def isComplete(self):
-        # type: () -> bool
+    def isComplete(self) -> bool:
         'should Next button be sensitive?'
         return self._wctxcleaner.isClean()
 
-    def repositoryChanged(self):
-        # type: () -> None
+    def repositoryChanged(self) -> None:
         'repository has detected a change to changelog or parents'
         pctx = self.repo[b'.']
-        self.localCsInfo.update(pctx)
+        self.localCsInfo.updateItems(pctx)
 
-    def canExit(self):
-        # type: () -> bool
+    def canExit(self) -> bool:
         'can backout tool be closed?'
         if self._wctxcleaner.isChecking():
             self._wctxcleaner.cancelCheck()
         return True
 
-    def currentPage(self):
-        # type: () -> None
+    def currentPage(self) -> None:
         self.refresh()
 
-    def refresh(self):
-        # type: () -> None
+    def refresh(self) -> None:
         self._wctxcleaner.check()
 
     @pyqtSlot()
-    def _onCheckStarted(self):
-        # type: () -> None
+    def _onCheckStarted(self) -> None:
         self.groups.set_visible(True, 'prog')
 
     @pyqtSlot(bool)
-    def _onCheckFinished(self, clean):
-        # type: (bool) -> None
+    def _onCheckFinished(self, clean: bool) -> None:
         self.groups.set_visible(False, 'prog')
         if self._wctxcleaner.isCheckCanceled():
             return
@@ -318,8 +303,11 @@ class SummaryPage(BasePage):
 
 
 class BackoutPage(BasePage):
-    def __init__(self, repoagent, backoutrev, parentbackout, parent):
-        # type: (RepoAgent, int, bool, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 backoutrev: int,
+                 parentbackout: bool,
+                 parent: Optional[QWidget]) -> None:
         super(BackoutPage, self).__init__(repoagent, parent)
         self._backoutrev = backoutrev
         self._parentbackout = parentbackout
@@ -343,8 +331,7 @@ class BackoutPage(BasePage):
         self.registerField('autoadvance', autonext)
         self.layout().addWidget(autonext)
 
-    def currentPage(self):
-        # type: () -> None
+    def currentPage(self) -> None:
         if self._parentbackout:
             self.wizard().next()
             return
@@ -356,8 +343,7 @@ class BackoutPage(BasePage):
         sess.commandFinished.connect(self.onCommandFinished)
         sess.outputReceived.connect(self._cmdlog.appendLog)
 
-    def isComplete(self):
-        # type: () -> bool
+    def isComplete(self) -> bool:
         'should Next button be sensitive?'
         if not self.backoutcomplete:
             return False
@@ -376,14 +362,12 @@ class BackoutPage(BasePage):
             return True
 
     @pyqtSlot(bool)
-    def tryAutoAdvance(self, checked):
-        # type: (bool) -> None
+    def tryAutoAdvance(self, checked: bool) -> None:
         if checked and self.isComplete():
             self.wizard().next()
 
     @pyqtSlot(int)
-    def onCommandFinished(self, ret):
-        # type: (int) -> None
+    def onCommandFinished(self, ret: int) -> None:
         if ret in (0, 1):
             self.backoutcomplete = True
             if self.field('autoadvance'):
@@ -391,8 +375,7 @@ class BackoutPage(BasePage):
             self.completeChanged.emit()
 
     @pyqtSlot(str)
-    def onLinkActivated(self, cmd):
-        # type: (Text) -> None
+    def onLinkActivated(self, cmd: Text) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -403,8 +386,11 @@ class BackoutPage(BasePage):
 
 class CommitPage(BasePage):
 
-    def __init__(self, repoagent, backoutrev, parentbackout, parent):
-        # type: (RepoAgent, int, bool, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 backoutrev: int,
+                 parentbackout: bool,
+                 parent: Optional[QWidget]) -> None:
         super(CommitPage, self).__init__(repoagent, parent)
         self._backoutrev = backoutrev
         self._parentbackout = parentbackout
@@ -419,15 +405,13 @@ class CommitPage(BasePage):
 
         # pytype: disable=redundant-function-type-comment
         # csinfo
-        def label_func(widget, item, ctx):
-            # type: (Any, Text, HgContext) -> Any
+        def label_func(widget, item: Text, ctx: HgContext):
             if item == 'rev':
                 return _('Revision:')
             elif item == 'parents':
                 return _('Parents')
             raise csinfo.UnknownItem()
-        def data_func(widget, item, ctx):
-            # type: (Any, Text, HgContext) -> Any
+        def data_func(widget, item: Text, ctx: HgContext):
             if item == 'rev':
                 return _('Working Directory'), str(ctx)
             elif item == 'parents':
@@ -453,8 +437,7 @@ class CommitPage(BasePage):
                 else:
                     return '<a href="view">%s</a> (%s)' % (text, rev)
             elif item == 'parents':
-                def branch_markup(branch):
-                    # type: (Text) -> Text
+                def branch_markup(branch: Text) -> Text:
                     opts = dict(fg='black', bg='#aaffaa')
                     return qtlib.markup(' %s ' % branch, **opts)
                 csets = []
@@ -538,17 +521,14 @@ class CommitPage(BasePage):
         self.engChk.setChecked(engmsg)
         self.layout().addWidget(self.engChk)
 
-    def refresh(self):
-        # type: () -> None
+    def refresh(self) -> None:
         pass
 
-    def cleanupPage(self):
-        # type: () -> None
+    def cleanupPage(self) -> None:
         s = QSettings()
         self.msgEntry.saveSettings(s, 'backout/message')
 
-    def currentPage(self):
-        # type: () -> None
+    def currentPage(self) -> None:
         engmsg = self._repoagent.configBool('tortoisehg', 'engmsg')
         msgset = i18n.keepgettext()._('Backed out changeset: ')
         msg = engmsg and msgset['id'] or msgset['str']
@@ -556,19 +536,16 @@ class CommitPage(BasePage):
         self.msgEntry.moveCursorToEnd()
 
     @pyqtSlot(str)
-    def onLinkActivated(self, cmd):
-        # type: (Text) -> None
+    def onLinkActivated(self, cmd: Text) -> None:
         if cmd == 'view':
             dlg = status.StatusDialog(self._repoagent, [], {}, self)
             dlg.exec()
             self.refresh()
 
-    def isComplete(self):
-        # type: () -> bool
+    def isComplete(self) -> bool:
         return len(self.msgEntry.text()) > 0
 
-    def validatePage(self):
-        # type: () -> bool
+    def validatePage(self) -> bool:
         if self.commitComplete:
             # commit succeeded, repositoryChanged() called wizard().next()
             if self.field('skiplast'):
@@ -608,16 +585,16 @@ class CommitPage(BasePage):
         return False
 
     @pyqtSlot(int)
-    def onCommandFinished(self, ret):
-        # type: (int) -> None
+    def onCommandFinished(self, ret: int) -> None:
         if ret == 0:
             self.commitComplete = True
             self.wizard().next()
 
 
 class ResultPage(BasePage):
-    def __init__(self, repoagent, parent):
-        # type: (RepoAgent, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 parent: Optional[QWidget]) -> None:
         super(ResultPage, self).__init__(repoagent, parent)
         self.setTitle(_('Finished'))
         self.setSubTitle(' ')
@@ -631,7 +608,6 @@ class ResultPage(BasePage):
         self.bkCsInfo = bkCsInfo
         self.layout().addStretch(1)
 
-    def currentPage(self):
-        # type: () -> None
-        self.bkCsInfo.update(self.repo[b'tip'])
+    def currentPage(self) -> None:
+        self.bkCsInfo.updateItems(self.repo[b'tip'])
         self.wizard().setOption(QWizard.WizardOption.NoCancelButton, True)
