@@ -18,7 +18,7 @@
 Qt4 widgets to display diffs as blocks
 """
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 from .qtcore import (
     Qt,
@@ -74,12 +74,12 @@ class BlockList(QWidget):
     def addBlock(self, typ, alo, ahi):
         self._blocks.add((typ, alo, ahi))
 
-    def setMaximum(self, maximum):
+    def setMaximum(self, maximum: int) -> None:
         self._maximum = maximum
         self.update()
         self.rangeChanged.emit(self._minimum, self._maximum)
 
-    def setMinimum(self, minimum):
+    def setMinimum(self, minimum: int) -> None:
         self._minimum = minimum
         self.update()
         self.rangeChanged.emit(self._minimum, self._maximum)
@@ -98,7 +98,7 @@ class BlockList(QWidget):
             self.update()
             self.valueChanged.emit(val)
 
-    def setPageStep(self, pagestep):
+    def setPageStep(self, pagestep: int) -> None:
         if pagestep != self._pagestep:
             self._pagestep = pagestep
             self.update()
@@ -281,12 +281,12 @@ class BlockMatch(BlockList):
 
             p.restore()
 
-    def setMaximum(self, maximum, side):
+    def setMaximum(self, maximum: int, side: str = 'left') -> None:
         self._maximum[side] = maximum
         self.update()
         self.rangeChanged.emit(self._minimum[side], self._maximum[side], side)
 
-    def setMinimum(self, minimum, side):
+    def setMinimum(self, minimum: int, side: str = 'left') -> None:
         self._minimum[side] = minimum
         self.update()
         self.rangeChanged.emit(self._minimum[side], self._maximum[side], side)
@@ -313,7 +313,7 @@ class BlockMatch(BlockList):
             self.update()
             self.valueChanged.emit(val, side)
 
-    def setPageStep(self, pagestep, side):
+    def setPageStep(self, pagestep: int, side: str = 'left') -> None:
         if pagestep != self._pagestep[side]:
             self._pagestep[side] = pagestep
             self.update()
@@ -390,7 +390,7 @@ def createTestWidget(ui, parent=None):
     w2.setRange(0, 1200)
     w2.setPageStep(100)
 
-    ui.status('sb1=%d %d %d\n' % (sb1.minimum(), sb1.maximum(), sb1.pageStep()))
-    ui.status('sb2=%d %d %d\n' % (sb2.minimum(), sb2.maximum(), sb2.pageStep()))
+    ui.status(b'sb1=%d %d %d\n' % (sb1.minimum(), sb1.maximum(), sb1.pageStep()))
+    ui.status(b'sb2=%d %d %d\n' % (sb2.minimum(), sb2.maximum(), sb2.pageStep()))
 
     return f
