@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import sys
@@ -274,8 +274,11 @@ class ExceptionMsgBox(QDialog):
                         return self.vfs.reljoin(self.root, f, *insidef)
 
                 fake = FakeRepo()
+                # TODO: a protocol could fix the bogus repo arg type
+                # pytype: disable=wrong-arg-types
                 qtlib.editfiles(fake, [hglib.fromunicode(fname)], int(lineno),
                                 parent=self)
+                # pytype: enable=wrong-arg-types
             except Exception as e:
                 qtlib.openlocalurl(fname)
         if ref.startswith('#fix:'):
