@@ -7,7 +7,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -47,7 +47,6 @@ from . import (
 
 if hglib.TYPE_CHECKING:
     from typing import (
-        Any,
         List,
         Optional,
         Text,
@@ -64,14 +63,12 @@ if hglib.TYPE_CHECKING:
     )
 
 
-def _startrev_available():
-    # type: () -> bool
+def _startrev_available() -> bool:
     entry = cmdutil.findcmd(b'clone', commands.table)[1]
     longopts = set(e[1] for e in entry[1])
     return b'startrev' in longopts
 
-def _suggesteddest(src, basedest):
-    # type: (Text, Text) -> Text
+def _suggesteddest(src: Text, basedest: Text) -> Text:
     if '://' in basedest:
         return basedest
     try:
@@ -92,8 +89,10 @@ def _suggesteddest(src, basedest):
 
 class CloneWidget(cmdui.AbstractCmdWidget):
 
-    def __init__(self, config, cmdagent, parent=None):
-        # type: (HgConfig, cmdcore.CmdAgent, Optional[QWidget]) -> None
+    def __init__(self,
+                 config: HgConfig,
+                 cmdagent: cmdcore.CmdAgent,
+                 parent: Optional[QWidget] = None) -> None:
         super(CloneWidget, self).__init__(parent)
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._config = config
@@ -170,15 +169,17 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             else:
                 return chk, text, None
 
-        def chktext2(chklabel, stretch=None):
-            # type: (Text, Optional[int]) -> Tuple[QCheckBox, QLineEdit]
+        def chktext2(chklabel: Text,
+                     stretch: Optional[int] = None) -> Tuple[QCheckBox, QLineEdit]:
             # pytype gets confused if the returned tuple is sliced and returned
             # without unpacking.
             chk, text, _unused = chktext(chklabel, stretch=stretch)
             return chk, text
 
-        def chktext3(chklabel, btnlabel, btnslot, stretch=None):
-            # type: (Text, Text, Any, Optional[int]) -> Tuple[QCheckBox, QLineEdit, QPushButton]
+        def chktext3(chklabel: Text,
+                     btnlabel: Text,
+                     btnslot,
+                     stretch: Optional[int] = None) -> Tuple[QCheckBox, QLineEdit, QPushButton]:
             assert btnlabel
             ret = chktext(chklabel, btnlabel, btnslot, stretch)
             assert isinstance(ret[2], QPushButton)
@@ -259,8 +260,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
 
         self._composeCommand()
 
-    def readSettings(self, qs):
-        # type: (QSettings) -> None
+    def readSettings(self, qs: QSettings) -> None:
         for key, combo in [('source', self.src_combo),
                            ('dest', self.dest_combo)]:
             # addItems() can overwrite temporary edit text
@@ -273,8 +273,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
 
         self.src_combo.lineEdit().selectAll()
 
-    def writeSettings(self, qs):
-        # type: (QSettings) -> None
+    def writeSettings(self, qs: QSettings) -> None:
         for key, combo in [('source', self.src_combo),
                            ('dest', self.dest_combo)]:
             l = [combo.currentText()]
@@ -282,51 +281,41 @@ class CloneWidget(cmdui.AbstractCmdWidget):
                      if combo.itemText(i) != combo.currentText())
             qs.setValue(key, l[:10])
 
-    def source(self):
-        # type: () -> Text
+    def source(self) -> Text:
         return self.src_combo.currentText().strip()
 
-    def setSource(self, url):
-        # type: (Text) -> None
+    def setSource(self, url: Text) -> None:
         self.src_combo.setCurrentIndex(self.src_combo.findText(url))
         self.src_combo.setEditText(url)
 
-    def destination(self):
-        # type: () -> Text
+    def destination(self) -> Text:
         return self.dest_combo.currentText().strip()
 
-    def setDestination(self, url):
-        # type: (Text) -> None
+    def setDestination(self, url: Text) -> None:
         self.dest_combo.setCurrentIndex(self.dest_combo.findText(url))
         self.dest_combo.setEditText(url)
 
     @pyqtSlot()
-    def _suggestDestination(self):
-        # type: () -> None
+    def _suggestDestination(self) -> None:
         self.setDestination(_suggesteddest(self.source(), self.destination()))
 
-    def revSymbol(self):
-        # type: () -> Text
+    def revSymbol(self) -> Text:
         if not self.rev_chk.isChecked():
             return ''
         return self.rev_text.text().strip()
 
-    def setRevSymbol(self, rev):
-        # type: (Text) -> None
+    def setRevSymbol(self, rev: Text) -> None:
         self.rev_chk.setChecked(bool(rev))
         self.rev_text.setText(rev)
 
-    def testOption(self, key):
-        # type: (Text) -> bool
+    def testOption(self, key: Text) -> bool:
         return self._opt_checks[key].isChecked()
 
-    def setOption(self, key, on):
-        # type: (Text, bool) -> None
+    def setOption(self, key: Text, on: bool) -> None:
         self._opt_checks[key].setChecked(on)
 
     @pyqtSlot()
-    def _composeCommand(self):
-        # type: () -> List[Text]
+    def _composeCommand(self) -> List[Text]:
         opts = {
             'verbose': True,
             'config': [],
@@ -362,19 +351,16 @@ class CloneWidget(cmdui.AbstractCmdWidget):
         self.commandChanged.emit()
         return cmdline
 
-    def canRunCommand(self):
-        # type: () -> bool
+    def canRunCommand(self) -> bool:
         src, dest = self.source(), self.destination()
         return bool(src and dest and src != dest)
 
-    def runCommand(self):
-        # type: () -> cmdcore.CmdSession
+    def runCommand(self) -> cmdcore.CmdSession:
         cmdline = self._composeCommand()
         return self._cmdagent.runCommand(cmdline, self)
 
     @pyqtSlot()
-    def _browseSource(self):
-        # type: () -> None
+    def _browseSource(self) -> None:
         FD = QFileDialog
         caption = _("Select source repository")
         path = FD.getExistingDirectory(self, caption,
@@ -385,8 +371,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             self.dest_combo.setFocus()
 
     @pyqtSlot()
-    def _browseDestination(self):
-        # type: () -> None
+    def _browseDestination(self) -> None:
         FD = QFileDialog
         caption = _("Select destination repository")
         path = FD.getExistingDirectory(self, caption,
@@ -397,8 +382,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             self.dest_combo.setFocus()
 
     @pyqtSlot()
-    def _browsePatchQueue(self):
-        # type: () -> None
+    def _browsePatchQueue(self) -> None:
         FD = QFileDialog
         caption = _("Select patch folder")
         upatchroot = os.path.join(self.src_combo.currentText(), '.hg')
@@ -409,8 +393,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             self.qclone_txt.setFocus()
 
     @pyqtSlot()
-    def _onSourceChanged(self):
-        # type: () -> None
+    def _onSourceChanged(self) -> None:
         self.insecure_chk.setEnabled(self.source().startswith('https://'))
         self._composeCommand()
 
@@ -419,8 +402,10 @@ class CloneDialog(cmdui.CmdControlDialog):
 
     clonedRepository = pyqtSignal(str, str)
 
-    def __init__(self, ui, config, parent=None):
-        # type: (uimod.ui, HgConfig, Optional[QWidget]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 config: HgConfig,
+                 parent: Optional[QWidget] = None) -> None:
         super(CloneDialog, self).__init__(parent)
 
         self.setWindowTitle(_('Clone - %s') % hglib.getcwdu())
@@ -432,50 +417,40 @@ class CloneDialog(cmdui.CmdControlDialog):
         self.setCommandWidget(CloneWidget(config, cmdagent, self))
         self.commandFinished.connect(self._emitCloned)
 
-    def source(self):
-        # type: () -> Text
+    def source(self) -> Text:
         return self.commandWidget().source()
 
-    def setSource(self, url):
-        # type: (Text) -> None
+    def setSource(self, url: Text) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setSource(url)
 
-    def destination(self):
-        # type: () -> Text
+    def destination(self) -> Text:
         return self.commandWidget().destination()
 
-    def setDestination(self, url):
-        # type: (Text) -> None
+    def setDestination(self, url: Text) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setDestination(url)
 
-    def revSymbol(self):
-        # type: () -> Text
+    def revSymbol(self) -> Text:
         return self.commandWidget().revSymbol()
 
-    def setRevSymbol(self, rev):
-        # type: (Text) -> None
+    def setRevSymbol(self, rev: Text) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setRevSymbol(rev)
 
-    def testOption(self, key):
-        # type: (Text) -> bool
+    def testOption(self, key: Text) -> bool:
         return self.commandWidget().testOption(key)
 
-    def setOption(self, key, on):
-        # type: (Text, bool) -> None
+    def setOption(self, key: Text, on: bool) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setOption(key, on)
 
     @pyqtSlot(int)
-    def _emitCloned(self, ret):
-        # type: (int) -> None
+    def _emitCloned(self, ret: int) -> None:
         if ret == 0:
             self.clonedRepository.emit(self.destination(), self.source())
 
-    def done(self, r):
-        # type: (int) -> None
+    def done(self, r: int) -> None:
         if self._cmdagent.isServiceRunning():
             self._cmdagent.stopService()
             return  # postponed until serviceStopped
