@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 from .qtgui import (
     QSizePolicy,
     QLineEdit,
@@ -39,8 +41,10 @@ if hglib.TYPE_CHECKING:
 
 
 class CloseWidget(cmdui.AbstractCmdWidget):
-    def __init__(self, repoagent, rev, parent=None):
-        # type: (RepoAgent, int, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 rev: int,
+                 parent: Optional[QWidget] = None) -> None:
         super(CloseWidget, self).__init__(parent)
         self._repoagent = repoagent
         self._repo = repoagent.rawRepo()
@@ -61,24 +65,22 @@ class CloseWidget(cmdui.AbstractCmdWidget):
                                hglib.tounicode(self._repo[self._rev].branch()))
         form.addRow(_('Commit message:'), self.hg_commit)
 
-    def compose_command(self):
-        # type: () -> List[Text]
+    def compose_command(self) -> List[Text]:
         rev = '%d' % self._rev
         cmdline = hglib.buildcmdargs('close-head', m=self.hg_commit.text(),
                                      r=rev)
         return cmdline
 
-    def runCommand(self):
-        # type: () -> CmdSession
+    def runCommand(self) -> CmdSession:
         cmdline = self.compose_command()
         return self._repoagent.runCommand(cmdline, self)
 
-    def canRunCommand(self):
-        # type: () -> bool
+    def canRunCommand(self) -> bool:
         return True
 
-def createCloseBranchDialog(repoagent, rev, parent):
-    # type: (RepoAgent, int, Optional[QWidget]) -> cmdui.CmdControlDialog
+def createCloseBranchDialog(repoagent: RepoAgent,
+                            rev: int,
+                            parent: Optional[QWidget]) -> cmdui.CmdControlDialog:
     dlg = cmdui.CmdControlDialog(parent)
     dlg.setWindowTitle(_('Close Branch - %s') % repoagent.displayName())
     dlg.setRunButtonText(_('&Close Branch'))
