@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import os
 import signal
@@ -28,6 +28,9 @@ from .qtcore import (
     pyqtSlot,
 )
 
+from . import (
+    qtlib,
+)
 from ..util import (
     hglib,
     paths,
@@ -64,8 +67,12 @@ class ProgressMessage(tuple):
 
     if hglib.TYPE_CHECKING:
         # pseudo implementation to help pytype (TODO: replace with attr.s)
-        def __init__(self, topic, pos, item=b'', unit=b'', total=None):
-            # type: (Union[bytes, Text], Optional[int], Union[bytes, Text], Union[bytes, Text], Optional[int]) -> None
+        def __init__(self,
+                     topic: Union[bytes, Text],
+                     pos: Optional[int],
+                     item: Union[bytes, Text] = b'',
+                     unit: Union[bytes, Text] = b'',
+                     total: Optional[int] = None) -> None:
             super(ProgressMessage, self).__init__((
                 hglib.tounicode(topic),
                 pos,
@@ -75,24 +82,19 @@ class ProgressMessage(tuple):
             ))
 
     @property
-    def topic(self):
-        # type: () -> pycompat.unicode
+    def topic(self) -> str:
         return self[0]  # pytype: disable=bad-return-type
     @property
-    def pos(self):
-        # type: () -> Optional[int]
+    def pos(self) -> Optional[int]:
         return self[1]  # pytype: disable=bad-return-type
     @property
-    def item(self):
-        # type: () -> pycompat.unicode
+    def item(self) -> str:
         return self[2]  # pytype: disable=bad-return-type
     @property
-    def unit(self):
-        # type: () -> pycompat.unicode
+    def unit(self) -> str:
         return self[3]  # pytype: disable=bad-return-type
     @property
-    def total(self):
-        # type: () -> Optional[int]
+    def total(self) -> Optional[int]:
         return self[4]  # pytype: disable=bad-return-type
 
     def __repr__(self):
@@ -109,52 +111,48 @@ class UiHandler(object):
     PasswordInput = 2
     ChoiceInput = 3
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
         self._datain = None
         self._dataout = None
 
-    def setPrompt(self, text, mode, default=None):
-        # type: (Text, int, Optional[Text]) -> None
+    def setPrompt(self,
+                  text: Text,
+                  mode: int,
+                  default: Optional[Text] = None) -> None:
         pass
 
-    def getLineInput(self):
-        # type: () -> Optional[Text]
+    def getLineInput(self) -> Optional[Text]:
         # '' to use default; None to abort
         return ''
 
-    def setDataInputDevice(self, device):
-        # type: (Optional[QIODevice]) -> None
+    def setDataInputDevice(self, device: Optional[QIODevice]) -> None:
         # QIODevice to read data from; None to disable data input
         self._datain = device
 
-    def setDataOutputDevice(self, device):
-        # type: (Optional[QIODevice]) -> None
+    def setDataOutputDevice(self, device: Optional[QIODevice]) -> None:
         # QIODevice to write data output; None to disable capturing
         self._dataout = device
 
-    def inputAtEnd(self):
-        # type: () -> bool
+    def inputAtEnd(self) -> bool:
         if not self._datain:
             return True
         return self._datain.atEnd()
 
-    def readInput(self, size):
-        # type: (int) -> Optional[bytes]
+    def readInput(self, size: int) -> Optional[bytes]:
         # b'' for EOF; None for error (per PyQt's QIODevice.read() convention)
         if not self._datain:
             return b''
         return self._datain.read(size)
 
-    def writeOutput(self, data, label):
-        # type: (Union[QByteArray, bytes, bytearray], bytes) -> int
+    def writeOutput(self,
+                    data: Union[QByteArray, bytes, bytearray],
+                    label: bytes) -> int:
         if not self._dataout or label.startswith(b'ui.') or b' ui.' in label:
             return -1
         return self._dataout.write(data)
 
 
-def _createDefaultUiHandler(uiparent):
-    # type: (Optional[QWidget]) -> UiHandler
+def _createDefaultUiHandler(uiparent: Optional[QWidget]) -> UiHandler:
     if uiparent is None:
         return UiHandler()
     # this makes layering violation but is handy to create GUI handler by
@@ -189,25 +187,19 @@ class CmdWorker(QObject):
     outputReceived = pyqtSignal(str, str)
     progressReceived = pyqtSignal(ProgressMessage)
 
-    def serviceState(self):
-        # type: () -> int
+    def serviceState(self) -> int:
         return CmdWorker.NoService
-    def startService(self):
-        # type: () -> None
+    def startService(self) -> None:
         # NotRunning->Starting; Stopping->Restarting->Starting; *->*
         pass
-    def stopService(self):
-        # type: () -> None
+    def stopService(self) -> None:
         # {Starting,Ready,Restarting}->Stopping; *->*
         pass
-    def startCommand(self, cmdline, uihandler):
-        # type: (List[Text], UiHandler) -> None
+    def startCommand(self, cmdline: List[Text], uihandler: UiHandler) -> None:
         raise NotImplementedError
-    def abortCommand(self):
-        # type: () -> None
+    def abortCommand(self) -> None:
         raise NotImplementedError
-    def isCommandRunning(self):
-        # type: () -> bool
+    def isCommandRunning(self) -> bool:
         raise NotImplementedError
 
 
@@ -229,7 +221,7 @@ if os.name == 'nt':
 
 else:
     def _interruptproc(proc):
-        os.kill(int(proc.pid()), signal.SIGINT)
+        os.kill(proc.processId(), signal.SIGINT)
 
 def _fixprocenv(proc):
     env = QProcessEnvironment.systemEnvironment()
@@ -245,7 +237,7 @@ def _fixprocenv(proc):
         # make sure hg process can look up our modules
         pypath = hglib.tounicode(thgroot)
         if env.contains('PYTHONPATH'):
-            pypath += os.pathsep + pycompat.unicode(env.value('PYTHONPATH'))
+            pypath += os.pathsep + env.value('PYTHONPATH')
         env.insert('PYTHONPATH', pypath)
     proc.setProcessEnvironment(env)
 
@@ -268,8 +260,10 @@ def _proccmdline(ui, exts):
 class CmdProc(CmdWorker):
     'Run mercurial command in separate process'
 
-    def __init__(self, ui, parent=None, cwd=None):
-        # type: (uimod.ui, Optional[QObject], Optional[Text]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 parent: Optional[QObject] = None,
+                 cwd: Optional[Text] = None) -> None:
         super(CmdProc, self).__init__(parent)
         self._ui = ui
         self._uihandler = None
@@ -282,21 +276,18 @@ class CmdProc(CmdWorker):
         proc.readyReadStandardError.connect(self._stderr)
         proc.errorOccurred.connect(self._handleerror)
 
-    def startCommand(self, cmdline, uihandler):
-        # type: (List[Text], UiHandler) -> None
+    def startCommand(self, cmdline: List[Text], uihandler: UiHandler) -> None:
         self._uihandler = uihandler
         fullcmdline = _proccmdline(self._ui, _localprocexts)
         fullcmdline.extend(cmdline)
         self._proc.start(fullcmdline[0], fullcmdline[1:], QIODevice.OpenModeFlag.ReadOnly)
 
-    def abortCommand(self):
-        # type: () -> None
+    def abortCommand(self) -> None:
         if not self.isCommandRunning():
             return
         _interruptproc(self._proc)
 
-    def isCommandRunning(self):
-        # type: () -> bool
+    def isCommandRunning(self) -> bool:
         return self._proc.state() != QProcess.ProcessState.NotRunning
 
     @pyqtSlot(int)
@@ -342,8 +333,10 @@ class CmdProc(CmdWorker):
 class CmdServer(CmdWorker):
     """Run Mercurial commands in command server process"""
 
-    def __init__(self, ui, parent=None, cwd=None):
-        # type: (uimod.ui, Optional[QObject], Optional[Text]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 parent: Optional[QObject] = None,
+                 cwd: Optional[Text] = None) -> None:
         super(CmdServer, self).__init__(parent)
         self._ui = ui
         self._uihandler = UiHandler()
@@ -368,8 +361,7 @@ class CmdServer(CmdWorker):
         proc.readyReadStandardError.connect(self._onReadyReadError)
         return proc
 
-    def serviceState(self):
-        # type: () -> int
+    def serviceState(self) -> int:
         return self._servicestate
 
     def _changeServiceState(self, newstate):
@@ -378,8 +370,7 @@ class CmdServer(CmdWorker):
         self._servicestate = newstate
         self.serviceStateChanged.emit(newstate)
 
-    def startService(self):
-        # type: () -> None
+    def startService(self) -> None:
         if self._servicestate == CmdWorker.NotRunning:
             self._startService()
         elif self._servicestate == CmdWorker.Stopping:
@@ -401,8 +392,7 @@ class CmdServer(CmdWorker):
         self._changeServiceState(CmdWorker.Starting)
         self._proc.start(cmdline[0], cmdline[1:])
 
-    def stopService(self):
-        # type: () -> None
+    def stopService(self) -> None:
         if self._servicestate in (CmdWorker.Starting, CmdWorker.Ready):
             self._stopService()
         elif self._servicestate == CmdWorker.Restarting:
@@ -437,12 +427,10 @@ class CmdServer(CmdWorker):
                             % self._proc.exitCode())
         self._changeServiceState(CmdWorker.NotRunning)
 
-    def isCommandRunning(self):
-        # type: () -> bool
+    def isCommandRunning(self) -> bool:
         return self._readchtable is self._runcommandchtable
 
-    def startCommand(self, cmdline, uihandler):
-        # type: (List[Text], UiHandler) -> None
+    def startCommand(self, cmdline: List[Text], uihandler: UiHandler) -> None:
         assert self._servicestate == CmdWorker.Ready, self._servicestate
         assert not self.isCommandRunning()
         try:
@@ -477,7 +465,7 @@ class CmdServer(CmdWorker):
         headersize = 5
         try:
             while True:
-                header = proc.peek(headersize).data()
+                header = qtlib.qbytearray_or_bytes_to_bytes(proc.peek(headersize))
                 if not header:
                     self._readtimer.stop()
                     break
@@ -505,7 +493,7 @@ class CmdServer(CmdWorker):
 
     @pyqtSlot()
     def _onReadTimeout(self):
-        startbytes = self._proc.peek(20).data()
+        startbytes = qtlib.qbytearray_or_bytes_to_bytes(self._proc.peek(20))
         if startbytes:
             # data corruption because bad extension might write to stdout?
             self._emitError(_('timed out while reading: %r...') % startbytes)
@@ -629,15 +617,17 @@ class CmdServer(CmdWorker):
         }
 
 
-_workertypes = {
+_workertypes: Dict[Text, Callable[[uimod.ui, Optional[QObject], Optional[Text]], CmdWorker]] = {
     'proc': CmdProc,
     'server': CmdServer,
-}  # type: Dict[Text, Callable[[uimod.ui, Optional[QObject], Optional[Text]], CmdWorker]]
+}
 
 
 class CmdSession(QObject):
     """Run Mercurial commands in a background thread or process"""
 
+    _worker: Optional[CmdWorker]
+
     commandFinished = pyqtSignal(int)
     # in order to receive only notification messages of session state, use
     # "controlMessage"; otherwise use "outputReceived"
@@ -646,11 +636,13 @@ class CmdSession(QObject):
     progressReceived = pyqtSignal(ProgressMessage)
     readyRead = pyqtSignal()
 
-    def __init__(self, cmdlines, uihandler, parent=None):
-        # type: (List[List[Text]], UiHandler, Optional[QObject]) -> None
+    def __init__(self,
+                 cmdlines: List[List[Text]],
+                 uihandler: UiHandler,
+                 parent: Optional[QObject] = None) -> None:
         super(CmdSession, self).__init__(parent)
         self._uihandler = uihandler
-        self._worker = None  # type: Optional[CmdWorker]
+        self._worker = None
         self._queue = list(cmdlines)
         self._qnextp = 0
         self._abortbyuser = False
@@ -662,8 +654,7 @@ class CmdSession(QObject):
             # assumes null session is failure for convenience
             self._exitcode = -1
 
-    def run(self, worker):
-        # type: (CmdWorker) -> None
+    def run(self, worker: CmdWorker) -> None:
         '''Execute Mercurial command'''
         if self._worker or self._qnextp >= len(self._queue):
             return
@@ -671,8 +662,7 @@ class CmdSession(QObject):
         if worker.serviceState() in (CmdWorker.NoService, CmdWorker.Ready):
             self._runNext()
 
-    def abort(self):
-        # type: () -> None
+    def abort(self) -> None:
         '''Cancel running Mercurial command'''
         if self.isRunning():
             self._worker.abortCommand()
@@ -683,41 +673,34 @@ class CmdSession(QObject):
             # -1 instead of 255 for compatibility with CmdThread
             self._finish(-1)
 
-    def isAborted(self):
-        # type: () -> bool
+    def isAborted(self) -> bool:
         """True if commands have finished by user abort"""
         return self.isFinished() and self._abortbyuser
 
-    def isFinished(self):
-        # type: () -> bool
+    def isFinished(self) -> bool:
         """True if all pending commands have finished or been aborted"""
         return self._qnextp >= len(self._queue) and not self.isRunning()
 
-    def isRunning(self):
-        # type: () -> bool
+    def isRunning(self) -> bool:
         """True if a command is running; False if finished or not started yet"""
         return bool(self._worker) and self._qnextp > 0
 
-    def errorString(self):
-        # type: () -> Text
+    def errorString(self) -> Text:
         """Error message received in the last command"""
         if self._abortbyuser:
             return _('Terminated by user')
         else:
             return ''.join(self._erroroutputs).rstrip()
 
-    def warningString(self):
-        # type: () -> Text
+    def warningString(self) -> Text:
         """Warning message received in the last command"""
         return ''.join(self._warningoutputs).rstrip()
 
-    def exitCode(self):
-        # type: () -> int
+    def exitCode(self) -> int:
         """Integer return code of the last command"""
         return self._exitcode
 
-    def setCaptureOutput(self, enabled):
-        # type: (bool) -> None
+    def setCaptureOutput(self, enabled: bool) -> None:
         """If enabled, data outputs (without "ui.*" label) are queued and
         outputReceived signal is not emitted in that case.  This is useful
         for receiving data to be parsed or copied to the clipboard.
@@ -734,41 +717,42 @@ class CmdSession(QObject):
             dataoutwbuf = None
         self.setOutputDevice(dataoutwbuf)
 
-    def setInputDevice(self, device):
-        # type: (Optional[QIODevice]) -> None
+    def setInputDevice(self, device: Optional[QIODevice]) -> None:
         """If set, data will be read from the specified device on data input
         request"""
         if self.isRunning():
             raise RuntimeError('command already running')
         self._uihandler.setDataInputDevice(device)
 
-    def setOutputDevice(self, device):
-        # type: (Optional[QIODevice]) -> None
+    def setOutputDevice(self, device: Optional[QIODevice]) -> None:
         """If set, data outputs will be sent to the specified device"""
         if self.isRunning():
             raise RuntimeError('command already running')
         self._uihandler.setDataOutputDevice(device)
 
-    def read(self, maxlen):
-        # type: (int) -> bytes
+    def read(self, maxlen: int) -> bytes:
         """Read output if capturing enabled; ui messages are not included"""
         return self._dataoutrbuf.read(maxlen)
 
-    def readAll(self):
-        # type: () -> QByteArray
+    def readAll(self) -> QByteArray:
         return self._dataoutrbuf.readAll()
 
-    def readLine(self, maxlen=0):
-        # type: (int) -> bytes
-        return self._dataoutrbuf.readLine(maxlen)
+    def readLine(self, maxlen: int = 0) -> bytes:
+        buf = self._dataoutrbuf
+        # There's possibly a bug in PyQt 6.8.1 or Qt 6.8.0 where passing 0 fails
+        # and prints "QIODevice::readLine (QBuffer): Called with maxSize < 2" to
+        # stderr.
+        if maxlen == 0:
+            line = buf.readLine()
+        else:
+            line = buf.readLine(maxlen)
+        return qtlib.qbytearray_or_bytes_to_bytes(line)
 
-    def canReadLine(self):
-        # type: () -> bool
+    def canReadLine(self) -> bool:
         return self._dataoutrbuf.canReadLine()
 
-    def peek(self, maxlen):
-        # type: (int) -> QByteArray
-        return self._dataoutrbuf.peek(maxlen)
+    def peek(self, maxlen: int) -> bytes:
+        return qtlib.qbytearray_or_bytes_to_bytes(self._dataoutrbuf.peek(maxlen))
 
     def _connectWorker(self, worker):
         self._worker = worker
@@ -833,19 +817,18 @@ class CmdSession(QObject):
             self._runNext()
 
     @pyqtSlot(str, str)
-    def _captureOutput(self, msg, label):
+    def _captureOutput(self, msg: str, label: str):
         if not label:
             return  # fast path
-        labelset = pycompat.unicode(label).split()
+        labelset = label.split()
         # typically ui.error is sent only once at end
         if 'ui.error' in labelset:
-            self._erroroutputs.append(pycompat.unicode(msg))
+            self._erroroutputs.append(msg)
         elif 'ui.warning' in labelset:
-            self._warningoutputs.append(pycompat.unicode(msg))
+            self._warningoutputs.append(msg)
 
 
-def nullCmdSession():
-    # type: () -> CmdSession
+def nullCmdSession() -> CmdSession:
     """Finished CmdSession object which can be used as the initial value
 
     exitCode() is -1 so that the command dialog can finish with error status
@@ -886,8 +869,11 @@ class CmdAgent(QObject):
     # isBusy() is False when the last commandFinished is emitted, but you
     # shouldn't rely on the emission order of busyChanged and commandFinished.
 
-    def __init__(self, ui, parent=None, cwd=None, worker=None):
-        # type: (uimod.ui, Optional[QObject], Optional[Text], Optional[Text]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 parent: Optional[QObject] = None,
+                 cwd: Optional[Text] = None,
+                 worker: Optional[Text] = None) -> None:
         super(CmdAgent, self).__init__(parent)
         self._ui = ui
         self._worker = self._createWorker(cwd, worker or 'server')
@@ -895,13 +881,11 @@ class CmdAgent(QObject):
         self._runlater = QTimer(self, interval=0, singleShot=True)
         self._runlater.timeout.connect(self._runNextSession)
 
-    def isServiceRunning(self):
-        # type: () -> bool
+    def isServiceRunning(self) -> bool:
         stoppedstates = (CmdWorker.NoService, CmdWorker.NotRunning)
         return self._worker.serviceState() not in stoppedstates
 
-    def stopService(self):
-        # type: () -> None
+    def stopService(self) -> None:
         """Shut down back-end services so that this can be deleted safely or
         reconfigured; serviceStopped will be emitted asynchronously"""
         self._worker.stopService()
@@ -911,8 +895,7 @@ class CmdAgent(QObject):
         if not self.isServiceRunning():
             self.serviceStopped.emit()
 
-    def isBusy(self):
-        # type: () -> bool
+    def isBusy(self) -> bool:
         return bool(self._sessqueue)
 
     def _enqueueSession(self, sess):
@@ -938,14 +921,16 @@ class CmdAgent(QObject):
                 del self._sessqueue[i]
                 sess.setParent(None)
 
-    def runCommand(self, cmdline, uihandler=None):
-        # type: (List[Text], Optional[Union[QWidget, UiHandler]]) -> CmdSession
+    def runCommand(self,
+                   cmdline: List[Text],
+                   uihandler: Optional[Union[QWidget, UiHandler]] = None) -> CmdSession:
         """Executes a single Mercurial command asynchronously and returns
         new CmdSession object"""
         return self.runCommandSequence([cmdline], uihandler)
 
-    def runCommandSequence(self, cmdlines, uihandler=None):
-        # type: (List[List[Text]], Optional[Union[QWidget, UiHandler]]) -> CmdSession
+    def runCommandSequence(self,
+                           cmdlines: List[List[Text]],
+                           uihandler: Optional[Union[QWidget, UiHandler]] = None) -> CmdSession:
         """Executes a series of Mercurial commands asynchronously and returns
         new CmdSession object which will provide notification signals.
 
@@ -972,15 +957,13 @@ class CmdAgent(QObject):
         self._enqueueSession(sess)
         return sess
 
-    def abortCommands(self):
-        # type: () -> None
+    def abortCommands(self) -> None:
         """Abort running and queued commands; all command sessions will emit
         commandFinished"""
         for sess in self._sessqueue[:]:
             sess.abort()
 
-    def _createWorker(self, cwd, name):
-        # type: (Optional[Text], Text) -> CmdWorker
+    def _createWorker(self, cwd: Optional[Text], name: Text) -> CmdWorker:
         self._ui.debug(b"creating cmdworker '%s'\n" % pycompat.sysbytes(name))
         worker = _workertypes[name](self._ui, self, cwd)
         worker.serviceStateChanged.connect(self._tryEmitServiceStopped)
