@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import weakref
 
@@ -293,8 +293,7 @@ class InteractiveUiHandler(cmdcore.UiHandler):
     """Handle user interaction of Mercurial commands with GUI prompt"""
 
     # Unlike QObject, "uiparent" does not own this handler
-    def __init__(self, uiparent=None):
-        # type: (Optional[QWidget]) -> None
+    def __init__(self, uiparent: Optional[QWidget] = None) -> None:
         super(InteractiveUiHandler, self).__init__()
         self._prompttext = ''
         self._promptmode = cmdcore.UiHandler.NoInput
