@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import re
@@ -115,8 +115,7 @@ if os.name == 'nt':
 else:
     _hasbugtraq = False
 
-def readopts(repoagent):
-    # type: (RepoAgent) -> CommitOpts
+def readopts(repoagent: RepoAgent) -> CommitOpts:
     opts = {
         'ciexclude': repoagent.configString('tortoisehg', 'ciexclude'),
         'pushafter': repoagent.configString('tortoisehg', 'cipushafter'),
@@ -134,8 +133,7 @@ def readopts(repoagent):
 
     return opts
 
-def commitopts2str(opts, mode='commit'):
-    # type: (CommitOpts, Text) -> Text
+def commitopts2str(opts: CommitOpts, mode: Text = 'commit') -> Text:
     optslist = []
     for opt, value in opts.items():
         if opt in ['user', 'date', 'pushafter', 'autoinc',
@@ -149,8 +147,7 @@ def commitopts2str(opts, mode='commit'):
                 optslist.append('--%s=%s' % (opt, value))
     return ' '.join(optslist)
 
-def mergecommitmessage(repo):
-    # type: (localrepo.localrepository) -> Text
+def mergecommitmessage(repo: localrepo.localrepository) -> Text:
     wctx = repo[None]
     engmsg = repo.ui.configbool(b'tortoisehg', b'engmsg')
     bcustommsg = repo.ui.config(b'tortoisehg', b'mergecommitmessage')
@@ -165,8 +162,8 @@ def mergecommitmessage(repo):
         text = text % hglib.tounicode(wctx.p2().branch())
     return text
 
-def _getUserOptions(opts, optionlist):
-    # type: (CommitOpts, Iterable[Text]) -> List[Text]
+def _getUserOptions(opts: CommitOpts,
+                    optionlist: Iterable[Text]) -> List[Text]:
     out = []
     for opt in optionlist:
         if opt not in opts:
@@ -184,8 +181,13 @@ def _getUserOptions(opts, optionlist):
             out.append(str(val))
     return out
 
-def _mqNewRefreshCommand(repo, isnew, stwidget, pnwidget, message, opts, olist):
-    # type: (localrepo.localrepository, bool, status.StatusWidget, QLineEdit, Text, CommitOpts, Iterable[Text]) -> Optional[CmdLines]
+def _mqNewRefreshCommand(repo: localrepo.localrepository,
+                         isnew: bool,
+                         stwidget: status.StatusWidget,
+                         pnwidget: QLineEdit,
+                         message: Text,
+                         opts: CommitOpts,
+                         olist: Iterable[Text]) -> Optional[CmdLines]:
     # TODO: convert all bytes to unicode in the return value
     if isnew:
         name = pnwidget.text()
@@ -237,8 +239,12 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
     progress = pyqtSignal(str, object, str, str, object)
 
-    def __init__(self, repoagent, pats, opts, parent=None, rev=None):
-        # type: (RepoAgent, List[bytes], Dict[Text, bytes], Optional[QObject], Optional[Text]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 pats: List[bytes],
+                 opts: Dict[Text, bytes],
+                 parent: Optional[QObject] = None,
+                 rev: Optional[Text] = None) -> None:
         # TODO: drop `opts`, since it is immediately overwritten?
         # TODO: make `rev` a byte string?
         QWidget.__init__(self, parent)
@@ -406,18 +412,15 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.msgte = msgte
 
     @property
-    def repo(self):
-        # type: () -> localrepo.localrepository
+    def repo(self) -> localrepo.localrepository:
         return self._repoagent.rawRepo()
 
     @property
-    def rev(self):
-        # type: () -> Text
+    def rev(self) -> Text:
         """Return current revision"""
         return self._rev
 
-    def selectRev(self, rev):
-        # type: (Text) -> None
+    def selectRev(self, rev: Text) -> None:
         """
         Select the revision that must be set when the dialog is shown again
         """
@@ -436,8 +439,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                 self.commitSetAction(refresh=True,
                     actionName=preferredActionName)
 
-    def _getPreferredActionName(self):
-        # type: () -> Text
+    def _getPreferredActionName(self) -> Text:
         """Select the preferred action, depending on the selected revision"""
         if not self.hasmqbutton:
             return 'commit'
@@ -454,12 +456,10 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                 # Set the button to QRefresh
                 return 'qref'
 
-    def commitSetupButton(self):
-        # type: () -> QToolButton
-        ispatch = lambda r: b'qtip' in r[b'.'].tags()  # type: Callable[[localrepo.localrepository], bool]
-        notpatch = lambda r: b'qtip' not in r[b'.'].tags()  # type: Callable[[localrepo.localrepository], bool]
-        def canamend(r):
-            # type: (localrepo.localrepository) -> bool
+    def commitSetupButton(self) -> QToolButton:
+        ispatch: Callable[[localrepo.localrepository], bool] = lambda r: b'qtip' in r[b'.'].tags()
+        notpatch: Callable[[localrepo.localrepository], bool] = lambda r: b'qtip' not in r[b'.'].tags()
+        def canamend(r: localrepo.localrepository) -> bool:
             if ispatch(r):
                 return False
             ctx = r[b'.']
@@ -510,8 +510,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             def __init__(self, parent, repo):
                 self.repo = repo
                 QMenu.__init__(self, parent)
-            def getActionByName(self, act):
-                # type: (Text) -> QAction
+            def getActionByName(self, act: Text) -> QAction:
                 return [a for a in self.actions() if a._name == act][0]
             def showEvent(self, event):
                 for a in self.actions():
@@ -540,8 +539,9 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         return committb
 
     @pyqtSlot(bool)
-    def commitSetAction(self, refresh=False, actionName=None):
-        # type: (bool, Optional[Text]) -> None
+    def commitSetAction(self,
+                        refresh: bool = False,
+                        actionName: Optional[Text] = None) -> None:
         # TODO: should this slot also be declared with str arg?
         allowcs = False
         if actionName:
@@ -610,12 +610,11 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             self.stwidget.refreshWctx()
         custom = self.wdirinfo.custom.copy()
         custom['isAmend'] = curraction._name == 'amend'
-        self.wdirinfo.update(custom=custom)
+        self.wdirinfo.updateItems(custom=custom)
         self.committb.setText(curraction._text)
         self.lastAction = curraction._name
 
-    def getBranchCommandLine(self):
-        # type: () -> Tuple[Optional[CmdLines], bool]
+    def getBranchCommandLine(self) -> Tuple[Optional[CmdLines], bool]:
         '''
         Create the command line to change or create the selected branch unless
         it is the selected branch
@@ -663,8 +662,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         return commandlines, newbranch
 
     @pyqtSlot()
-    def mqPerformAction(self):
-        # type: () -> Optional[bool]
+    def mqPerformAction(self) -> Optional[bool]:
         # TODO: drop bool return?
         curraction = self.mqgroup.checkedAction()
         if curraction._name == 'commit':
@@ -692,8 +690,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self._runCommand(curraction._name, wholecmdlines)
 
     @pyqtSlot(str, str)
-    def fileDisplayed(self, wfile, contents):
-        # type: (Text, Text) -> None
+    def fileDisplayed(self, wfile: Text, contents: Text) -> None:
         'Status widget is displaying a new file'
         if not (wfile and contents):
             return
@@ -740,13 +737,11 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self._apis.apiPreparationFinished.connect(self.apiPrepFinished)
         self._apis.prepare()
 
-    def apiPrepFinished(self):
-        # type: () -> None
+    def apiPrepFinished(self) -> None:
         'QsciAPIs has finished parsing displayed file'
         self.msgte.lexer().setAPIs(self._apis)
 
-    def bugTrackerPostCommit(self):
-        # type: () -> None
+    def bugTrackerPostCommit(self) -> None:
         if not _hasbugtraq or self.opts['bugtraqtrigger'] != 'commit':
             return
         # commit already happened, get last message in history
@@ -764,15 +759,13 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         result = bugtraq.BugTraq(bugtraqid)
         return result
 
-    def getBugTrackerCommitMessage(self):
-        # type: () -> None
+    def getBugTrackerCommitMessage(self) -> None:
         parameters = self.opts['bugtraqparameters']
         message = self.getMessage(True)
         newMessage = self.bugtraq.get_commit_message(parameters, message)
         self.setMessage(newMessage)
 
-    def details(self):
-        # type: () -> None
+    def details(self) -> None:
         mode = 'commit'
         if len(self.repo[None].parents()) > 1:
             mode = 'merge'
@@ -786,15 +779,13 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             self.refresh()
 
     @pyqtSlot(int)
-    def repositoryChanged(self, flags):
-        # type: (int) -> None
+    def repositoryChanged(self, flags: int) -> None:
         if flags & thgrepo.WorkingParentChanged:
             self._refreshWorkingState()
         elif flags & thgrepo.WorkingBranchChanged:
             self.refresh()
 
-    def _refreshWorkingState(self):
-        # type: () -> None
+    def _refreshWorkingState(self) -> None:
         curraction = self.mqgroup.checkedAction()
         if curraction._name == 'commit' and not self.msgte.isModified():
             # default merge or close-branch message is outdated if new commit
@@ -818,22 +809,19 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.lastCommitMsgs['amend'] = ('', False)  # clear saved stale cache
 
     @pyqtSlot()
-    def refreshWctx(self):
-        # type: () -> None
+    def refreshWctx(self) -> None:
         'User has requested a working context refresh'
         self.stwidget.refreshWctx() # Trigger reload of working context
 
     @pyqtSlot()
-    def reload(self):
-        # type: () -> None
+    def reload(self) -> None:
         'User has requested a reload'
         self.repo.thginvalidate()
         self.refresh()
         self.stwidget.refreshWctx() # Trigger reload of working context
 
     @pyqtSlot()
-    def refresh(self):
-        # type: () -> None
+    def refresh(self) -> None:
         ispatch = self.repo[b'.'].thgmqappliedpatch()
         if not self.hasmqbutton:
             self.commitButtonEnable.emit(not ispatch)
@@ -867,7 +855,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
         # Update wdir csinfo widget
         self.wdirinfo.set_revision(None)
-        self.wdirinfo.update()
+        self.wdirinfo.updateItems()
 
         # This is ugly, but want pnlabel to have the same alignment/style/etc
         # as wdirinfo, so extract the needed parts of wdirinfo's markup.  Would
@@ -887,8 +875,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                 self.pnlabel.setText(patchname)
             self.commitSetAction()
 
-    def branchOp(self):
-        # type: () -> None
+    def branchOp(self) -> None:
         d = branchop.BranchOpDialog(self._repoagent, self.branchop, self)
         d.setWindowFlags(Qt.WindowType.Sheet)
         d.setWindowModality(Qt.WindowModality.WindowModal)
@@ -905,8 +892,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             self.msgte.setFocus()
             self.refresh()
 
-    def topicOp(self):
-        # type: () -> None
+    def topicOp(self) -> None:
         d = topic.TopicDialog(self._repoagent, None, self)
         d.setWindowFlags(Qt.WindowType.Sheet)
         d.setWindowModality(Qt.WindowModality.WindowModal)
@@ -914,16 +900,14 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.msgte.setFocus()
         self.refresh()
 
-    def canUndo(self):
-        # type: () -> Optional[Text]
+    def canUndo(self) -> Optional[Text]:
         'Returns undo description or None if not valid'
         desc, oldlen = hglib.readundodesc(self.repo)
         if desc == 'commit':
             return _('Rollback commit to revision %d') % (oldlen - 1)
         return None
 
-    def rollback(self):
-        # type: () -> None
+    def rollback(self) -> None:
         msg = self.canUndo()
         if not msg:
             return
@@ -933,8 +917,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             return
         self._runCommand('rollback', [['rollback']])
 
-    def updateRecentMessages(self):
-        # type: () -> None
+    def updateRecentMessages(self) -> None:
         # Define a menu that lists recent messages
         m = self.recentMessagesButton.menu()
         m.clear()
@@ -943,8 +926,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             a = m.addAction(title)
             a.setData(s)
 
-    def getMessage(self, allowreplace):
-        # type: (bool) -> bytes
+    def getMessage(self, allowreplace: bool) -> bytes:
         text = self.msgte.text()
         try:
             return hglib.fromunicode(text, 'strict')
@@ -955,8 +937,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                 raise
 
     @pyqtSlot(QAction)
-    def msgSelected(self, action):
-        # type: (QAction) -> None
+    def msgSelected(self, action: QAction) -> None:
         if self.msgte.text() and self.msgte.isModified():
             d = QMessageBox.question(self, _('Confirm Discard Message'),
                         _('Discard current commit message?'),
@@ -967,20 +948,17 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.setMessage(message)
         self.msgte.setFocus()
 
-    def setMessage(self, msg, modified=False):
-        # type: (Text, bool) -> None
+    def setMessage(self, msg: Text, modified: bool = False) -> None:
         self.msgte.setText(msg)
         self.msgte.moveCursorToEnd()
         self.msgte.setModified(modified)
 
-    def canExit(self):
-        # type: () -> bool
+    def canExit(self) -> bool:
         if not self.stwidget.canExit():
             return False
         return self._cmdsession.isFinished()
 
-    def loadSettings(self, s, prefix):
-        # type: (QSettings, Text) -> None
+    def loadSettings(self, s: QSettings, prefix: Text) -> None:
         'Load history, etc, from QSettings instance'
         repoid = hglib.shortrepoid(self.repo)
         lpref = prefix + '/commit/' # local settings (splitter, etc)
@@ -1006,8 +984,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         except EnvironmentError:
             pass
 
-    def saveSettings(self, s, prefix):
-        # type: (QSettings, Text) -> None
+    def saveSettings(self, s: QSettings, prefix: Text) -> None:
         'Save history, etc, in QSettings instance'
         try:
             repoid = hglib.shortrepoid(self.repo)
@@ -1023,23 +1000,20 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         except (EnvironmentError, IOError):
             pass
 
-    def addMessageToHistory(self, umsg):
-        # type: (Text) -> None
+    def addMessageToHistory(self, umsg: Text) -> None:
         if umsg in self.msghistory:
             self.msghistory.remove(umsg)
         self.msghistory.insert(0, umsg)
         self.msghistory = self.msghistory[:10]
         self.updateRecentMessages()
 
-    def addUsernameToHistory(self, user):
-        # type: (Text) -> None
+    def addUsernameToHistory(self, user: Text) -> None:
         if user in self.userhist:
             self.userhist.remove(user)
         self.userhist.insert(0, user)
         self.userhist = self.userhist[:10]
 
-    def commit(self, amend=False):
-        # type: (bool) -> Optional[bool]
+    def commit(self, amend: bool = False) -> Optional[bool]:
         # TODO: drop the bool return?
         repo = self.repo
         try:
@@ -1241,8 +1215,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
     def stop(self):
         self._cmdsession.abort()
 
-    def _runCommand(self, action, cmdlines):
-        # type: (Text, CmdLines) -> None
+    def _runCommand(self, action: Text, cmdlines: CmdLines) -> None:
         self.currentAction = action
         self.progress.emit(*cmdui.startProgress(_topicmap[action], ''))
         self.commitButtonEnable.emit(False)
@@ -1251,8 +1224,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                                                                      self)
         sess.commandFinished.connect(self.commandFinished)
 
-    def commandFinished(self, ret):
-        # type: (int) -> None
+    def commandFinished(self, ret: int) -> None:
         self.progress.emit(*cmdui.stopProgress(_topicmap[self.currentAction]))
         self.stopAction.setEnabled(False)
         self.commitButtonEnable.emit(True)
@@ -1284,8 +1256,12 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
 class DetailsDialog(QDialog):
     'Utility dialog for configuring uncommon settings'
-    def __init__(self, repoagent, opts, userhistory, parent, mode='commit'):
-        # type: (RepoAgent, CommitOpts, List[Text], QWidget, Text) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 opts: CommitOpts,
+                 userhistory: List[Text],
+                 parent: QWidget,
+                 mode: Text = 'commit') -> None:
         QDialog.__init__(self, parent)
         self.setWindowTitle(_('%s - commit options') % repoagent.displayName())
         self._repoagent = repoagent
@@ -1434,8 +1410,7 @@ class DetailsDialog(QDialog):
         layout.addWidget(bb)
 
     @property
-    def repo(self):
-        # type: () -> localrepo.localrepository
+    def repo(self) -> localrepo.localrepository:
         return self._repoagent.rawRepo()
 
     def saveInRepo(self):
@@ -1445,8 +1420,7 @@ class DetailsDialog(QDialog):
     def saveGlobal(self):
         self.saveToPath(hglib.userrcpath())
 
-    def saveToPath(self, path):
-        # type: (List[bytes]) -> None
+    def saveToPath(self, path: List[bytes]) -> None:
         fn, cfg = hgrcutil.loadIniFile(path, self)
         if not hasattr(cfg, 'write'):
             qtlib.WarningMsgBox(_('Unable to save username'),
@@ -1538,7 +1512,7 @@ class DetailsDialog(QDialog):
                                 hglib.exception_str(e), parent=self)
 
     def accept(self):
-        outopts = {}  # type: Dict[Text, Text]
+        outopts: Dict[Text, Text] = {}
         if self.datecb.isChecked():
             udate = self.datele.text()
             date = hglib.fromunicode(udate)
@@ -1589,8 +1563,11 @@ class DetailsDialog(QDialog):
 class CommitDialog(QDialog):
     'Standalone commit tool, a wrapper for CommitWidget'
 
-    def __init__(self, repoagent, pats, opts, parent=None):
-        # type: (RepoAgent, List[bytes], Dict[Text, bytes], Optional[QObject]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 pats: List[bytes],
+                 opts: Dict[Text, bytes],
+                 parent: Optional[QObject] = None) -> None:
         QDialog.__init__(self, parent)
         self.setWindowFlags(Qt.WindowType.Window)
         self.setWindowIcon(qtlib.geticon('hg-commit'))
@@ -1644,19 +1621,16 @@ class CommitDialog(QDialog):
         self.commit.msgte.setFocus()
         qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Refresh, self, self.refresh)
 
-    def linkActivated(self, link):
-        # type: (Text) -> None
+    def linkActivated(self, link: Text) -> None:
         if link.startswith('repo:'):
             self._subdialogs.open(link[len('repo:'):])
 
-    def _createSubDialog(self, uroot):
-        # type: (Text) -> CommitDialog
+    def _createSubDialog(self, uroot: Text) -> CommitDialog:
         repoagent = self._repoagent.subRepoAgent(uroot)
         return CommitDialog(repoagent, [], {}, parent=self)
 
     @pyqtSlot()
-    def updateUndo(self):
-        # type: () -> None
+    def updateUndo(self) -> None:
         undomsg = self.commit.canUndo()
         if undomsg:
             self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(True)
@@ -1665,13 +1639,11 @@ class CommitDialog(QDialog):
             self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(False)
             self.bb.button(QDialogButtonBox.StandardButton.Discard).setToolTip('')
 
-    def refresh(self):
-        # type: () -> None
+    def refresh(self) -> None:
         self.updateUndo()
         self.commit.reload()
 
-    def postcommit(self):
-        # type: () -> None
+    def postcommit(self) -> None:
         repo = self.commit.stwidget.repo
         if repo.ui.configbool(b'tortoisehg', b'closeci'):
             if self.commit.canExit():
@@ -1680,8 +1652,7 @@ class CommitDialog(QDialog):
                 self.commit.stwidget.refthread.wait()
                 QTimer.singleShot(0, self.reject)
 
-    def promptExit(self):
-        # type: () -> bool
+    def promptExit(self) -> bool:
         exit = self.commit.canExit()
         if not exit:
             exit = qtlib.QuestionMsgBox(_('TortoiseHg Commit'),
@@ -1693,11 +1664,9 @@ class CommitDialog(QDialog):
             self.commit.saveSettings(s, 'committool')
         return exit
 
-    def accept(self):
-        # type: () -> None
+    def accept(self) -> None:
         self.commit.commit()
 
-    def reject(self):
-        # type: () -> None
+    def reject(self) -> None:
         if self.promptExit():
             QDialog.reject(self)
