@@ -5,10 +5,11 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import binascii
 import re
+import sys
 
 from .qtcore import (
     QSize,
@@ -106,7 +107,7 @@ class Factory(object):
         else:
             widget = SummaryLabel(*args)
         if self.withupdate:
-            widget.update()
+            widget.updateItems()
         return widget
 
 class UnknownItem(Exception):
@@ -396,7 +397,22 @@ class SummaryBase(object):
     def set_revision(self, rev):
         self.target = rev
 
-    def update(self, target=None, custom=None, repo=None):
+    # TODO: drop this when all callers are removed, since it hides the update()
+    # method that SummaryPanel and SummaryLabel get through multiple inheritance
+    # from QWidget and QLabel respectively. That update() method seems related
+    # to painting the component, or an area of it.
+    def update(self, *args, **kwargs):  # pytype: disable=signature-mismatch
+        import warnings
+
+        warnings.warn(
+            "SummaryBase.update() should be changed to SummaryBase.updateItems()",
+            DeprecationWarning,
+            2,
+        )
+        sys.stderr.flush()
+        self.updateItems(*args, **kwargs)
+
+    def updateItems(self, target=None, style=None, custom=None, repo=None):
         self.ctx = None
         if target is not None:
             self.target = target
@@ -435,8 +451,8 @@ class SummaryPanel(SummaryBase, QWidget):
         self.revlabel = None
         self.expand_btn = qtlib.PMButton()
 
-    def update(self, target=None, style=None, custom=None, repo=None):
-        SummaryBase.update(self, target, custom, repo)
+    def updateItems(self, target=None, style=None, custom=None, repo=None):
+        SummaryBase.updateItems(self, target, style, custom, repo)
 
         layout = self.layout()
         assert isinstance(layout, QHBoxLayout)
@@ -451,7 +467,7 @@ class SummaryPanel(SummaryBase, QWidget):
 
         if 'expandable' in self.csstyle and self.csstyle['expandable']:
             if self.expand_btn.parentWidget() is None:
-                self.expand_btn.clicked.connect(lambda: self.update())
+                self.expand_btn.clicked.connect(lambda: self.updateItems())
                 margin = QHBoxLayout()
                 margin.setContentsMargins(3, 3, 3, 3)
                 margin.addWidget(self.expand_btn, 0, Qt.AlignmentFlag.AlignTop)
@@ -497,7 +513,7 @@ class SummaryPanel(SummaryBase, QWidget):
 
     def set_expanded(self, state):
         self.expand_btn.set_expanded(state)
-        self.update()
+        self.updateItems()
 
     def is_expanded(self):
         return self.expand_btn.is_expanded()
@@ -516,8 +532,8 @@ class SummaryLabel(SummaryBase, QLabel):
 
         self.csstyle = style
 
-    def update(self, target=None, style=None, custom=None, repo=None):
-        SummaryBase.update(self, target, custom, repo)
+    def updateItems(self, target=None, style=None, custom=None, repo=None):
+        SummaryBase.updateItems(self, target, style, custom, repo)
 
         if style is not None:
             self.csstyle = style
