@@ -6,9 +6,10 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
+import sys
 
 from .qtcore import (
     Qt,
@@ -135,7 +136,7 @@ class ChangesetList(QWidget):
         """
         style = self.compactchk.isChecked() and self.lstyle or self.pstyle
         info = self.curfactory(item, style=style)
-        info.update(item)
+        info.updateItems(item)
         sizePolicy = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -150,7 +151,21 @@ class ChangesetList(QWidget):
             text = _('Displaying %(count)d of %(total)d items') % num
         self.statuslabel.setText(text)
 
-    def update(self, items, uselimit=True):
+    # TODO: drop this when all callers are removed, since it hides update() in
+    #  the superclass, which seems related to painting the component, or an area
+    #  of it.
+    def update(self, items, uselimit=True):  # pytype: disable=signature-mismatch
+        import warnings
+
+        warnings.warn(
+            "ChangesetList.update() should be changed to ChangesetList.updateItems()",
+            DeprecationWarning,
+            2,
+        )
+        sys.stderr.flush()
+        self.updateItems(items, uselimit=uselimit)
+
+    def updateItems(self, items, uselimit=True):
         """Update the item list.
 
         Public arguments:
@@ -195,4 +210,4 @@ class ChangesetList(QWidget):
 
     @pyqtSlot()
     def _updateView(self):
-        self.update(self.curitems)
+        self.updateItems(self.curitems)
