@@ -7,7 +7,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import re
@@ -221,8 +221,7 @@ class FilectxActions(QObject):
         # override to add actions that cannot be declared as actionSlot
         pass
 
-    def _parentWidget(self):
-        # type: () -> QWidget
+    def _parentWidget(self) -> QWidget:
         p = self.parent()
         assert isinstance(p, QWidget)
         return p
@@ -756,12 +755,12 @@ class WctxActions(FilectxActions):
         self._runWorkingFileCommand('revert', fds, revertopts)
 
     @actionSlot(_('&Copy...'), 'edit-copy', None, '',
-                (_single, _isfile, _filestatus('MC')))
+                (_single, _isfile, _filestatus('MAC')))
     def copyFile(self, fds: List["FileData"]) -> None:
         self._openRenameDialog(fds, iscopy=True)
 
     @actionSlot(_('Re&name...'), 'hg-rename', None, '',
-                (_single, _isfile, _filestatus('MC')))
+                (_single, _isfile, _filestatus('MAC')))
     def renameFile(self, fds: List["FileData"]) -> None:
         self._openRenameDialog(fds, iscopy=False)
 
