@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 import os, posixpath
 
 from typing import (
@@ -674,9 +676,8 @@ class SubrepoData(_AbstractFileData):
         self.flabel = u'<b>%s</b>' % self.filePath()
 
         try:
-            def genSubrepoRevChangedDescription(subrelpath, sfrom, sto,
-                                                repo):
-                # type: (bytes, Text, Text, localrepo.localrepository) -> Tuple[List[Text], Text]
+            def genSubrepoRevChangedDescription(subrelpath: bytes, sfrom: Text, sto: Text,
+                                                repo: localrepo.localrepository) -> Tuple[List[Text], Text]:
                 """Generate a subrepository revision change description"""
                 out = []
                 def getLog(_ui, srepo, opts):
