@@ -17,7 +17,7 @@
 Qt4 dialogs to display hg revisions of a file
 """
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import difflib
 
@@ -174,7 +174,7 @@ class _AbstractFileDialog(QMainWindow):
         self.setupUi()
         self._show_rev = None
 
-        assert not isinstance(filename, pycompat.unicode), repr(filename)
+        assert not isinstance(filename, str), repr(filename)
         self.filename = filename
 
         self.setWindowTitle(_('Hg file log viewer [%s] - %s')
@@ -375,8 +375,7 @@ class FileLogDialog(_AbstractFileDialog):
         self.revdetails.raise_()
 
     @pyqtSlot(str)
-    def onLinkActivated(self, link):
-        link = pycompat.unicode(link)
+    def onLinkActivated(self, link: str):
         if ':' in link:
             scheme, param = link.split(':', 1)
             if scheme == 'cset':
@@ -390,7 +389,7 @@ class FileLogDialog(_AbstractFileDialog):
         self.textView.display(fd)
         self.textView.verticalScrollBar().setValue(pos)
         self.revpanel.set_revision(rev)
-        self.revpanel.update(repo = self.repo)
+        self.revpanel.updateItems(repo = self.repo)
 
     @pyqtSlot()
     def _onRevisionSelectionChanged(self):
@@ -432,6 +431,9 @@ class FileDiffDialog(_AbstractFileDialog):
     """
     Qt4 dialog to display diffs between different mercurial revisions of a file.
     """
+
+    filedata: Dict[Text, List[str]]
+
     def __init__(self, repoagent, filename):
         super(FileDiffDialog, self).__init__(repoagent, filename)
         self._readSettings()
@@ -521,9 +523,10 @@ class FileDiffDialog(_AbstractFileDialog):
             sci.setMarginLineNumbers(1, True)
             sci.SendScintilla(sci.SCI_SETSELEOLFILLED, True)
 
+            font = qtlib.getfont('fontdiff').font()
+            sci.setFont(font)
             sci.setLexer(lexer)
-            if lexer is None:
-                sci.setFont(qtlib.getfont('fontdiff').font())
+            sci.setFont(font)
 
             sci.setReadOnly(True)
             sci.setUtf8(True)
@@ -590,7 +593,7 @@ class FileDiffDialog(_AbstractFileDialog):
         self.timer.timeout.connect(self.idle_fill_files)
 
     def setupModels(self):
-        self.filedata = {'left': [], 'right': []}  # type: Dict[Text, List[pycompat.unicode]]
+        self.filedata = {'left': [], 'right': []}
         self._invbarchanged = False
         self.filerevmodel = repomodel.FileRevModel(
             self._repoagent, self.filename, parent=self)
