@@ -14,7 +14,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     QModelIndex,
@@ -52,8 +52,7 @@ class HgFileListView(QTreeView):
     fileSelected = pyqtSignal(str, str)
     clearDisplay = pyqtSignal()
 
-    def __init__(self, parent):
-        # type: (Optional[QWidget]) -> None
+    def __init__(self, parent: Optional[QWidget]) -> None:
         QTreeView.__init__(self, parent)
         self.setHeaderHidden(True)
         self.setDragDropMode(QAbstractItemView.DragDropMode.DragOnly)
@@ -65,40 +64,34 @@ class HgFileListView(QTreeView):
         self.setIconSize(qtlib.smallIconSize())
         self.setUniformRowHeights(True)
 
-    def _model(self):
-        # type: () -> manifestmodel.ManifestModel
+    def _model(self) -> manifestmodel.ManifestModel:
         model = self.model()
         assert isinstance(model, manifestmodel.ManifestModel)
         return model
 
-    def setModel(self, model):
-        # type: (QAbstractItemModel) -> None
+    def setModel(self, model: QAbstractItemModel) -> None:
         assert isinstance(model, manifestmodel.ManifestModel)
         QTreeView.setModel(self, model)
         model.layoutChanged.connect(self._onLayoutChanged)
         model.revLoaded.connect(self._onRevLoaded)
         self.selectionModel().currentRowChanged.connect(self._emitFileChanged)
 
-    def currentFile(self):
-        # type: () -> bytes
+    def currentFile(self) -> bytes:
         index = self.currentIndex()
         model = self._model()
         return hglib.fromunicode(model.filePath(index))
 
-    def setCurrentFile(self, path):
-        # type: (bytes) -> None
+    def setCurrentFile(self, path: bytes) -> None:
         model = self._model()
         model.fetchMore(QModelIndex())  # make sure path is populated
         self.setCurrentIndex(model.indexFromPath(hglib.tounicode(path)))
 
-    def getSelectedFiles(self):
-        # type: () -> List[bytes]
+    def getSelectedFiles(self) -> List[bytes]:
         model = self._model()
         return [hglib.fromunicode(model.filePath(index))
                 for index in self.selectedRows()]
 
-    def _initCurrentIndex(self):
-        # type: () -> None
+    def _initCurrentIndex(self) -> None:
         m = self._model()
         if m.rowCount() > 0:
             self.setCurrentIndex(m.index(0, 0))
@@ -106,8 +99,7 @@ class HgFileListView(QTreeView):
             self.clearDisplay.emit()
 
     @pyqtSlot()
-    def _onLayoutChanged(self):
-        # type: () -> None
+    def _onLayoutChanged(self) -> None:
         index = self.currentIndex()
         if index.isValid():
             self.scrollTo(index)
@@ -115,8 +107,7 @@ class HgFileListView(QTreeView):
         self._initCurrentIndex()
 
     @pyqtSlot()
-    def _onRevLoaded(self):
-        # type: () -> None
+    def _onRevLoaded(self) -> None:
         index = self.currentIndex()
         if index.isValid():
             # redisplay previous row
@@ -125,8 +116,7 @@ class HgFileListView(QTreeView):
             self._initCurrentIndex()
 
     @pyqtSlot()
-    def _emitFileChanged(self):
-        # type: () -> None
+    def _emitFileChanged(self) -> None:
         index = self.currentIndex()
         m = self._model()
         if index.isValid():
@@ -137,6 +127,5 @@ class HgFileListView(QTreeView):
         else:
             self.clearDisplay.emit()
 
-    def selectedRows(self):
-        # type: () -> List[QModelIndex]
+    def selectedRows(self) -> List[QModelIndex]:
         return self.selectionModel().selectedRows()
