@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import difflib
 import os
@@ -722,8 +722,7 @@ class _AbstractViewControl(QObject):
     def setupContextMenu(self, menu, line):
         pass
 
-    def _parentWidget(self):
-        # type: () -> Optional[QWidget]
+    def _parentWidget(self) -> Optional[QWidget]:
         p = self.parent()
         assert p is None or isinstance(p, QWidget)
         return p
@@ -842,9 +841,12 @@ class _FileViewControl(_AbstractViewControl):
         if fd.contents:
             filename = fd.filePath()
             lexer = lexers.getlexer(self._ui, filename, fd.contents, self)
+            newFont = qtlib.getfont('fontlog').font()
+
+            self._sci.setFont(newFont)
             self._sci.setLexer(lexer)
-            if lexer is None:
-                self._sci.setFont(qtlib.getfont('fontlog').font())
+            self._sci.setFont(newFont)
+
             self._sci.setText(fd.fileText())
 
         self._sci.setMarginsFont(self._sci.font())
@@ -924,8 +926,8 @@ class _MessageViewControl(_AbstractViewControl):
         self._forceviewindicator = None
 
     def open(self):
-        self._sci.setLexer(None)
         self._sci.setFont(qtlib.getfont('fontlog').font())
+        self._sci.setLexer(None)
 
     def close(self):
         pass
