@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     QSettings,
@@ -37,7 +37,6 @@ from . import (
 
 if hglib.TYPE_CHECKING:
     from typing import (
-        Any,
         List,
         Optional,
         Text,
@@ -54,8 +53,10 @@ BB = QDialogButtonBox
 
 class GraftDialog(QDialog):
 
-    def __init__(self, repoagent, parent, **opts):
-        # type: (RepoAgent, Optional[QWidget], Any) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 parent: Optional[QWidget],
+                 **opts) -> None:
         super(GraftDialog, self).__init__(parent)
         self.setWindowIcon(qtlib.geticon('hg-transplant'))
         self.setWindowFlags(self.windowFlags()
@@ -165,8 +166,7 @@ class GraftDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def _readSettings(self):
-        # type: () -> None
+    def _readSettings(self) -> None:
         qs = QSettings()
         qs.beginGroup('graft')
         for n, w in self._optchks.items():
@@ -178,16 +178,14 @@ class GraftDialog(QDialog):
                 w.setChecked(qtlib.readBool(qs, n))
         qs.endGroup()
 
-    def _writeSettings(self):
-        # type: () -> None
+    def _writeSettings(self) -> None:
         qs = QSettings()
         qs.beginGroup('graft')
         for n, w in self._optchks.items():
             qs.setValue(n, w.isChecked())
         qs.endGroup()
 
-    def _updateSourceTitle(self, idx):
-        # type: (int) -> None
+    def _updateSourceTitle(self, idx: int) -> None:
         numrevs = len(self.sourcelist)
         if numrevs <= 1:
             title = _('Graft changeset')
@@ -195,14 +193,12 @@ class GraftDialog(QDialog):
             title = _('Graft changeset #%d of %d') % (idx + 1, numrevs)
         self.srcb.setTitle(title)
 
-    def _updateSource(self, idx):
-        # type: (int) -> None
+    def _updateSource(self, idx: int) -> None:
         self._updateSourceTitle(idx)
-        self.cslist.update(self.sourcelist[idx:])
+        self.cslist.updateItems(self.sourcelist[idx:])
 
     @pyqtSlot(bool)
-    def _onCheckFinished(self, clean):
-        # type: (bool) -> None
+    def _onCheckFinished(self, clean: bool) -> None:
         if not clean:
             self.graftbtn.setEnabled(False)
             txt = _('Before graft, you must '
@@ -214,8 +210,7 @@ class GraftDialog(QDialog):
             txt = _('You may continue or start the graft')
         self._stbar.showMessage(txt)
 
-    def graft(self):
-        # type: () -> None
+    def graft(self) -> None:
         self.graftbtn.setEnabled(False)
         self.cancelbtn.setVisible(False)
         opts = dict((n, w.isChecked()) for n, w in self._optchks.items())
@@ -230,19 +225,16 @@ class GraftDialog(QDialog):
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._graftFinished)
 
-    def abort(self):
-        # type: () -> None
+    def abort(self) -> None:
         self.abortbtn.setDisabled(True)
         cmdline = hglib.buildcmdargs('graft', abort=True)
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._abortFinished)
 
-    def graftstate(self):
-        # type: () -> Optional[List[bytes]]
+    def graftstate(self) -> Optional[List[bytes]]:
         return hglib.readgraftstate(self.repo)
 
-    def _runCommand(self, cmdline):
-        # type: (List[Text]) -> cmdcore.CmdSession
+    def _runCommand(self, cmdline: List[Text]) -> cmdcore.CmdSession:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self._stbar.clearProgress)
@@ -252,8 +244,7 @@ class GraftDialog(QDialog):
         return sess
 
     @pyqtSlot(int)
-    def _graftFinished(self, ret):
-        # type: (int) -> None
+    def _graftFinished(self, ret: int) -> None:
         if self.checkResolve() is False:
             msg = _('Graft is complete')
             if ret == 255:
@@ -265,21 +256,18 @@ class GraftDialog(QDialog):
             self._makeCloseButton()
 
     @pyqtSlot()
-    def _abortFinished(self):
-        # type: () -> None
+    def _abortFinished(self) -> None:
         if self.checkResolve() is False:
             self._stbar.showMessage(_('Graft aborted'))
             self._makeCloseButton()
 
-    def _makeCloseButton(self):
-        # type: () -> None
+    def _makeCloseButton(self) -> None:
         self.graftbtn.setEnabled(True)
         self.graftbtn.setText(_('Close'))
         self.graftbtn.clicked.disconnect(self.graft)
         self.graftbtn.clicked.connect(self.accept)
 
-    def checkResolve(self):
-        # type: () -> bool
+    def checkResolve(self) -> bool:
         for root, path, status in thgrepo.recursiveMergeStatus(self.repo):
             if status == b'u':
                 txt = _('Graft generated merge <b>conflicts</b> that must '
@@ -310,8 +298,7 @@ class GraftDialog(QDialog):
             self.abortbtn.setEnabled(False)
             return False
 
-    def linkActivated(self, cmd):
-        # type: (Text) -> None
+    def linkActivated(self, cmd: Text) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -319,8 +306,7 @@ class GraftDialog(QDialog):
         else:
             self._wctxcleaner.runCleaner(cmd)
 
-    def reject(self):
-        # type: () -> None
+    def reject(self) -> None:
         if self._wctxcleaner.isChecking():
             return
         if hglib.graft_in_progress(self.repo):
@@ -333,7 +319,6 @@ class GraftDialog(QDialog):
                 return
         super(GraftDialog, self).reject()
 
-    def done(self, r):
-        # type: (int) -> None
+    def done(self, r: int) -> None:
         self._writeSettings()
         super(GraftDialog, self).done(r)
