@@ -18,13 +18,20 @@ of Graph instances that describe a revision set graph. These generators
 are used by repomodel.py which renders them on a widget.
 """
 
-
+from __future__ import annotations
 
 import collections
 import os
 import time
+import typing
 
 from mercurial.thirdparty import attr
+
+# Force pytype to use the non-vendored package
+if typing.TYPE_CHECKING:
+    # noinspection PyPackageRequirements
+    import attr
+
 from mercurial import (
     error,
     hg,
