@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -49,8 +49,11 @@ if hglib.TYPE_CHECKING:
 
 class InitWidget(cmdui.AbstractCmdWidget):
 
-    def __init__(self, ui, cmdagent, destdir='.', parent=None):
-        # type: (uimod.ui, cmdcore.CmdAgent, Text, Optional[QWidget]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 cmdagent: cmdcore.CmdAgent,
+                 destdir: Text = '.',
+                 parent: Optional[QWidget] = None) -> None:
         super(InitWidget, self).__init__(parent)
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._cmdagent = cmdagent
@@ -102,20 +105,17 @@ class InitWidget(cmdui.AbstractCmdWidget):
         self._make_pre_1_7_chk.toggled.connect(self._composeCommand)
 
     @pyqtSlot()
-    def _browseDestination(self):
-        # type: () -> None
+    def _browseDestination(self) -> None:
         """Select the destination directory"""
         caption = _('Select Destination Folder')
         path = QFileDialog.getExistingDirectory(self, caption)
         if path:
             self._dest_edit.setText(path)
 
-    def destination(self):
-        # type: () -> Text
+    def destination(self) -> Text:
         return self._dest_edit.text().strip()
 
-    def _buildCommand(self):
-        # type: () -> List[Text]
+    def _buildCommand(self) -> List[Text]:
         cfgs = []
         if self._add_files_chk.isChecked():
             cfgs.append('hooks.post-init.thgskel='
@@ -125,18 +125,15 @@ class InitWidget(cmdui.AbstractCmdWidget):
         return hglib.buildcmdargs('init', self.destination(), config=cfgs)
 
     @pyqtSlot()
-    def _composeCommand(self):
-        # type: () -> None
+    def _composeCommand(self) -> None:
         cmdline = self._buildCommand()
         self._hgcmd_txt.setText('hg ' + hglib.prettifycmdline(cmdline))
         self.commandChanged.emit()
 
-    def canRunCommand(self):
-        # type: () -> bool
+    def canRunCommand(self) -> bool:
         return bool(self.destination())
 
-    def runCommand(self):
-        # type: () -> cmdcore.CmdSession
+    def runCommand(self) -> cmdcore.CmdSession:
         cmdline = self._buildCommand()
         return self._cmdagent.runCommand(cmdline, self)
 
@@ -145,8 +142,10 @@ class InitDialog(cmdui.CmdControlDialog):
 
     newRepository = pyqtSignal(str)
 
-    def __init__(self, ui, destdir='.', parent=None):
-        # type: (uimod.ui, Text, Optional[QWidget]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 destdir: Text = '.',
+                 parent: Optional[QWidget] = None) -> None:
         super(InitDialog, self).__init__(parent)
         self.setWindowTitle(_('New Repository'))
         self.setWindowIcon(qtlib.geticon('hg-init'))
@@ -157,19 +156,16 @@ class InitDialog(cmdui.CmdControlDialog):
         self.setCommandWidget(InitWidget(ui, cmdagent, destdir, self))
         self.commandFinished.connect(self._handleNewRepo)
 
-    def destination(self):
-        # type: () -> Text
+    def destination(self) -> Text:
         return self.commandWidget().destination()
 
     @pyqtSlot(int)
-    def _handleNewRepo(self, ret):
-        # type: (int) -> None
+    def _handleNewRepo(self, ret: int) -> None:
         if ret != 0:
             return
         self.newRepository.emit(self.destination())
 
-    def done(self, r):
-        # type: (int) -> None
+    def done(self, r: int) -> None:
         if self._cmdagent.isServiceRunning():
             self._cmdagent.stopService()
             return  # postponed until serviceStopped
