@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 import os
 
 from mercurial import error, match
@@ -27,8 +29,8 @@ if hglib.TYPE_CHECKING:
     )
 
 
-def _createPrompt(parent, files):
-    # type: (Optional[QWidget], List[bytes]) -> qtlib.CustomPrompt
+def _createPrompt(parent: Optional[QWidget],
+                  files: List[bytes]) -> qtlib.CustomPrompt:
     return qtlib.CustomPrompt(
         _('Confirm Add'),
         _('Some of the files that you have selected are of a size '
@@ -40,8 +42,10 @@ def _createPrompt(parent, files):
         (_('Add as &Largefiles'), _('Add as &Normal Files'), _('Cancel')),
         0, 2, files)
 
-def promptForLfiles(parent, ui, repo, files):
-    # type: (Optional[QWidget], uimod.ui, localrepo.localrepository, List[bytes]) -> Optional[Tuple[List[bytes], List[bytes]]]
+def promptForLfiles(parent: Optional[QWidget],
+                    ui: uimod.ui,
+                    repo: localrepo.localrepository,
+                    files: List[bytes]) -> Optional[Tuple[List[bytes], List[bytes]]]:
     lfiles = []
     section = b'largefiles'
     try:
