@@ -8,7 +8,7 @@
 # Foundation; either version 2 of the License, or (at your option) any later
 # version.
 
-
+from __future__ import annotations
 
 import os
 import re
@@ -98,9 +98,8 @@ class ManifestModel(QAbstractItemModel):
     FirstParent = -2
     SecondParent = -3
 
-    def __init__(self, repoagent, parent=None, rev=None, namefilter=None,
-                 statusfilter='MASC', flat=False):
-        # type: (RepoAgent, Optional[QObject], Optional[int], Optional[Text], Text, bool) -> None
+    def __init__(self, repoagent: RepoAgent, parent: Optional[QObject] = None, rev: Optional[int] = None, namefilter: Optional[Text] = None,
+                 statusfilter: Text = 'MASC', flat: bool = False) -> None:
         QAbstractItemModel.__init__(self, parent)
 
         self._fileiconprovider = QFileIconProvider()
@@ -117,8 +116,9 @@ class ManifestModel(QAbstractItemModel):
         self._populate = _populaterepo
         self._rootpopulated = False
 
-    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
-        # type: (QModelIndex, Qt.ItemDataRole) -> Any
+    def data(self,
+             index: QModelIndex,
+             role: Qt.ItemDataRole = Qt.ItemDataRole.DisplayRole) -> Any:
         if not index.isValid():
             return
 
@@ -127,12 +127,11 @@ class ManifestModel(QAbstractItemModel):
         if role == self.StatusRole:
             return self.fileStatus(index)
 
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         if role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             return e.name
 
-    def filePath(self, index):
-        # type: (QModelIndex) -> Text
+    def filePath(self, index: QModelIndex) -> Text:
         """Return path at the given index [unicode]"""
         if not index.isValid():
             return ''
@@ -145,7 +144,7 @@ class ManifestModel(QAbstractItemModel):
         if not index.isValid():
             return filedata.createNullData(repo)
 
-        f = index.internalPointer()  # type: "_Entry"
+        f: "_Entry" = index.internalPointer()
         e = f.parent
         while e and e.ctx is None:
             e = e.parent
@@ -160,19 +159,17 @@ class ManifestModel(QAbstractItemModel):
             return filedata.createDirData(e.ctx, e.pctx, wfile, rpath)
         return filedata.createFileData(e.ctx, e.pctx, wfile, f.status, rpath)
 
-    def subrepoType(self, index):
-        # type: (QModelIndex) -> Optional[Text]
+    def subrepoType(self, index: QModelIndex) -> Optional[Text]:
         """Return the subrepo type the specified index"""
         if not index.isValid():
             return
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         return e.subkind
 
-    def fileIcon(self, index):
-        # type: (QModelIndex) -> QIcon
+    def fileIcon(self, index: QModelIndex) -> QIcon:
         if not index.isValid():
             return QIcon()
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         k = (e.path, e.status, e.subkind)
         try:
             return self._iconcache[k]
@@ -180,9 +177,9 @@ class ManifestModel(QAbstractItemModel):
             self._iconcache[k] = ic = self._makeFileIcon(e)
             return ic
 
-    def _makeFileIcon(self, e):
-        # type: ("_Entry") -> QIcon
+    def _makeFileIcon(self, e: "_Entry") -> QIcon:
         if e.subkind in _subrepoType2IcoMap:
+            assert e.subkind is not None
             ic = qtlib.geticon(_subrepoType2IcoMap[e.subkind])
             # use fine-tuned status overlay if any
             n = _subrepoStatus2IcoMap.get(e.status)
@@ -206,37 +203,33 @@ class ManifestModel(QAbstractItemModel):
 
         return ic
 
-    def fileStatus(self, index):
-        # type: (QModelIndex) -> Optional[Text]
+    def fileStatus(self, index: QModelIndex) -> Optional[Text]:
         """Return the change status of the specified file"""
         if not index.isValid():
             return
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         # TODO: 'S' should not be a status
         if e.subkind:
             return 'S'
         return e.status
 
     # TODO: this should be merged to fileStatus()
-    def subrepoStatus(self, index):
-        # type: (QModelIndex) -> Optional[Text]
+    def subrepoStatus(self, index: QModelIndex) -> Optional[Text]:
         """Return the change status of the specified subrepo"""
         if not index.isValid():
             return
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         if not e.subkind:
             return
         return e.status
 
-    def isDir(self, index):
-        # type: (QModelIndex) -> bool
+    def isDir(self, index: QModelIndex) -> bool:
         if not index.isValid():
             return True  # root entry must be a directory
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         return e.isdir
 
-    def mimeData(self, indexes):
-        # type: (Iterable[QModelIndex]) -> QMimeData
+    def mimeData(self, indexes: Iterable[QModelIndex]) -> QMimeData:
         files = [self.filePath(i) for i in indexes if i.isValid()]
         ctx = self._rootentry.ctx
         if ctx.rev() is not None:
@@ -252,12 +245,10 @@ class ManifestModel(QAbstractItemModel):
         m.setUrls([QUrl.fromLocalFile(os.path.join(base, e)) for e in files])
         return m
 
-    def mimeTypes(self):
-        # type: () -> List[Text]
+    def mimeTypes(self) -> List[Text]:
         return ['text/uri-list']
 
-    def flags(self, index):
-        # type: (QModelIndex) -> Qt_ItemFlags
+    def flags(self, index: QModelIndex) -> Qt_ItemFlags:
         f = super(ManifestModel, self).flags(index)
         if not index.isValid():
             return f
@@ -266,14 +257,15 @@ class ManifestModel(QAbstractItemModel):
             f |= Qt.ItemFlag.ItemIsDragEnabled
         return f
 
-    def index(self, row, column, parent=QModelIndex()):
-        # type: (int, int, QModelIndex) -> QModelIndex
+    def index(self,
+              row: int,
+              column: int,
+              parent: QModelIndex = QModelIndex()) -> QModelIndex:
         if row < 0 or self.rowCount(parent) <= row or column != 0:
             return QModelIndex()
         return self.createIndex(row, column, self._parententry(parent).at(row))
 
-    def indexFromPath(self, path, column=0):
-        # type: (Text, int) -> QModelIndex
+    def indexFromPath(self, path: Text, column: int = 0) -> QModelIndex:
         """Return index for the specified path if found [unicode]
 
         If not found, returns invalid index.
@@ -288,42 +280,36 @@ class ManifestModel(QAbstractItemModel):
 
         return self.createIndex(e.parent.index(e.name), column, e)
 
-    def parent(self, index):
-        # type: (QModelIndex) -> QModelIndex
+    def parent(self, index: QModelIndex) -> QModelIndex:
         if not index.isValid():
             return QModelIndex()
 
-        e = index.internalPointer()  # type: "_Entry"
+        e: "_Entry" = index.internalPointer()
         if e.path:
             return self.indexFromPath(e.parent.path, index.column())
         else:
             return QModelIndex()
 
-    def _parententry(self, parent):
-        # type: (QModelIndex) -> "_Entry"
+    def _parententry(self, parent: QModelIndex) -> "_Entry":
         if parent.isValid():
             return parent.internalPointer()
         else:
             return self._rootentry
 
-    def rowCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def rowCount(self, parent: QModelIndex = QModelIndex()) -> int:
         return len(self._parententry(parent))
 
-    def columnCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def columnCount(self, parent: QModelIndex = QModelIndex()) -> int:
         return 1
 
-    def rev(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> Optional[int]
+    def rev(self, parent: QModelIndex = QModelIndex()) -> Optional[int]:
         """Revision number of the current changectx"""
         e = self._parententry(parent)
         if e.ctx is None or not _isreporev(e.ctx.rev()):
             return -1
         return e.ctx.rev()
 
-    def baseRev(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def baseRev(self, parent: QModelIndex = QModelIndex()) -> int:
         """Revision of the base changectx where status is calculated from"""
         e = self._parententry(parent)
         if e.pctx is None or not _isreporev(e.pctx.rev()):
@@ -332,11 +318,16 @@ class ManifestModel(QAbstractItemModel):
         assert rev is not None  # help pytype
         return rev
 
-    def setRev(self, rev, prev=FirstParent):
-        # type: (Optional[int], int) -> None
+    def setRev(self, rev: Optional[int], prev: int = FirstParent) -> None:
         """Change to the specified repository revision; None for working-dir"""
         roote = self._rootentry
         newroote = self._newRevNode(rev, prev)
+
+        # Help pytype- .ctx is always initialized by _newRevNode(), which is
+        # also how _rootentry is created.
+        assert roote.ctx is not None
+        assert newroote.ctx is not None
+
         if (_samectx(newroote.ctx, roote.ctx)
             and _samectx(newroote.pctx, roote.pctx)):
             return
@@ -345,8 +336,7 @@ class ManifestModel(QAbstractItemModel):
         if self._rootpopulated:
             self.revLoaded.emit(self.rev())
 
-    def setRawContext(self, ctx):
-        # type: (ThgContext) -> None
+    def setRawContext(self, ctx: ThgContext) -> None:
         """Change to the specified changectx in place of repository revision"""
         if _samectx(self._rootentry.ctx, ctx):
             return
@@ -364,29 +354,25 @@ class ManifestModel(QAbstractItemModel):
         if self._rootpopulated:
             self.revLoaded.emit(self.rev())
 
-    def nameFilter(self):
-        # type: () -> Text
+    def nameFilter(self) -> Text:
         """Return the current name filter"""
         return self._namefilter
 
     @pyqtSlot(str)
-    def setNameFilter(self, pattern):
-        # type: (Text) -> None
+    def setNameFilter(self, pattern: Text) -> None:
         """Filter file name by partial match of glob pattern"""
         if self._namefilter == pattern:
             return
         self._namefilter = pattern
         self._repopulateNodes()
 
-    def statusFilter(self):
-        # type: () -> Text
+    def statusFilter(self) -> Text:
         """Return the current status filter"""
         return self._statusfilter
 
     # TODO: split or remove 'S' which causes several design flaws
     @pyqtSlot(str)
-    def setStatusFilter(self, status):
-        # type: (Text) -> None
+    def setStatusFilter(self, status: Text) -> None:
         """Filter file tree by change status 'MARSC'"""
         assert all(c in 'MARSC' for c in status), repr(status)
         if self._statusfilter == status:
@@ -394,8 +380,7 @@ class ManifestModel(QAbstractItemModel):
         self._statusfilter = status
         self._repopulateNodes()
 
-    def isChangedFilesOnly(self):
-        # type: () -> bool
+    def isChangedFilesOnly(self) -> bool:
         """Whether or not to filter by ctx.files, i.e. to exclude files not
         changed in the current revision.
 
@@ -404,34 +389,29 @@ class ManifestModel(QAbstractItemModel):
         """
         return self._changedfilesonly
 
-    def setChangedFilesOnly(self, changedonly):
-        # type: (bool) -> None
+    def setChangedFilesOnly(self, changedonly: bool) -> None:
         if self._changedfilesonly == bool(changedonly):
             return
         self._changedfilesonly = bool(changedonly)
         self._repopulateNodes()
 
-    def isFlat(self):
-        # type: () -> bool
+    def isFlat(self) -> bool:
         """Whether all entries are listed in the same level or per directory"""
         return self._nodeop is _listnodeop
 
-    def setFlat(self, flat):
-        # type: (bool) -> None
+    def setFlat(self, flat: bool) -> None:
         if self.isFlat() == bool(flat):
             return
         # self._nodeop must be changed after layoutAboutToBeChanged; otherwise
         # client code may obtain invalid indexes in its slot
         self._repopulateNodes(newnodeop=_nodeopmap[bool(flat)])
 
-    def canFetchMore(self, parent):
-        # type: (QModelIndex) -> bool
+    def canFetchMore(self, parent: QModelIndex) -> bool:
         if parent.isValid():
             return False
         return not self._rootpopulated
 
-    def fetchMore(self, parent):
-        # type: (QModelIndex) -> None
+    def fetchMore(self, parent: QModelIndex) -> None:
         if parent.isValid() or self._rootpopulated:
             return
         assert len(self._rootentry) == 0, self._rootentry
@@ -446,8 +426,9 @@ class ManifestModel(QAbstractItemModel):
             self.endInsertRows()
         self.revLoaded.emit(self.rev())
 
-    def _repopulateNodes(self, newnodeop=None, newroote=None):
-        # type: (Optional[Any], Optional["_Entry"]) -> None
+    def _repopulateNodes(self,
+                         newnodeop: Optional[Any] = None,
+                         newroote: Optional["_Entry"] = None) -> None:
         """Recreate populated nodes if any"""
         if not self._rootpopulated:
             # no stale nodes
@@ -472,8 +453,9 @@ class ManifestModel(QAbstractItemModel):
         finally:
             self.layoutChanged.emit()
 
-    def _newRevNode(self, rev, prev=FirstParent):
-        # type: (Optional[int], int) -> "_Entry"
+    def _newRevNode(self,
+                    rev: Optional[int],
+                    prev: int = FirstParent) -> "_Entry":
         """Create empty root node for the specified revision"""
         if not _isreporev(rev):
             raise ValueError('unacceptable revision number: %r' % rev)
@@ -490,10 +472,12 @@ class ManifestModel(QAbstractItemModel):
             roote.pctx = repo[prev]
         return roote
 
-    def _populateNodes(self, roote):
-        # type: ("_Entry") -> None
+    def _populateNodes(self, roote: "_Entry") -> None:
         repo = self._repoagent.rawRepo()
         lpat = hglib.fromunicode(self._namefilter)
+
+        assert roote.ctx is not None
+
         match = _makematcher(repo, roote.ctx, lpat, self._changedfilesonly)
         self._populate(roote, repo, self._nodeop, self._statusfilter, match)
         roote.sort()
@@ -505,23 +489,28 @@ class _Entry(object):
     __slots__ = ('_name', '_parent', 'status', 'ctx', 'pctx', 'subkind',
                  '_child', '_nameindex')
 
-    def __init__(self, name='', parent=None):
-        # type: (Text, Optional["_Entry"]) -> None
+    _name: Text
+    _parent: Optional["_Entry"]
+    status: Optional[Text]
+    ctx: Optional[ThgContext]
+    pctx: Optional[ThgContext]
+    subkind: Optional[Text]
+    _child: Dict[Text, "_Entry"]
+    _nameindex: List[Text]
+
+    def __init__(self,
+                 name: Text = '',
+                 parent: Optional["_Entry"] = None) -> None:
         self._name = name
         self._parent = parent
-        self.status = None  # type: Optional[Text]
-        # TODO: check this with newer pytype versions periodically.  It was fine
-        #       when it was `Optional[context.basectx]`.
-        # pytype: disable=not-supported-yet
-        self.ctx = None  # type: Optional[ThgContext]
-        self.pctx = None  # type: Optional[ThgContext]
-        # pytype: enable=not-supported-yet
-        self.subkind = None  # type: Optional[Text]
-        self._child = {}  # type: Dict[Text, "_Entry"]
-        self._nameindex = []  # type: List[Text]
+        self.status = None
+        self.ctx = None
+        self.pctx = None
+        self.subkind = None
+        self._child = {}
+        self._nameindex = []
 
-    def copyskel(self):
-        # type: () -> "_Entry"
+    def copyskel(self) -> "_Entry":
         """Create unpopulated copy of this entry"""
         e = self.__class__()
         e.status = self.status
@@ -531,52 +520,43 @@ class _Entry(object):
         return e
 
     @property
-    def parent(self):
-        # type: () -> Optional["_Entry"]
+    def parent(self) -> Optional["_Entry"]:
         return self._parent
 
     @property
-    def path(self):
-        # type: () -> Text
+    def path(self) -> Text:
         if self.parent is None or not self.parent.name:
             return self.name
         else:
             return self.parent.path + '/' + self.name
 
     @property
-    def name(self):
-        # type: () -> Text
+    def name(self) -> Text:
         return self._name
 
     @property
-    def isdir(self):
-        # type: () -> bool
+    def isdir(self) -> bool:
         return bool(self.subkind or self._child)
 
-    def __len__(self):
-        # type: () -> int
+    def __len__(self) -> int:
         return len(self._child)
 
-    def __nonzero__(self):
-        # type: () -> bool
+    def __nonzero__(self) -> bool:
         # leaf node should not be False because of len(node) == 0
         return True
 
     __bool__ = __nonzero__
 
-    def __getitem__(self, name):
-        # type: (Text) -> "_Entry"
+    def __getitem__(self, name: Text) -> "_Entry":
         return self._child[name]
 
-    def makechild(self, name):
-        # type: (Text) -> "_Entry"
+    def makechild(self, name: Text) -> "_Entry":
         if name not in self._child:
             self._nameindex.append(name)
         self._child[name] = e = self.__class__(name, parent=self)
         return e
 
-    def putchild(self, name, e):
-        # type: (Text, "_Entry") -> None
+    def putchild(self, name: Text, e: "_Entry") -> None:
         assert not e.name and not e.parent, (e.name, e.parent)
         e._name = name
         e._parent = self
@@ -584,20 +564,16 @@ class _Entry(object):
             self._nameindex.append(name)
         self._child[name] = e
 
-    def __contains__(self, item):
-        # type: (Text) -> bool
+    def __contains__(self, item: Text) -> bool:
         return item in self._child
 
-    def at(self, index):
-        # type: (int) -> "_Entry"
+    def at(self, index: int) -> "_Entry":
         return self._child[self._nameindex[index]]
 
-    def index(self, name):
-        # type: (Text) -> int
+    def index(self, name: Text) -> int:
         return self._nameindex.index(name)
 
-    def sort(self, reverse=False):
-        # type: (bool) -> None
+    def sort(self, reverse: bool = False) -> None:
         """Sort the entries recursively; directories first"""
         for e in self._child.values():
             e.sort(reverse=reverse)
@@ -606,13 +582,11 @@ class _Entry(object):
             reverse=reverse)
 
 
-def _isreporev(rev):
-    # type: (Optional[Union[bytes, int]]) -> bool
+def _isreporev(rev: Optional[Union[bytes, int]]) -> bool:
     # patchctx.rev() returns str, which isn't a valid repository revision
     return rev is None or isinstance(rev, int)
 
-def _samectx(ctx1, ctx2):
-    # type: (ThgContext, ThgContext) -> bool
+def _samectx(ctx1: ThgContext, ctx2: ThgContext) -> bool:
     # no fast way to detect changes in uncommitted ctx, just assumes different
     if ctx1.rev() is None or not _isreporev(ctx1.rev()):
         return False
@@ -620,8 +594,10 @@ def _samectx(ctx1, ctx2):
     return ctx1 == ctx2 and ctx1.node() == ctx2.node()
 
 # TODO: visual feedback to denote query type and error as in repofilter
-def _makematcher(repo, ctx, pat, changedonly):
-    # type: (localrepo.localrepository, ThgContext, bytes, bool) -> matchmod.basematcher
+def _makematcher(repo: localrepo.localrepository,
+                 ctx: ThgContext,
+                 pat: bytes,
+                 changedonly: bool) -> matchmod.basematcher:
     cwd = b''  # always relative to repo root
     patterns = []
     if pat and b':' not in pat and b'*' not in pat:
@@ -649,33 +625,28 @@ class _listnodeop(object):
     subreporecursive = False
 
     @staticmethod
-    def findpath(e, path):
-        # type: (_Entry, Text) -> _Entry
+    def findpath(e: _Entry, path: Text) -> _Entry:
         return e[path]
 
     @staticmethod
-    def makepath(e, path):
-        # type: (_Entry, Text) -> _Entry
+    def makepath(e: _Entry, path: Text) -> _Entry:
         return e.makechild(path)
 
     @staticmethod
-    def putpath(e, path, c):
-        # type: (_Entry, Text, _Entry) -> None
+    def putpath(e: _Entry, path: Text, c: _Entry) -> None:
         e.putchild(path, c)
 
 class _treenodeop(object):
     subreporecursive = True
 
     @staticmethod
-    def findpath(e, path):
-        # type: (_Entry, Text) -> _Entry
+    def findpath(e: _Entry, path: Text) -> _Entry:
         for p in path.split('/'):
             e = e[p]
         return e
 
     @staticmethod
-    def makepath(e, path):
-        # type: (_Entry, Text) -> _Entry
+    def makepath(e: _Entry, path: Text) -> _Entry:
         for p in path.split('/'):
             if p not in e:
                 e.makechild(p)
@@ -683,8 +654,7 @@ class _treenodeop(object):
         return e
 
     @staticmethod
-    def putpath(e, path, c):
-        # type: (_Entry, Text, _Entry) -> None
+    def putpath(e: _Entry, path: Text, c: _Entry) -> None:
         rp = path.rfind('/')
         if rp >= 0:
             e = _treenodeop.makepath(e, path[:rp])
@@ -696,8 +666,11 @@ _nodeopmap = {
     }
 
 
-def _populaterepo(roote, repo, nodeop, statusfilter, match):
-    # type: (_Entry, localrepo.localrepository, Any, Text, matchmod.basematcher) -> None
+def _populaterepo(roote: _Entry,
+                  repo: localrepo.localrepository,
+                  nodeop,
+                  statusfilter: Text,
+                  match: matchmod.basematcher) -> None:
     # TODO: replace 'Any' with structural typing for _treenodeop/_listnodeop
     if 'S' in statusfilter:
         _populatesubrepos(roote, repo, nodeop, statusfilter, match)
@@ -715,8 +688,8 @@ def _populaterepo(roote, repo, nodeop, statusfilter, match):
             e = nodeop.makepath(roote, hglib.tounicode(path))
             e.status = st
 
-def _comparesubstate(state1, state2):
-    # type: (Tuple[bytes, bytes, bytes], Tuple[bytes, bytes, bytes]) -> Text
+def _comparesubstate(state1: Tuple[bytes, bytes, bytes],
+                     state2: Tuple[bytes, bytes, bytes]) -> Text:
     if state1 == state2:
         return 'C'
     elif state1 == hglib.nullsubrepostate:
@@ -726,8 +699,11 @@ def _comparesubstate(state1, state2):
     else:
         return 'M'
 
-def _populatesubrepos(roote, repo, nodeop, statusfilter, match):
-    # type: (_Entry, localrepo.localrepository, Any, Text, matchmod.basematcher) -> None
+def _populatesubrepos(roote: _Entry,
+                      repo: localrepo.localrepository,
+                      nodeop,
+                      statusfilter: Text,
+                      match: matchmod.basematcher) -> None:
     # TODO: replace 'Any' with structural typing for _treenodeop/_listnodeop
     ctx = roote.ctx
     pctx = roote.pctx
@@ -751,7 +727,7 @@ def _populatesubrepos(roote, repo, nodeop, statusfilter, match):
             smatch = matchmod.subdirmatcher(path, match)
             try:
                 # pytype: disable=attribute-error
-                srepo = ctx.sub(path)._repo  # type: localrepo.localrepository
+                srepo: localrepo.localrepository = ctx.sub(path)._repo
                 # pytype: enable=attribute-error
                 e.ctx = hglib.revsymbol(srepo, substate[1])
 
@@ -768,8 +744,11 @@ def _populatesubrepos(roote, repo, nodeop, statusfilter, match):
         if len(e) > 0 or (e.status in statusfilter and match(path)):
             nodeop.putpath(roote, hglib.tounicode(path), e)
 
-def _populatepatch(roote, repo, nodeop, statusfilter, match):
-    # type: (_Entry, localrepo.localrepository, Any, Text, matchmod.basematcher) -> None
+def _populatepatch(roote: _Entry,
+                   repo: localrepo.localrepository,
+                   nodeop,
+                   statusfilter: Text,
+                   match: matchmod.basematcher) -> None:
     # TODO: replace 'Any' with structural typing for _treenodeop/_listnodeop
     ctx = roote.ctx
     stat = ctx.changesToParent(0)  # pytype: disable=attribute-error
@@ -786,8 +765,7 @@ def _populatepatch(roote, repo, nodeop, statusfilter, match):
 class ManifestCompleter(QCompleter):
     """QCompleter for ManifestModel"""
 
-    def splitPath(self, path):
-        # type: (Text) -> List[Text]
+    def splitPath(self, path: Text) -> List[Text]:
         """
         >>> c = ManifestCompleter()
         >>> c.splitPath(u'foo/bar')
@@ -800,8 +778,7 @@ class ManifestCompleter(QCompleter):
         """
         return path.split('/')
 
-    def pathFromIndex(self, index):
-        # type: (QModelIndex) -> Text
+    def pathFromIndex(self, index: QModelIndex) -> Text:
         if not index.isValid():
             return ''
         m = self.model()
