@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     QSettings,
@@ -220,7 +220,7 @@ class MatchDialog(QDialog):
                 self.rev_to_match_info.setVisible(False)
                 self.rev_to_match_info_text.setVisible(True)
         def csinfo_update(ctx):
-            self.rev_to_match_info.update(ctx)
+            self.rev_to_match_info.updateItems(ctx)
             set_csinfo_mode(True)
         def csinfo_set_text(text):
             self.rev_to_match_info_text.setText(text)
@@ -274,7 +274,7 @@ class MatchDialog(QDialog):
             if chk.isChecked():
                 fields.append(field)
 
-        rev = hglib.fromunicode(self.rev_combo.currentText())
+        rev = self.rev_combo.currentText()
         if fields:
             self.revsetexpression = ("matching(%s, '%s')"
                                      % (rev, ' '.join(fields)))
