@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from mercurial import (
     pycompat,
@@ -293,7 +293,7 @@ class SummaryPage(BasePage):
     def repositoryChanged(self):
         'repository has detected a change to changelog or parents'
         pctx = self.repo[b'.']
-        self.localCsInfo.update(pctx)
+        self.localCsInfo.updateItems(pctx)
 
     def canExit(self):
         'can merge tool be closed?'
@@ -582,7 +582,7 @@ class CommitPage(BasePage):
     def currentPage(self):
         super(CommitPage, self).currentPage()
         self.wizard().setOption(QWizard.WizardOption.NoDefaultButton, True)
-        self.mergeCsInfo.update()  # show post-merge state
+        self.mergeCsInfo.updateItems()  # show post-merge state
 
         self.msgEntry.setText(commit.mergecommitmessage(self.repo))
         self.msgEntry.moveCursorToEnd()
@@ -687,5 +687,5 @@ class ResultPage(BasePage):
 
     def currentPage(self):
         super(ResultPage, self).currentPage()
-        self.mergeCsInfo.update(self.repo[b'tip'])
+        self.mergeCsInfo.updateItems(self.repo[b'tip'])
         self.wizard().setOption(QWizard.WizardOption.NoCancelButton, True)
