@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     Qt,
@@ -86,7 +86,7 @@ class PerforcePending(QDialog):
         except (error.Abort, error.RepoLookupError) as e:
             revs = []
         self.cslist.clear()
-        self.cslist.update(revs)
+        self.cslist.updateItems(revs)
         sensitive = not curcl.endswith(b'(submitted)')
         self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(sensitive)
         self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(sensitive)
