@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from mercurial import (
     pycompat,
@@ -66,38 +66,38 @@ class user(tuple):
 
     __slots__ = ()
 
-    def __new__(cls, username, realname, roles):
-        # type: (Any, Text, Text, List[Text]) -> user
+    def __new__(cls,
+                username: Text,
+                realname: Text,
+                roles: List[Text]) -> user:
         return tuple.__new__(cls, (username, realname, roles))
 
     @property
-    def username(self):
-        # type: () -> Text
+    def username(self) -> Text:
         '''username used by phabsend'''
         return self[0]
 
     @property
-    def realname(self):
-        # type: () -> Text
+    def realname(self) -> Text:
         '''friendly name of this user'''
         return self[1]
 
     @property
-    def roles(self):
-        # type: () -> List[Text]
+    def roles(self) -> List[Text]:
         '''the roles filled by this user'''
         return self[2]
 
-    def __repr__(self):
-        # type: () -> Text
+    def __repr__(self) -> Text:
         return '%s (%s)' % (self.realname, self.username)
 
 
 class PhabReviewDialog(QDialog):
     """Dialog for posting patches to Phabricator"""
 
-    def __init__(self, repoagent, revs, parent=None):
-        # type: (RepoAgent, Sequence[int], Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 revs: Sequence[int],
+                 parent: Optional[QWidget] = None) -> None:
         """Create PhabReviewDialog for the given repo and revs
 
         :revs: List of revisions to be sent.
@@ -159,18 +159,16 @@ class PhabReviewDialog(QDialog):
         self._writesettings()
         super(PhabReviewDialog, self).closeEvent(event)
 
-    def _readsettings(self):
-        # type: () -> None
+    def _readsettings(self) -> None:
         s = QSettings()
         self.restoreGeometry(qtlib.readByteArray(s, 'phabsend/geom'))
 
-    def _writesettings(self):
-        # type: () -> None
+    def _writesettings(self) -> None:
         s = QSettings()
         s.setValue('phabsend/geom', self.saveGeometry())
 
-    def _reviewerhistorypath(self, withcallsign=False):
-        # type: (bool) -> Optional[Text]
+    def _reviewerhistorypath(self,
+                             withcallsign: bool = False) -> Optional[Text]:
         '''Fetches the path in the settings used to store reviewer history.
 
         If no reviewers are stored or the configuration isn't present to find
@@ -194,8 +192,7 @@ class PhabReviewDialog(QDialog):
 
         return 'phabsend/%s/%s/reviewers' % (hostpath, callsign)
 
-    def _getreviewerhistory(self):
-        # type: () -> List[user]
+    def _getreviewerhistory(self) -> List[user]:
         '''Returns a fully populated list of the users previously selected to
         perform a review for any repository on the configured server.
         '''
@@ -219,8 +216,7 @@ class PhabReviewDialog(QDialog):
 
         return reviewers
 
-    def _readreviewerhistory(self):
-        # type: () -> None
+    def _readreviewerhistory(self) -> None:
         '''Pre-populates the reviewer lists.
 
         The available reviewer list is populated with all reviewers selected
@@ -255,8 +251,7 @@ class PhabReviewDialog(QDialog):
                     reviewers.addItem(witem)
             s.endArray()
 
-    def _writereviewerhistory(self):
-        # type: () -> None
+    def _writereviewerhistory(self) -> None:
         '''Stores the selected reviewers persistently.
 
         The currently selected reviewers are combined with the existing reviewer
@@ -300,8 +295,7 @@ class PhabReviewDialog(QDialog):
                            reviewers.item(i).data(Qt.ItemDataRole.UserRole + 1).username)
             s.endArray()
 
-    def _initchangesets(self, revs):
-        # type: (Sequence[int]) -> None
+    def _initchangesets(self, revs: Sequence[int]) -> None:
 
         # Posting a review amends the commits, making them hidden.  That in
         # turn would raise a FilteredRepoLookupError each time the table tries
@@ -315,23 +309,19 @@ class PhabReviewDialog(QDialog):
         self._qui.changesets_view.setModel(self._changesets)
 
     @property
-    def _repo(self):
-        # type: () -> localrepo.localrepository
+    def _repo(self) -> localrepo.localrepository:
         return self._repoagent.rawRepo()
 
     @property
-    def _ui(self):
-        # type: () -> uimod.ui
+    def _ui(self) -> uimod.ui:
         return self._repo.ui
 
     @property
-    def _revs(self):
-        # type: () -> List[int]
+    def _revs(self) -> List[int]:
         """Returns list of revisions to be sent"""
         return self._changesets.selectedrevs
 
-    def _phabsendopts(self, **opts):
-        # type: (...) -> Dict[Text, Any]
+    def _phabsendopts(self, **opts) -> Dict[Text, Any]:
         """Generate opts for phabsend by form values"""
         opts['rev'] = hglib.compactrevs(self._revs)
 
@@ -341,8 +331,7 @@ class PhabReviewDialog(QDialog):
 
         return opts
 
-    def _isvalid(self):
-        # type: () -> bool
+    def _isvalid(self) -> bool:
         """Filled all required values?"""
         if not self._revs:
             return False
@@ -350,15 +339,13 @@ class PhabReviewDialog(QDialog):
         return True
 
     @pyqtSlot()
-    def _updateforms(self):
-        # type: () -> None
+    def _updateforms(self) -> None:
         """Update availability of form widgets"""
         valid = self._isvalid()
         self._qui.send_button.setEnabled(valid)
         self._qui.main_tabs.setTabEnabled(self._previewtabindex(), valid)
 
-    def accept(self):
-        # type: () -> None
+    def accept(self) -> None:
         opts = self._phabsendopts()
         cmdline = hglib.buildcmdargs('phabsend', **opts)
         cmd = cmdui.CmdSessionDialog(self)
@@ -368,8 +355,7 @@ class PhabReviewDialog(QDialog):
         if cmd.exec() == 0:
             self._writereviewerhistory()
 
-    def _initpreviewtab(self):
-        # type: () -> None
+    def _initpreviewtab(self) -> None:
         def initqsci(w):
             w.setUtf8(True)
             w.setReadOnly(True)
@@ -378,6 +364,7 @@ class PhabReviewDialog(QDialog):
             fh = qtlib.getfont('fontdiff')
             fh.changed.connect(self.forwardFont)
             lex.setFont(fh.font())
+            w.setFont(fh.font())
             w.setLexer(lex)
             # TODO: better way to setup diff lexer
 
@@ -391,8 +378,7 @@ class PhabReviewDialog(QDialog):
             self.lexer.setFont(font)
 
     @pyqtSlot(int)
-    def _refreshpreviewtab(self, index):
-        # type: (int) -> None
+    def _refreshpreviewtab(self, index: int) -> None:
         """Generate preview text if current tab is preview"""
         if self._previewtabindex() != index:
             return
@@ -406,8 +392,7 @@ class PhabReviewDialog(QDialog):
         sess.commandFinished.connect(self._updatepreview)
 
     @pyqtSlot()
-    def _updatepreview(self):
-        # type: () -> None
+    def _updatepreview(self) -> None:
         preview = self._qui.preview_edit
         exported = hglib.tounicode(bytes(self._cmdsession.readAll()))
 
@@ -435,8 +420,7 @@ class PhabReviewDialog(QDialog):
 
         preview.append(exported)
 
-    def _previewtabindex(self):
-        # type: () -> int
+    def _previewtabindex(self) -> int:
         """Index of preview tab"""
         return self._qui.main_tabs.indexOf(self._qui.preview_tab)
 
@@ -492,8 +476,7 @@ class PhabReviewDialog(QDialog):
             # Must add to source model since setDynamicSortFilter() is True.
             availablereviewers.appendRow(item)
 
-    def _queryreviewers(self, after):
-        # type: (Optional[bytes]) -> None
+    def _queryreviewers(self, after: Optional[bytes]) -> None:
         """Issues the command to query the users, and arranges to have
         _updateavailablereviewers() called on completion.  ``after`` is the
         cursor value from the result of the last command, or None at the start
@@ -529,8 +512,7 @@ class PhabReviewDialog(QDialog):
         sess.commandFinished.connect(self._updateavailablereviewers)
 
     @pyqtSlot()
-    def on_rescan_button_clicked(self):
-        # type: () -> None
+    def on_rescan_button_clicked(self) -> None:
         availablereviewers = self.availablereviewersmodel.sourceModel()
 
         availablereviewers.clear()
@@ -543,8 +525,7 @@ class PhabReviewDialog(QDialog):
 
         self._queryreviewers(None)
 
-    def _get_my_username(self):
-        # type: () -> None
+    def _get_my_username(self) -> None:
         """Spawns the phabricator command to return the current user's info."""
         buf = QBuffer()
 
@@ -558,8 +539,7 @@ class PhabReviewDialog(QDialog):
         sess.commandFinished.connect(self._update_self_username)
 
     @pyqtSlot()
-    def _update_self_username(self):
-        # type: () -> None
+    def _update_self_username(self) -> None:
         """Handles the completion of the current user info fetch."""
         exitcode = self._namesession.exitCode()
 
@@ -570,8 +550,7 @@ class PhabReviewDialog(QDialog):
             self._my_username = results.get("userName")
 
     @pyqtSlot()
-    def _updateavailablereviewers(self):
-        # type: () -> None
+    def _updateavailablereviewers(self) -> None:
         exitcode = self._rescansession.exitCode()
 
         if exitcode == 0:
@@ -599,20 +578,17 @@ class PhabReviewDialog(QDialog):
         self._qui.rescan_button.setEnabled(True)
 
     @pyqtSlot()
-    def on_available_reviewer_selection_changed(self):
-        # type: () -> None
+    def on_available_reviewer_selection_changed(self) -> None:
         view = self._qui.available_reviewer_list
         self._qui.addreviewer_button.setEnabled(bool(view.selectedIndexes()))
 
     @pyqtSlot()
-    def on_reviewer_selection_changed(self):
-        # type: () -> None
+    def on_reviewer_selection_changed(self) -> None:
         view = self._qui.selected_reviewers_list
         self._qui.removereviewer_button.setEnabled(bool(view.selectedIndexes()))
 
     @pyqtSlot()
-    def on_addreviewer_button_clicked(self):
-        # type: () -> None
+    def on_addreviewer_button_clicked(self) -> None:
         """Populates the selected reviewers list when the ">" button is clicked.
         """
         reviewers = self._qui.selected_reviewers_list
@@ -627,8 +603,7 @@ class PhabReviewDialog(QDialog):
                 reviewers.addItem(witem)
 
     @pyqtSlot()
-    def on_removereviewer_button_clicked(self):
-        # type: () -> None
+    def on_removereviewer_button_clicked(self) -> None:
         """Removes items from the selected reviewers list when the "<" button is
         clicked.
         """
@@ -637,11 +612,9 @@ class PhabReviewDialog(QDialog):
             reviewers.takeItem(reviewers.row(i))
 
     @pyqtSlot()
-    def on_selectall_button_clicked(self):
-        # type: () -> None
+    def on_selectall_button_clicked(self) -> None:
         self._changesets.selectAll()
 
     @pyqtSlot()
-    def on_selectnone_button_clicked(self):
-        # type: () -> None
+    def on_selectnone_button_clicked(self) -> None:
         self._changesets.selectNone()
