@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     QSettings,
@@ -37,7 +37,6 @@ from . import (
 
 if hglib.TYPE_CHECKING:
     from typing import (
-        Any,
         List,
         Optional,
         Text,
@@ -51,8 +50,10 @@ if hglib.TYPE_CHECKING:
 
 
 class PickDialog(QDialog):
-    def __init__(self, repoagent, parent, **opts):
-        # type: (RepoAgent, Optional[QWidget], Any) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 parent: Optional[QWidget],
+                 **opts) -> None:
         super(PickDialog, self).__init__(parent)
 
         # TODO: self.setWindowIcon(qtlib.geticon('hg-pick'))
@@ -128,8 +129,7 @@ class PickDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def _readSettings(self):
-        # type: () -> None
+    def _readSettings(self) -> None:
         """Initialize widgets on this dialog from persistent storage.
         """
         qs = QSettings()
@@ -139,8 +139,7 @@ class PickDialog(QDialog):
                                        qtlib.readBool(qs, 'autoresolve', True)))
         qs.endGroup()
 
-    def _writeSettings(self):
-        # type: () -> None
+    def _writeSettings(self) -> None:
         """Save the option widget states on this dialog to persistent storage.
         """
         qs = QSettings()
@@ -149,8 +148,7 @@ class PickDialog(QDialog):
         qs.endGroup()
 
     @pyqtSlot(bool)
-    def _onWctxCheckFinished(self, clean):
-        # type: (bool) -> None
+    def _onWctxCheckFinished(self, clean: bool) -> None:
         """The callback when the command to check that wdir is clean completes.
         """
         if not clean:
@@ -164,8 +162,7 @@ class PickDialog(QDialog):
             txt = _('You may continue the pick')
         self._stbar.showMessage(txt)
 
-    def runCommand(self):
-        # type: () -> None
+    def runCommand(self) -> None:
         """The handler for clicking the operation action button.
 
         This issues the main command for the dialog, or ``--continue`` if there
@@ -186,8 +183,7 @@ class PickDialog(QDialog):
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._commandFinished)
 
-    def abort(self):
-        # type: () -> None
+    def abort(self) -> None:
         """The handler for clicking the Abort button.
 
         This issues a command to abort the interrupted operation.
@@ -196,8 +192,7 @@ class PickDialog(QDialog):
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._abortFinished)
 
-    def _runCommand(self, cmdline):
-        # type: (List[Text]) -> cmdcore.CmdSession
+    def _runCommand(self, cmdline: List[Text]) -> cmdcore.CmdSession:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self._stbar.clearProgress)
@@ -207,8 +202,7 @@ class PickDialog(QDialog):
         return sess
 
     @pyqtSlot(int)
-    def _commandFinished(self, ret):
-        # type: (int) -> None
+    def _commandFinished(self, ret: int) -> None:
         """The callback when the main command (or ``--continue``) completes."""
         # TODO since hg 2.6, pick will end with ret=1 in case of "unresolved
         # conflicts", so we can fine-tune checkResolve() later.
@@ -221,22 +215,19 @@ class PickDialog(QDialog):
             self._makeCloseButton()
 
     @pyqtSlot()
-    def _abortFinished(self):
-        # type: () -> None
+    def _abortFinished(self) -> None:
         """The callback when the abort command completes."""
         if self.checkResolve() is False:
             self._stbar.showMessage(_('Pick aborted'))
             self._makeCloseButton()
 
-    def _makeCloseButton(self):
-        # type: () -> None
+    def _makeCloseButton(self) -> None:
         self.runbtn.setEnabled(True)
         self.runbtn.setText(_('Close'))
         self.runbtn.clicked.disconnect(self.runCommand)
         self.runbtn.clicked.connect(self.accept)
 
-    def checkResolve(self):
-        # type: () -> bool
+    def checkResolve(self) -> bool:
         for root, path, status in thgrepo.recursiveMergeStatus(self.repo):
             if status == b'u':
                 txt = _('Pick generated merge <b>conflicts</b> that must '
@@ -256,8 +247,7 @@ class PickDialog(QDialog):
             self.abortbtn.setEnabled(False)
             return False
 
-    def linkActivated(self, cmd):
-        # type: (Text) -> None
+    def linkActivated(self, cmd: Text) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -265,8 +255,7 @@ class PickDialog(QDialog):
         else:
             self._wctxcleaner.runCleaner(cmd)
 
-    def reject(self):
-        # type: () -> None
+    def reject(self) -> None:
         """The handler for clicking the Cancel button.
 
         If the user confirms the cancellation, the operation is left in the
@@ -282,7 +271,6 @@ class PickDialog(QDialog):
                 return
         super(PickDialog, self).reject()
 
-    def done(self, r):
-        # type: (int) -> None
+    def done(self, r: int) -> None:
         self._writeSettings()
         super(PickDialog, self).done(r)
