@@ -17,7 +17,7 @@ https://foss.heptapod.net/mercurial/tortoisehg/thg-build-deps/mercurial-reviewbo
 More information can be found at http://www.mikeyd.com.au/tortoisehg-reviewboard
 """
 
-
+from __future__ import annotations
 
 from .qtcore import (
     QSettings,
@@ -71,13 +71,11 @@ if hglib.TYPE_CHECKING:
 
 
 class LoadReviewDataThread(QThread):
-    def __init__ (self, dialog):
-        # type: ("PostReviewDialog") -> None
+    def __init__ (self, dialog: "PostReviewDialog") -> None:
         super(LoadReviewDataThread, self).__init__(dialog)
         self.dialog = dialog
 
-    def run(self):
-        # type: () -> None
+    def run(self) -> None:
         msg = None
         if not self.dialog.server:
             msg = _("Invalid Settings - The ReviewBoard server is not setup")
@@ -108,8 +106,7 @@ class LoadReviewDataThread(QThread):
 
         self.dialog.error_message = msg
 
-    def loadCombos(self):
-        # type: () -> None
+    def loadCombos(self) -> None:
         #Get the index of a users previously selected repo id
         index = 0
         count = 0
@@ -134,8 +131,11 @@ class LoadReviewDataThread(QThread):
 
 class PostReviewDialog(QDialog):
     """Dialog for sending patches to reviewboard"""
-    def __init__(self, ui, repoagent, revs, parent=None):
-        # type: (uimod.ui, RepoAgent, Sequence[Union[bytes, int]], Optional[QWidget]) -> None
+    def __init__(self,
+                 ui: uimod.ui,
+                 repoagent: RepoAgent,
+                 revs: Sequence[Union[bytes, int]],
+                 parent: Optional[QWidget] = None) -> None:
         super(PostReviewDialog, self).__init__(parent)
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.ui = ui
@@ -161,8 +161,7 @@ class PostReviewDialog(QDialog):
         return self._repoagent.rawRepo()
 
     @pyqtSlot()
-    def passwordPrompt(self):
-        # type: () -> bool
+    def passwordPrompt(self) -> bool:
         pwd, ok = qtlib.getTextInput(self,
                                      _('Review Board'),
                                      _('Password:'),
@@ -175,8 +174,7 @@ class PostReviewDialog(QDialog):
             return False
 
     @pyqtSlot()
-    def errorPrompt(self):
-        # type: () -> None
+    def errorPrompt(self) -> None:
         self.qui.progress_bar.hide()
         self.qui.progress_label.hide()
 
@@ -187,8 +185,7 @@ class PostReviewDialog(QDialog):
         elif self.isValid():
             self.qui.post_review_button.setEnabled(True)
 
-    def closeEvent(self, event):
-        # type: (QCloseEvent) -> None
+    def closeEvent(self, event: QCloseEvent) -> None:
         if not self._cmdsession.isFinished():
             self._cmdsession.abort()
             event.ignore()
@@ -201,8 +198,7 @@ class PostReviewDialog(QDialog):
         self.writeSettings()
         super(PostReviewDialog, self).closeEvent(event)
 
-    def readSettings(self):
-        # type: () -> None
+    def readSettings(self) -> None:
         s = QSettings()
 
         self.restoreGeometry(qtlib.readByteArray(s, 'reviewboard/geom'))
@@ -231,8 +227,7 @@ class PostReviewDialog(QDialog):
         self.password = self.repo.ui.config(b'reviewboard', b'password')
         self.browser = self.repo.ui.config(b'reviewboard', b'browser')
 
-    def writeSettings(self):
-        # type: () -> None
+    def writeSettings(self) -> None:
         s = QSettings()
         s.setValue('reviewboard/geom', self.saveGeometry())
         s.setValue('reviewboard/publish_immediately_check',
@@ -255,10 +250,10 @@ class PostReviewDialog(QDialog):
         s.setValue('reviewboard/summary_edit_history',
                    list(itercombo(self.qui.summary_edit))[:10])
 
-    def initChangesets(self, revs, selected_revs=None):
-        # type: (Sequence[Union[bytes, int]], Optional[Sequence[int]]) -> None
-        def purerevs(revs):
-            # type: (Sequence[Union[bytes, int]]) -> Sequence[int]
+    def initChangesets(self,
+                       revs: Sequence[Union[bytes, int]],
+                       selected_revs: Optional[Sequence[int]] = None) -> None:
+        def purerevs(revs: Sequence[Union[bytes, int]]) -> Sequence[int]:
             return [r for r in scmutil.revrange(self.repo, revs)]
         if selected_revs:
             selectedrevs = purerevs(selected_revs)
@@ -274,34 +269,28 @@ class PostReviewDialog(QDialog):
         self.qui.changesets_view.setModel(self._changesets)
 
     @property
-    def selectedRevs(self):
-        # type: () -> List[int]
+    def selectedRevs(self) -> List[int]:
         """Returns list of revisions to be sent"""
         return self._changesets.selectedrevs
 
     @property
-    def allRevs(self):
-        # type: () -> List[int]
+    def allRevs(self) -> List[int]:
         """Returns list of revisions to be sent"""
         return self._changesets.revs
 
-    def getRepoId(self):
-        # type: () -> Text
+    def getRepoId(self) -> Text:
         comboText = self.qui.repo_id_combo.currentText().split(":")
         return comboText[0]
 
-    def getReviewId(self):
-        # type: () -> Text
+    def getReviewId(self) -> Text:
         comboText = self.qui.review_id_combo.currentText().split(":")
         return comboText[0]
 
-    def getSummary(self):
-        # type: () -> Text
+    def getSummary(self) -> Text:
         comboText = self.qui.review_id_combo.currentText().split(":")
         return comboText[1]
 
-    def postReviewOpts(self, **opts):
-        # type: (...) -> Dict[Text, Union[bool, Text]]
+    def postReviewOpts(self, **opts) -> Dict[Text, Union[bool, Text]]:
         """Generate opts for reviewboard by form values"""
         opts['outgoingchanges'] = self.qui.outgoing_changes_check.isChecked()
         opts['branch'] = self.qui.branch_check.isChecked()
@@ -330,8 +319,7 @@ class PostReviewDialog(QDialog):
 
         return opts
 
-    def isValid(self):
-        # type: () -> bool
+    def isValid(self) -> bool:
         """Filled all required values?"""
         if not self.qui.repo_id_combo.currentText():
             return False
@@ -346,28 +334,24 @@ class PostReviewDialog(QDialog):
         return True
 
     @pyqtSlot()
-    def tabChanged(self):
-        # type: () -> None
+    def tabChanged(self) -> None:
         self.qui.post_review_button.setEnabled(self.isValid())
 
     @pyqtSlot()
-    def branchCheckToggle(self):
-        # type: () -> None
+    def branchCheckToggle(self) -> None:
         if self.qui.branch_check.isChecked():
             self.qui.outgoing_changes_check.setChecked(False)
 
         self.toggleOutgoingChangesets()
 
     @pyqtSlot()
-    def outgoingChangesCheckToggle(self):
-        # type: () -> None
+    def outgoingChangesCheckToggle(self) -> None:
         if self.qui.outgoing_changes_check.isChecked():
             self.qui.branch_check.setChecked(False)
 
         self.toggleOutgoingChangesets()
 
-    def toggleOutgoingChangesets(self):
-        # type: () -> None
+    def toggleOutgoingChangesets(self) -> None:
         branch = self.qui.branch_check.isChecked()
         outgoing = self.qui.outgoing_changes_check.isChecked()
         if branch or outgoing:
@@ -377,12 +361,10 @@ class PostReviewDialog(QDialog):
             self.initChangesets(self.allRevs, self.allRevs)
             self.qui.changesets_view.setEnabled(True)
 
-    def close(self):
-        # type: () -> None
+    def close(self) -> None:
         super(PostReviewDialog, self).close()
 
-    def accept(self):
-        # type: () -> None
+    def accept(self) -> None:
         if not self.isValid():
             return
         if not self.password and not self.passwordPrompt():
@@ -392,8 +374,7 @@ class PostReviewDialog(QDialog):
         self.qui.progress_label.setText("Posting Review...")
         self.qui.progress_label.show()
 
-        def cmdargs(opts):
-            # type: (Dict[Text, Union[bool, Text]]) -> List[Text]
+        def cmdargs(opts: Dict[Text, Union[bool, Text]]) -> List[Text]:
             args = []
             for k, v in opts.items():
                 if isinstance(v, bool):
@@ -419,8 +400,7 @@ class PostReviewDialog(QDialog):
         sess.outputReceived.connect(self._captureOutput)
 
     @pyqtSlot()
-    def onCompletion(self):
-        # type: () -> None
+    def onCompletion(self) -> None:
         self.qui.progress_bar.hide()
         self.qui.progress_label.hide()
 
@@ -458,14 +438,12 @@ class PostReviewDialog(QDialog):
         super(PostReviewDialog, self).accept()
 
     @pyqtSlot(str, str)
-    def _captureOutput(self, msg, label):
-        # type: (Text, Text) -> None
+    def _captureOutput(self, msg: Text, label: Text) -> None:
         if label != 'control':
             self._cmdoutputs.append(msg)
 
     @pyqtSlot()
-    def onSettingsButtonClicked(self):
-        # type: () -> None
+    def onSettingsButtonClicked(self) -> None:
         from tortoisehg.hgqt import settings
         if settings.SettingsDialog(parent=self, focus='reviewboard.server').exec():
             # not use repo.configChanged because it can clobber user input
