@@ -6,7 +6,11 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
+
+from typing import (
+    List,
+)
 
 from .qtcore import (
     QSettings,
@@ -29,7 +33,6 @@ from .qtgui import (
 
 from hgext import mq
 from mercurial import (
-    context,
     pycompat,
 )
 
@@ -150,10 +153,10 @@ class QFoldDialog(QDialog):
 
     def options(self):
         return {'keep': self.keepchk.isChecked(),
-                'message': pycompat.unicode(self.msgte.text())}
+                'message': self.msgte.text()}
 
-    def patches(self):
-        return pycompat.maplist(hglib.tounicode, self.ulw.getPatchList())
+    def patches(self) -> List[str]:
+        return hglib.to_unicode_list(self.ulw.getPatchList())
 
     def accept(self):
         self._writesettings()
