@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import re
@@ -831,9 +831,10 @@ def fileEditor(filename, **opts):
     editor.setMarginLineNumbers(1, True)
     editor.setMarginWidth(1, '000')
 
+    font = qtlib.getfont('fonteditor').font()
     lexer = QsciLexerProperties()
-    lexer.setFont(qtlib.getfont('fonteditor').font(), -1)
-
+    lexer.setFont(font, -1)
+    editor.setFont(font)
     editor.setLexer(lexer)
 
     if opts.get('foldable'):
