@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import gc
 import os
@@ -520,7 +520,7 @@ class QtRunner(QObject):
         self._mainapp.setOrganizationDomain('tortoisehg.org')
         self._mainapp.setApplicationVersion(thgversion.version())
         if hasattr(self._mainapp, 'setDesktopFileName'):  # introduced in Qt 5.7
-            self._mainapp.setDesktopFileName('thg.desktop')
+            self._mainapp.setDesktopFileName('thg')
         self._fixlibrarypaths()
         self._installtranslator()
         QFont.insertSubstitutions('monospace', ['monaco', 'courier new'])
@@ -636,8 +636,7 @@ class QtRunner(QObject):
             dlg.setParent(self._workbench, dlg.windowFlags())
         dlg.show()
 
-    def actionRegistry(self):
-        # type: () -> shortcutregistry.ActionRegistry
+    def actionRegistry(self) -> shortcutregistry.ActionRegistry:
         assert self._actionregistry
         return self._actionregistry
 
