@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import atexit
 import os
@@ -25,6 +25,7 @@ from .qtcore import (
     QEvent,
     QFile,
     QObject,
+    QPoint,
     QProcess,
     QSettings,
     QSignalMapper,
@@ -45,6 +46,7 @@ from .qtgui import (
     QColor,
     QDesktopServices,
     QDialog,
+    QDropEvent,
     QFont,
     QFrame,
     QHBoxLayout,
@@ -112,7 +114,7 @@ from ..util.i18n import _
 
 try:
     import win32con  # pytype: disable=import-error
-    openflags = win32con.CREATE_NO_WINDOW  # type: int
+    openflags: int = win32con.CREATE_NO_WINDOW
 except ImportError:
     openflags = 0
 
@@ -178,8 +180,11 @@ def openlocalurl(path: AnyStr) -> bool:
         qurl = QUrl.fromLocalFile(path)
     return QDesktopServices.openUrl(qurl)
 
-def editfiles(repo, files, lineno=None, search=None, parent=None):
-    # type: (localrepo.localrepository, List[bytes], Optional[int], Optional[bytes], Optional[QWidget]) -> None
+def editfiles(repo: localrepo.localrepository,
+              files: List[bytes],
+              lineno: Optional[int] = None,
+              search: Optional[bytes] = None,
+              parent: Optional[QWidget] = None) -> None:
     """open the given file with TortoiseHg's configured visual editor."""
     if len(files) == 1:
         # if editing a single file, open in cwd context of that file
@@ -232,7 +237,7 @@ def editfiles(repo, files, lineno=None, search=None, parent=None):
         # back to older tortoisehg.editor OpenAtLine parsing
         cmdline = b' '.join([toolpath] + files) # default
         try:
-            regexp = re.compile(b'\[([^\]]*)\]')
+            regexp = re.compile(rb'\[([^\]]*)\]')
             expanded = []
             pos = 0
             for m in regexp.finditer(toolpath):
@@ -939,7 +944,11 @@ class CustomPrompt(QMessageBox):
                 self.setEscapeButton(btn)
 
     def run(self) -> int:
-        return self.exec()
+        self.exec()
+        clicked = self.clickedButton()
+        if clicked is None:
+            return -1
+        return self.buttons().index(clicked)
 
     def keyPressEvent(self, event: QKeyEvent) -> None:
         for k, btn in self.hotkeys.items():
@@ -948,8 +957,12 @@ class CustomPrompt(QMessageBox):
         super(CustomPrompt, self).keyPressEvent(event)
 
 class ChoicePrompt(QDialog):
-    def __init__(self, title, message, parent, choices, default=None):
-        # type: (Text, Text, QWidget, List[Text], Optional[Text]) -> None
+    def __init__(self,
+                 title: Text,
+                 message: Text,
+                 parent: QWidget,
+                 choices: List[Text],
+                 default: Optional[Text] = None) -> None:
         QDialog.__init__(self, parent)
         self.setWindowTitle(title)
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
@@ -984,8 +997,7 @@ class ChoicePrompt(QDialog):
         self.box.addLayout(vbox)
         self.setLayout(self.box)
 
-    def run(self):
-        # type: () -> Optional[Text]
+    def run(self) -> Optional[Text]:
         if self.exec():
             return self.choices[self.choice_combo.currentIndex()]
         return None
@@ -1513,8 +1525,9 @@ class Spacer(QWidget):
     def sizeHint(self) -> QSize:
         return QSize(self.width, self.height)
 
-def getCurrentUsername(widget, repo, opts=None):
-    # type: (Optional[QWidget], localrepo.localrepository, Optional[Dict[Text, Text]]) -> Optional[Text]
+def getCurrentUsername(widget: Optional[QWidget],
+                       repo: localrepo.localrepository,
+                       opts: Optional[Dict[Text, Text]] = None) -> Optional[Text]:
     if opts:
         # 1. Override has highest priority
         user = opts.get('user')
@@ -1635,8 +1648,8 @@ def setContextMenuShortcut(
     if QT_VERSION >= 0x50a00 and PYQT_VERSION >= 0x50a00:
         action.setShortcutVisibleInContextMenu(True)
 
-def setContextMenuShortcuts(action, shortcuts):
-    # type: (QAction, List[QKeySequence]) -> None
+def setContextMenuShortcuts(action: QAction,
+                            shortcuts: List[QKeySequence]) -> None:
     """Set shortcuts for a context menu action, making sure it's visible"""
     action.setShortcuts(shortcuts)
     if QT_VERSION >= 0x50a00 and PYQT_VERSION >= 0x50a00:
@@ -1658,3 +1671,11 @@ def toCheckStateEnum(value: Union[int, Qt.CheckState]) -> Qt.CheckState:
             # pytype: enable=attribute-error
 
     return cast(Qt.CheckState, value)
+
+
+def qDropEventPosition(event: QDropEvent) -> QPoint:
+    """Retrieve QPoint position for the drop event"""
+    if QT_VERSION >= 0x060000:
+        return event.position().toPoint()  # pytype: disable=attribute-error
+    else:
+        return event.pos()  # pytype: disable=attribute-error
