@@ -5,12 +5,11 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import sys
 from typing import (
-    Any,
     List,
 )
 
@@ -182,8 +181,10 @@ class QuickOpDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def _runCommand(self, files, lfiles, opts):
-        # type: (List[bytes], List[bytes], Any) -> None
+    def _runCommand(self,
+                    files: List[bytes],
+                    lfiles: List[bytes],
+                    opts) -> None:
         cmdlines = []
         if files:
             cmdlines.append(hglib.buildcmdargs(self.command, *[
