@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     QSettings,
@@ -39,7 +39,6 @@ from . import (
 
 if hglib.TYPE_CHECKING:
     from typing import (
-        Any,
         List,
         Optional,
         Text,
@@ -63,8 +62,10 @@ _SOURCE_SPECS = [
 
 class RebaseDialog(QDialog):
 
-    def __init__(self, repoagent, parent, **opts):
-        # type: (RepoAgent, Optional[QWidget], Any) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 parent: Optional[QWidget],
+                 **opts) -> None:
         super(RebaseDialog, self).__init__(parent)
         self.setWindowIcon(qtlib.geticon('hg-rebase'))
         self.setWindowFlags(self.windowFlags()
@@ -182,8 +183,7 @@ class RebaseDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def _readSettings(self):
-        # type: () -> None
+    def _readSettings(self) -> None:
         qs = QSettings()
         qs.beginGroup('rebase')
         self.autoresolvechk.setChecked(
@@ -191,16 +191,14 @@ class RebaseDialog(QDialog):
                                        qtlib.readBool(qs, 'autoresolve', True)))
         qs.endGroup()
 
-    def _writeSettings(self):
-        # type: () -> None
+    def _writeSettings(self) -> None:
         qs = QSettings()
         qs.beginGroup('rebase')
         qs.setValue('autoresolve', self.autoresolvechk.isChecked())
         qs.endGroup()
 
     @pyqtSlot(bool)
-    def _onCheckFinished(self, clean):
-        # type: (bool) -> None
+    def _onCheckFinished(self, clean: bool) -> None:
         if not clean:
             self.rebasebtn.setEnabled(False)
             txt = _('Before rebase, you must '
@@ -213,13 +211,11 @@ class RebaseDialog(QDialog):
         self._stbar.showMessage(txt)
 
     @pyqtSlot()
-    def _updateSourceSelector(self):
-        # type: () -> None
+    def _updateSourceSelector(self) -> None:
         _name, title, _oplabel = _SOURCE_SPECS[self._sourcegroup.checkedId()]
         self._sourcebox.setTitle(title)
 
-    def rebase(self):
-        # type: () -> None
+    def rebase(self) -> None:
         self.rebasebtn.setEnabled(False)
         self.cancelbtn.setVisible(False)
         self.keepchk.setEnabled(False)
@@ -249,25 +245,22 @@ class RebaseDialog(QDialog):
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._rebaseFinished)
 
-    def swap(self):
-        # type: () -> None
+    def swap(self) -> None:
         oldsource = self.opts.get('source', '.')
         olddest = self.opts.get('dest', '.')
 
-        self.sourcecsinfo.update(target=olddest)
-        self.destcsinfo.update(target=oldsource)
+        self.sourcecsinfo.updateItems(target=olddest)
+        self.destcsinfo.updateItems(target=oldsource)
 
         self.opts['source'] = olddest
         self.opts['dest'] = oldsource
 
-    def abort(self):
-        # type: () -> None
+    def abort(self) -> None:
         cmdline = hglib.buildcmdargs('rebase', abort=True)
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._abortFinished)
 
-    def _runCommand(self, cmdline):
-        # type: (List[Text]) -> cmdcore.CmdSession
+    def _runCommand(self, cmdline: List[Text]) -> cmdcore.CmdSession:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self._stbar.clearProgress)
@@ -277,8 +270,7 @@ class RebaseDialog(QDialog):
         return sess
 
     @pyqtSlot(int)
-    def _rebaseFinished(self, ret):
-        # type: (int) -> None
+    def _rebaseFinished(self, ret: int) -> None:
         # TODO since hg 2.6, rebase will end with ret=1 in case of "unresolved
         # conflicts", so we can fine-tune checkResolve() later.
         if self.checkResolve() is False:
@@ -290,21 +282,18 @@ class RebaseDialog(QDialog):
             self._makeCloseButton()
 
     @pyqtSlot()
-    def _abortFinished(self):
-        # type: () -> None
+    def _abortFinished(self) -> None:
         if self.checkResolve() is False:
             self._stbar.showMessage(_('Rebase aborted'))
             self._makeCloseButton()
 
-    def _makeCloseButton(self):
-        # type: () -> None
+    def _makeCloseButton(self) -> None:
         self.rebasebtn.setEnabled(True)
         self.rebasebtn.setText(_('Close'))
         self.rebasebtn.clicked.disconnect(self.rebase)
         self.rebasebtn.clicked.connect(self.accept)
 
-    def checkResolve(self):
-        # type: () -> bool
+    def checkResolve(self) -> bool:
         for root, path, status in thgrepo.recursiveMergeStatus(self.repo):
             if status == b'u':
                 txt = _('Rebase generated merge <b>conflicts</b> that must '
@@ -325,8 +314,7 @@ class RebaseDialog(QDialog):
             self.abortbtn.setEnabled(False)
             return False
 
-    def linkActivated(self, cmd):
-        # type: (Text) -> None
+    def linkActivated(self, cmd: Text) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -334,8 +322,7 @@ class RebaseDialog(QDialog):
         else:
             self._wctxcleaner.runCleaner(cmd)
 
-    def reject(self):
-        # type: () -> None
+    def reject(self) -> None:
         if hglib.rebase_in_progress(self.repo):
             main = _('Exiting with an unfinished rebase is not recommended.')
             text = _('Consider aborting the rebase first.')
@@ -346,7 +333,6 @@ class RebaseDialog(QDialog):
                 return
         super(RebaseDialog, self).reject()
 
-    def done(self, r):
-        # type: (int) -> None
+    def done(self, r: int) -> None:
         self._writeSettings()
         super(RebaseDialog, self).done(r)
