@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import os
 
@@ -37,7 +37,6 @@ from mercurial import (
     pycompat,
     repoview,
     scmutil,
-    util,
 )
 
 from ..util import hglib
@@ -70,8 +69,7 @@ _permanent_queries = ('head()', 'merge()',
                       'tagged()', 'bookmark()',
                       'file(".hgsubstate") or file(".hgsub")')
 
-def _firstword(query):
-    # type: (Text) -> Optional[bytes]
+def _firstword(query: Text) -> Optional[bytes]:
     lquery = hglib.fromunicode(query)
     try:
         for token, value, _pos in hglib.tokenizerevspec(lquery):
@@ -80,8 +78,7 @@ def _firstword(query):
     except error.ParseError:
         pass
 
-def _querytype(repo, query):
-    # type: (localrepo.localrepository, Text) -> Optional[Text]
+def _querytype(repo: localrepo.localrepository, query: Text) -> Optional[Text]:
     r"""
     >>> # TODO: maybe replace with real repo
     >>> origisrevsymbol = scmutil.isrevsymbol
@@ -126,8 +123,7 @@ def _querytype(repo, query):
 
 
 class SelectAllLineEdit(QLineEdit):
-    def __init__(self, parent=None):
-        # type: (Optional[QWidget]) -> None
+    def __init__(self, parent: Optional[QWidget] = None) -> None:
         super(SelectAllLineEdit, self).__init__(parent)
         self.just_got_focus = False
 
@@ -157,8 +153,9 @@ class RepoFilterBar(QToolBar):
 
     _allBranchesLabel = u'\u2605 ' + _('Show all') + u' \u2605'
 
-    def __init__(self, repoagent, parent=None):
-        # type: (thgrepo.RepoAgent, Optional[QWidget]) -> None
+    def __init__(self,
+                 repoagent: thgrepo.RepoAgent,
+                 parent: Optional[QWidget] = None) -> None:
         super(RepoFilterBar, self).__init__(parent)
         self.layout().setContentsMargins(0, 0, 0, 0)
         self.setIconSize(qtlib.smallIconSize())
@@ -305,26 +302,23 @@ class RepoFilterBar(QToolBar):
         self.entrydlg.entry.setFocus()
         self.entrydlg.setVisible(True)
 
-    def queryIssued(self, query):
-        # type: (Text) -> None
+    def queryIssued(self, query: Text) -> None:
         self.revsetcombo.setEditText(query)
         self.runQuery()
 
-    def _prepareQuery(self):
-        # type: () -> Text
-        query = pycompat.unicode(self.revsetcombo.currentText()).strip()
+    def _prepareQuery(self) -> Text:
+        query = self.revsetcombo.currentText().strip()
         if _querytype(self._repo, query) == 'keyword':
             return hglib.formatrevspec('keyword(%s)', query)
         else:
             return query
 
-    def _isUnsavedQuery(self):
-        # type: () -> bool
-        return pycompat.unicode(self.revsetcombo.currentText()).startswith(' ')
+    def _isUnsavedQuery(self) -> bool:
+        return self.revsetcombo.currentText().startswith(' ')
 
     @pyqtSlot()
     def _updateQueryType(self):
-        query = pycompat.unicode(self.revsetcombo.currentText()).strip()
+        query = self.revsetcombo.currentText().strip()
         qtype = _querytype(self._repo, query)
         if not qtype:
             self._revsettypelabel.hide()
@@ -351,15 +345,14 @@ class RepoFilterBar(QToolBar):
         w = label.minimumSizeHint().width()
         label.setGeometry(le.width() - w - 1, 1, w, le.height() - 2)
         # right margin for label
-        margins = list(le.getContentsMargins())
+        margins = le.contentsMargins()
         if label.isHidden():
-            margins[2] = 0
+            margins.setRight(0)
         else:
-            margins[2] = w + 1
-        le.setContentsMargins(*margins)
+            margins.setRight(w + 1)
+        le.setContentsMargins(margins)
 
-    def setQuery(self, query):
-        # type: (Text) -> None
+    def setQuery(self, query: Text) -> None:
         self.revsetcombo.setCurrentIndex(self.revsetcombo.findText(query))
         self.revsetcombo.setEditText(query)
 
@@ -386,8 +379,7 @@ class RepoFilterBar(QToolBar):
         self.revsetcombo.addItems(full)
         self.revsetcombo.setCurrentIndex(self.revsetcombo.findText(query))
 
-    def loadSettings(self, s):
-        # type: (QSettings) -> None
+    def loadSettings(self, s: QSettings) -> None:
         repoid = hglib.shortrepoid(self._repo)
         s.beginGroup('revset/' + repoid)
         self.entrydlg.restoreGeometry(qtlib.readByteArray(s, 'geom'))
@@ -404,8 +396,7 @@ class RepoFilterBar(QToolBar):
         self._loadBranchFilterSettings(s)
         s.endGroup()
 
-    def saveSettings(self, s):
-        # type: (QSettings) -> None
+    def saveSettings(self, s: QSettings) -> None:
         try:
             repoid = hglib.shortrepoid(self._repo)
         except EnvironmentError:
@@ -455,8 +446,7 @@ class RepoFilterBar(QToolBar):
         self.addWidget(qtlib.Spacer(2, 2))
         self.addWidget(self._branchCombo)
 
-    def _loadBranchFilterSettings(self, s):
-        # type: (QSettings) -> None
+    def _loadBranchFilterSettings(self, s: QSettings) -> None:
         branch = qtlib.readString(s, 'branch')
         if branch == '.':
             branch = hglib.tounicode(self._repo.dirstate.branch())
@@ -466,8 +456,7 @@ class RepoFilterBar(QToolBar):
 
         self._allparAction.setChecked(qtlib.readBool(s, 'branch_allparents'))
 
-    def _saveBranchFilterSettings(self, s):
-        # type: (QSettings) -> None
+    def _saveBranchFilterSettings(self, s: QSettings) -> None:
         branch = self.branch()
         if branch == hglib.tounicode(self._repo.dirstate.branch()):
             # special case for working branch: it's common to have multiple
@@ -486,7 +475,7 @@ class RepoFilterBar(QToolBar):
                 for n in self._repo.heads()
                 if not self._repo[n].extra().get(b'close')]))
         elif self._cbranchAction.isChecked():
-            branches = sorted(self._repo.branchmap())  # type: List[bytes]
+            branches: List[bytes] = sorted(self._repo.branchmap())
         else:
             branches = hglib.namedbranches(self._repo)
 
@@ -494,13 +483,12 @@ class RepoFilterBar(QToolBar):
         priomap = {self._repo.dirstate.branch(): -2, b'default': -1}
         branches = sorted(branches, key=lambda e: priomap.get(e, 0))
 
-        branches = pycompat.maplist(hglib.tounicode, branches)
-
         self._branchCombo.blockSignals(True)
         self._branchCombo.clear()
         self._branchCombo.addItem(self._allBranchesLabel)
         self._branchCombo.setItemData(self._branchCombo.count() - 1, '')
-        for i, branch in enumerate(branches, self._branchCombo.count()):
+        for i, branch in enumerate(pycompat.maplist(hglib.tounicode, branches),
+                                   self._branchCombo.count()):
             self._branchCombo.addItem(branch)
             self._branchCombo.setItemData(i, branch, Qt.ItemDataRole.ToolTipRole)
             self._branchCombo.setItemData(i, branch)
@@ -512,30 +500,25 @@ class RepoFilterBar(QToolBar):
             self._emitBranchChanged()  # falls back to "show all"
 
     @pyqtSlot(str)
-    def setBranch(self, branch):
-        # type: (Text) -> None
+    def setBranch(self, branch: Text) -> None:
         """Change the current branch by name [unicode]"""
         index = self._branchCombo.findData(branch)
         if index >= 0:
             self._branchCombo.setCurrentIndex(index)
 
-    def branch(self):
-        # type: () -> Text
+    def branch(self) -> Text:
         """Return the current branch name [unicode]"""
         index = self._branchCombo.currentIndex()
         branch = self._branchCombo.itemData(index)
-        return pycompat.unicode(branch)
+        return branch
 
-    def branchAncestorsIncluded(self):
-        # type: () -> bool
+    def branchAncestorsIncluded(self) -> bool:
         return self._allparAction.isChecked()
 
-    def getShowHidden(self):
-        # type: () -> bool
+    def getShowHidden(self) -> bool:
         return self.showHiddenBtn.isChecked()
 
-    def getShowGraftSource(self):
-        # type: () -> bool
+    def getShowGraftSource(self) -> bool:
         return self.showGraftSourceBtn.isChecked()
 
     @pyqtSlot()
