@@ -14,7 +14,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
+from __future__ import annotations
 
 import binascii
 import os
@@ -127,8 +127,7 @@ PUBLISHED_TOPIC_COLOR = QColor('#666666')
 GraphNodeRole = Qt.ItemDataRole.UserRole + 0
 LabelsRole = Qt.ItemDataRole.UserRole + 1  # [(text, style), ...]
 
-def _parsebranchcolors(value):
-    # type: (Text) -> List[Tuple[Text, Text]]
+def _parsebranchcolors(value: Text) -> List[Tuple[Text, Text]]:
     r"""Parse tortoisehg.branchcolors setting
 
     >>> _parsebranchcolors('foo:#123456  bar:#789abc ')
@@ -185,14 +184,17 @@ class HgRepoListModel(QAbstractTableModel):
 
     _mqtags = (b'qbase', b'qtip', b'qparent')
 
-    def __init__(self, repoagent, parent=None):
-        # type: (RepoAgent, Optional[QObject]) -> None
+    _selectedrevs: FrozenSet[int]
+
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 parent: Optional[QObject] = None) -> None:
         QAbstractTableModel.__init__(self, parent)
         self._cache = []
         self._timerhandle = None
         self._rowcount = 0
         self._repoagent = repoagent
-        self._selectedrevs = frozenset([])  # type: FrozenSet[int]
+        self._selectedrevs = frozenset([])
         self._revspec = ''
         self._filterbyrevset = True
         self.unicodestar = True
@@ -222,8 +224,7 @@ class HgRepoListModel(QAbstractTableModel):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def _initBranchColors(self):
-        # type: () -> None
+    def _initBranchColors(self) -> None:
         # Always assign the first color to the default branch
         self._branch_colors['default'] = graph.COLORS[0]
 
@@ -231,8 +232,7 @@ class HgRepoListModel(QAbstractTableModel):
         self._branch_colors.update(_parsebranchcolors(
             self._repoagent.configString('tortoisehg', 'branchcolors')))
 
-    def setBranch(self, branch, allparents=False):
-        # type: (Text, bool) -> None
+    def setBranch(self, branch: Text, allparents: bool = False) -> None:
         branchchanged = (branch != self._filterbranch)
         parentchanged = (allparents != self._allparents)
         self._filterbranch = branch
@@ -240,8 +240,7 @@ class HgRepoListModel(QAbstractTableModel):
         if branchchanged or (branch and parentchanged):
             self._rebuildGraph()
 
-    def setShowGraftSource(self, visible):
-        # type: (bool) -> None
+    def setShowGraftSource(self, visible: bool) -> None:
         if self._showgraftsource == visible:
             return
         self._showgraftsource = visible
@@ -274,16 +273,14 @@ class HgRepoListModel(QAbstractTableModel):
             return g
 
     @pyqtSlot()
-    def _reloadGraph(self):
-        # type: () -> None
+    def _reloadGraph(self) -> None:
         self._branchheads.clear()
         self._latesttags = {-1: self._latesttags[-1]}  # clear
         if self._revspec:
             self._runQuery()
         self._rebuildGraph()
 
-    def _rebuildGraph(self):
-        # type: () -> None
+    def _rebuildGraph(self) -> None:
         if not self._querysess.isFinished():
             self._pendingrebuild = True
             return
@@ -351,12 +348,10 @@ class HgRepoListModel(QAbstractTableModel):
         self._emitAllDataChanged()
         self.revsUpdated.emit()
 
-    def revset(self):
-        # type: () -> Text
+    def revset(self) -> Text:
         return self._revspec
 
-    def setRevset(self, revspec):
-        # type: (Text) -> None
+    def setRevset(self, revspec: Text) -> None:
         if revspec == self._revspec:
             return
         self._revspec = revspec
@@ -366,8 +361,7 @@ class HgRepoListModel(QAbstractTableModel):
             return
         self._runQuery()
 
-    def _runQuery(self):
-        # type: () -> None
+    def _runQuery(self) -> None:
         self.showMessage.emit(_('Searching...'))
 
         self._querysess.abort()
@@ -377,8 +371,7 @@ class HgRepoListModel(QAbstractTableModel):
         sess.commandFinished.connect(self._onQueryFinished)
 
     @pyqtSlot(int)
-    def _onQueryFinished(self, ret):
-        # type: (int) -> None
+    def _onQueryFinished(self, ret: int) -> None:
         sess = self._querysess
         if not sess.isFinished():
             # new query is already running
@@ -395,8 +388,7 @@ class HgRepoListModel(QAbstractTableModel):
         if self._pendingrebuild:
             self._rebuildGraph()  # invalid revspec
 
-    def _applyRevsetResult(self, revset):
-        # type: (List[int]) -> None
+    def _applyRevsetResult(self, revset: List[int]) -> None:
         self._selectedrevs = frozenset(revset)
         if self._filterbyrevset or self._pendingrebuild:
             self._rebuildGraph()
@@ -404,16 +396,14 @@ class HgRepoListModel(QAbstractTableModel):
             self._invalidate()
             self.revsUpdated.emit()  # some revisions may be disabled
 
-    def setFilterByRevset(self, filtered):
-        # type: (bool) -> None
+    def setFilterByRevset(self, filtered: bool) -> None:
         if self._filterbyrevset == filtered:
             return
         self._filterbyrevset = filtered
         if self._revspec:
             self._rebuildGraph()
 
-    def _reloadConfig(self):
-        # type: () -> None
+    def _reloadConfig(self) -> None:
         self._fill_step = self._repoagent.configInt('tortoisehg', 'graphlimit')
         self._authorcolor = self._repoagent.configBool(
             'tortoisehg', 'authorcolor')
@@ -423,39 +413,33 @@ class HgRepoListModel(QAbstractTableModel):
             'tortoisehg', 'show-branch-head-label')
 
     @pyqtSlot()
-    def _invalidate(self):
-        # type: () -> None
+    def _invalidate(self) -> None:
         self._reloadConfig()
         self._cache = []
         self._emitAllDataChanged()
 
-    def _emitAllDataChanged(self):
-        # type: () -> None
+    def _emitAllDataChanged(self) -> None:
         if self._rowcount <= 0:
             return
         # optimize range if necessary
         bottomright = self.index(self._rowcount - 1, self.columnCount() - 1)
         self.dataChanged.emit(self.index(0, 0), bottomright)
 
-    def branch(self):
-        # type: () -> Text
+    def branch(self) -> Text:
         return self._filterbranch
 
-    def canFetchMore(self, parent):
-        # type: (QModelIndex) -> bool
+    def canFetchMore(self, parent: QModelIndex) -> bool:
         if parent.isValid():
             return False
         return not self.graph.isfilled()
 
-    def fetchMore(self, parent):
-        # type: (QModelIndex) -> None
+    def fetchMore(self, parent: QModelIndex) -> None:
         if parent.isValid() or self.graph.isfilled():
             return
         self.graph.build_nodes(self._fill_step)
         self._expandRowCount()
 
-    def _ensureBuilt(self, rev):
-        # type: (Optional[int]) -> None
+    def _ensureBuilt(self, rev: Optional[int]) -> None:
         """
         Make sure rev data is available (graph element created).
 
@@ -465,8 +449,7 @@ class HgRepoListModel(QAbstractTableModel):
         self.graph.build_nodes(rev=rev)
         # caller should do _expandRowCount() or _shrinkRowCount() by itself
 
-    def loadall(self):
-        # type: () -> None
+    def loadall(self) -> None:
         self._timerhandle = self.startTimer(1)
 
     def timerEvent(self, event):
@@ -482,36 +465,31 @@ class HgRepoListModel(QAbstractTableModel):
                 self._expandRowCount()
                 self.showMessage.emit('')
 
-    def _expandRowCount(self):
-        # type: () -> None
+    def _expandRowCount(self) -> None:
         newlen = len(self.graph)
         if newlen > self._rowcount:
             self.beginInsertRows(QModelIndex(), self._rowcount, newlen - 1)
             self._rowcount = newlen
             self.endInsertRows()
 
-    def _shrinkRowCount(self):
-        # type: () -> None
+    def _shrinkRowCount(self) -> None:
         newlen = len(self.graph)
         if newlen < self._rowcount:
             self.beginRemoveRows(QModelIndex(), newlen, self._rowcount - 1)
             self._rowcount = newlen
             self.endRemoveRows()
 
-    def rowCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def rowCount(self, parent: QModelIndex = QModelIndex()) -> int:
         if parent.isValid():
             return 0
         return self._rowcount
 
-    def columnCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def columnCount(self, parent: QModelIndex = QModelIndex()) -> int:
         if parent.isValid():
             return 0
         return len(self.allColumns())
 
-    def maxWidthValueForColumn(self, column):
-        # type: (int) -> Optional[Text]
+    def maxWidthValueForColumn(self, column: int) -> Optional[Text]:
         if column == RevColumn:
             return '8' * len(str(len(self.repo))) + '+'
         if column in (NodeColumn, GitNodeColumn):
@@ -535,8 +513,7 @@ class HgRepoListModel(QAbstractTableModel):
         # Fall through for DescColumn
         return None
 
-    def rev(self, index):
-        # type: (QModelIndex) -> int
+    def rev(self, index: QModelIndex) -> int:
         """Revision number of the specified row; None for working-dir"""
         if not index.isValid():
             return -1
@@ -546,24 +523,23 @@ class HgRepoListModel(QAbstractTableModel):
             return -1
         return gnode.rev
 
-    def _user_color(self, user):
-        # type: (Text) -> Text
+    def _user_color(self, user: Text) -> Text:
         'deprecated, please replace with hgtk color scheme'
         if user not in self._user_colors:
             idx = graph.hashcolor(user)
             self._user_colors[user] = graph.COLORS[idx]
         return self._user_colors[user]
 
-    def _namedbranch_color(self, branch):
-        # type: (Text) -> Text
+    def _namedbranch_color(self, branch: Text) -> Text:
         'deprecated, please replace with hgtk color scheme'
         if branch not in self._branch_colors:
             idx = graph.hashcolor(branch)
             self._branch_colors[branch] = graph.COLORS[idx]
         return self._branch_colors[branch]
 
-    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
-        # type: (QModelIndex, int) -> Any
+    def data(self,
+             index: QModelIndex,
+             role: int = Qt.ItemDataRole.DisplayRole) -> Any:
         if not index.isValid():
             return None
         gnode = self.graph[index.row()]
@@ -595,8 +571,7 @@ class HgRepoListModel(QAbstractTableModel):
             else:
                 return None
 
-    def _safedata(self, index, role):
-        # type: (QModelIndex, int) -> Any
+    def _safedata(self, index: QModelIndex, role: int) -> Any:
         row = index.row()
         graphlen = len(self.graph)
         cachelen = len(self._cache)
@@ -617,8 +592,7 @@ class HgRepoListModel(QAbstractTableModel):
             data[idx] = result
         return data[idx]
 
-    def _rawdata(self, index, role):
-        # type: (QModelIndex, int) -> Any
+    def _rawdata(self, index: QModelIndex, role: int) -> Any:
         row = index.row()
         column = index.column()
         gnode = self.graph[row]
@@ -656,8 +630,7 @@ class HgRepoListModel(QAbstractTableModel):
             return self._getchanges(ctx)
         return None
 
-    def flags(self, index):
-        # type: (QModelIndex) -> Qt_ItemFlags
+    def flags(self, index: QModelIndex) -> Qt_ItemFlags:
         flags = super(HgRepoListModel, self).flags(index)
         if not index.isValid():
             return flags
@@ -674,8 +647,7 @@ class HgRepoListModel(QAbstractTableModel):
             flags |= Qt.ItemFlag.ItemIsDropEnabled
         return flags
 
-    def isActiveRev(self, rev):
-        # type: (int) -> bool
+    def isActiveRev(self, rev: int) -> bool:
         """True if the specified rev is not excluded by revset"""
         return (not self._revspec
                 or rev in self._selectedrevs
@@ -683,15 +655,13 @@ class HgRepoListModel(QAbstractTableModel):
                 or (self._revspec and not self._selectedrevs
                     and not self._querysess.isFinished()))
 
-    def mimeTypes(self):
-        # type: () -> List[Text]
+    def mimeTypes(self) -> List[Text]:
         return [mqpatchmimetype]
 
     def supportedDropActions(self):
         return Qt.DropAction.MoveAction
 
-    def mimeData(self, indexes):
-        # type: (List[QModelIndex]) -> QMimeData
+    def mimeData(self, indexes: List[QModelIndex]) -> QMimeData:
         data = set()
         for index in indexes:
             row = b'%d' % index.row()
@@ -702,8 +672,12 @@ class HgRepoListModel(QAbstractTableModel):
         qmd.setData(mqpatchmimetype, bytearray)
         return qmd
 
-    def dropMimeData(self, data, action, row, column, parent):
-        # type: (QMimeData, int, int, int, QModelIndex) -> bool
+    def dropMimeData(self,
+                     data: QMimeData,
+                     action: int,
+                     row: int,
+                     column: int,
+                     parent: QModelIndex) -> bool:
         if mqpatchmimetype not in data.formats():
             return False
         dragrows = [int(r)
@@ -727,13 +701,14 @@ class HgRepoListModel(QAbstractTableModel):
         self._repoagent.runCommand(cmdline)
         return True
 
-    def headerData(self, section, orientation, role=Qt.ItemDataRole.DisplayRole):
-        # type: (int, int, int) -> Optional[Text]
+    def headerData(self,
+                   section: int,
+                   orientation: int,
+                   role: int = Qt.ItemDataRole.DisplayRole) -> Optional[Text]:
         if orientation == Qt.Orientation.Horizontal and role == Qt.ItemDataRole.DisplayRole:
             return self.allColumnHeaders()[section][1]
 
-    def defaultIndex(self):
-        # type: () -> QModelIndex
+    def defaultIndex(self) -> QModelIndex:
         """Index that should be selected when the model is initially loaded
         or the row previously selected is gone"""
         repo = self.repo
@@ -743,7 +718,7 @@ class HgRepoListModel(QAbstractTableModel):
                     'tip': b'tip',
                     'workingdir': None,
                     }.get(initialsel, b'.')
-        rev = repo[changeid].rev()  # type: int
+        rev: int = repo[changeid].rev()
         if self._selectedrevs and rev not in self._selectedrevs:
             rev = max(self._selectedrevs)
         index = self.indexFromRev(rev)
@@ -762,8 +737,7 @@ class HgRepoListModel(QAbstractTableModel):
                     return index
         return QModelIndex()
 
-    def indexFromRev(self, rev):
-        # type: (int) -> QModelIndex
+    def indexFromRev(self, rev: int) -> QModelIndex:
         self._ensureBuilt(rev)
         self._expandRowCount()
         try:
@@ -772,8 +746,7 @@ class HgRepoListModel(QAbstractTableModel):
             return QModelIndex()
         return self.index(row, 0)
 
-    def _getbranch(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getbranch(self, ctx: context.changectx) -> Text:
         b = hglib.tounicode(ctx.branch())
         assert b is not None
         if ctx.extra().get(b'close'):
@@ -783,8 +756,7 @@ class HgRepoListModel(QAbstractTableModel):
                 b += u'--'
         return b
 
-    def _getlatesttags(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getlatesttags(self, ctx: context.changectx) -> Text:
         rev = ctx.rev()
         todo = [rev]
         repo = self.repo
@@ -814,15 +786,13 @@ class HgRepoListModel(QAbstractTableModel):
             self._latesttags[rev] = pdate, pdist + 1, ptag
         return self._latesttags[rev][2]
 
-    def _gettags(self, ctx):
-        # type: (context.changectx) -> Text
+    def _gettags(self, ctx: context.changectx) -> Text:
         if ctx.rev() is None:
             return ''
         tags = [hglib.tounicode(t) for t in ctx.tags() if t not in self._mqtags]
         return ','.join(tags)
 
-    def _getrev(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getrev(self, ctx: context.changectx) -> Text:
         rev = ctx.rev()
         if isinstance(rev, int):
             return str(rev)
@@ -831,8 +801,7 @@ class HgRepoListModel(QAbstractTableModel):
         else:
             return ''
 
-    def _getauthor(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getauthor(self, ctx: context.changectx) -> Text:
         try:
             user = ctx.user()
             if not self._fullauthorname:
@@ -841,8 +810,7 @@ class HgRepoListModel(QAbstractTableModel):
         except error.Abort:
             return _('Mercurial User')
 
-    def _getlog(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getlog(self, ctx: context.changectx) -> Text:
         if ctx.rev() is None:
             if self.unicodestar:
                 # The Unicode symbol is a black star:
@@ -855,8 +823,7 @@ class HgRepoListModel(QAbstractTableModel):
             limit = None  # first line
         return hglib.longsummary(ctx.description(), limit)
 
-    def _getrevlabels(self, ctx):
-        # type: (context.changectx) -> List[Tuple[Text, Text]]
+    def _getrevlabels(self, ctx: context.changectx) -> List[Tuple[Text, Text]]:
         labels = []
 
         # as of hg 4.4.2, repo.branchheads() can be slow because of
@@ -913,8 +880,7 @@ class HgRepoListModel(QAbstractTableModel):
 
         return labels
 
-    def _getchanges(self, ctx):
-        # type: (context.changectx) -> List[Tuple[Text, Text]]
+    def _getchanges(self, ctx: context.changectx) -> List[Tuple[Text, Text]]:
         """Return the MAR status for the given ctx."""
         labels = []
 
@@ -928,8 +894,7 @@ class HgRepoListModel(QAbstractTableModel):
             labels.append((str(len(R)), 'log.removed'))
         return labels
 
-    def _getconv(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getconv(self, ctx: context.changectx) -> Text:
         if ctx.rev() is not None:
             extra = ctx.extra()
             cvt = extra.get(b'convert_revision', b'')
@@ -947,8 +912,7 @@ class HgRepoListModel(QAbstractTableModel):
                 return hglib.tounicode(cvt)
         return ''
 
-    def _getphase(self, ctx):
-        # type: (context.changectx) -> Text
+    def _getphase(self, ctx: context.changectx) -> Text:
         if ctx.rev() is None:
             return ''
         try:
@@ -956,16 +920,13 @@ class HgRepoListModel(QAbstractTableModel):
         except:
             return 'draft'
 
-    def _gettopic(self, ctx):
-        # type: (context.changectx) -> Optional[Text]
+    def _gettopic(self, ctx: context.changectx) -> Optional[Text]:
         return hglib.tounicode(ctx.extra().get(b'topic'))
 
-    def _hasFileColumn(self):
-        # type: () -> bool
+    def _hasFileColumn(self) -> bool:
         return False # no FileColumn
 
-    def allColumns(self):
-        # type: () -> Tuple[Text, ...]
+    def allColumns(self) -> Tuple[Text, ...]:
         if self._hasFileColumn():
             return ALLCOLUMNS
         else:
@@ -1004,8 +965,10 @@ class FileRevModel(HgRepoListModel):
     _defaultcolumns = ('Graph', 'Rev', 'Branch', 'Description', 'Author',
                        'Age', 'Filename')
 
-    def __init__(self, repoagent, filename, parent=None):
-        # type: (RepoAgent, bytes, Optional[QObject]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 filename: bytes,
+                 parent: Optional[QObject] = None) -> None:
         self._filename = filename
         HgRepoListModel.__init__(self, repoagent, parent)
 
@@ -1016,8 +979,7 @@ class FileRevModel(HgRepoListModel):
         grapher = graph.filelog_grapher(self.repo, self._filename)
         return graph.Graph(self.repo, grapher)
 
-    def indexLinkedFromRev(self, rev):
-        # type: (Optional[int]) -> QModelIndex
+    def indexLinkedFromRev(self, rev: Optional[int]) -> QModelIndex:
         """Index for the last changed revision before the specified revision
 
         This does not follow renames.
@@ -1032,8 +994,9 @@ class FileRevModel(HgRepoListModel):
             return QModelIndex()
         return self.indexFromRev(fctx.linkrev())
 
-    def fileData(self, index, baseindex=QModelIndex()):
-        # type: (QModelIndex, QModelIndex) -> Union[filedata.FileData, filedata.PatchFileData]
+    def fileData(self,
+                 index: QModelIndex,
+                 baseindex: QModelIndex = QModelIndex()) -> Union[filedata.FileData, filedata.PatchFileData]:
         """Displayable file data at the given index; baseindex specifies the
         revision where status is calculated from"""
         row = index.row()
