@@ -15,7 +15,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
+from __future__ import annotations
 
 from math import sin, cos, pi
 
@@ -86,7 +86,6 @@ class HgRepoView(QTableView):
         QTableView.__init__(self, parent)
         self._repoagent = repoagent
         self.current_rev = -1
-        self.resized = False
         self.cfgname = cfgname
         self.colselect = colselect
         self.setShowGrid(False)
@@ -285,7 +284,6 @@ class HgRepoView(QTableView):
         hh.setStretchLastSection(False)
         self._resizeColumns(col_widths)
         hh.setStretchLastSection(True)
-        self.resized = True
 
     def _resizeColumns(self, col_widths):
         # _resizeColumns misbehaves if called with last section streched
@@ -497,27 +495,6 @@ class HgRepoView(QTableView):
         self._adjustRowHeight()
         super(HgRepoView, self).showEvent(event)
 
-    def resizeEvent(self, e):
-        # re-size columns the smart way: the column holding Description
-        # is re-sized according to the total widget size.
-        if self.resized and e.oldSize().width() != e.size().width():
-            model = self.model()
-            assert model is not None
-            total_width = stretch_col = 0
-
-            for c in range(model.columnCount()):
-                if c == repomodel.DescColumn:
-                    #save the description column
-                    stretch_col = c
-                else:
-                    #total the other widths
-                    total_width += self.columnWidth(c)
-
-            width = max(self.viewport().width() - total_width, 100)
-            self.setColumnWidth(stretch_col, width)
-
-        super(HgRepoView, self).resizeEvent(e)
-
     def enablefilterpalette(self, enable):
         self._paletteswitcher.enablefilterpalette(enable)
 
