@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -110,7 +110,7 @@ class ResolveDialog(QDialog):
             localrevtitle = qtlib.LabeledSeparator(_('Local revision '
                                                      'information'))
             localrevinfo = csinfo.create(repo)
-            localrevinfo.update(self.mergeState.localctx)
+            localrevinfo.updateItems(self.mergeState.localctx)
             vbox.addWidget(localrevtitle)
             vbox.addWidget(localrevinfo)
             vbox.addStretch()
@@ -121,7 +121,7 @@ class ResolveDialog(QDialog):
             otherrevtitle = qtlib.LabeledSeparator(_('Other revision '
                                                      'information'))
             otherrevinfo = csinfo.create(repo)
-            otherrevinfo.update(self.mergeState.otherctx)
+            otherrevinfo.updateItems(self.mergeState.otherctx)
 
             vbox.addWidget(otherrevtitle)
             vbox.addWidget(otherrevinfo)
@@ -267,8 +267,7 @@ class ResolveDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def getSelectedPaths(self, tree):
-        # type: (QTreeView) -> List[Tuple[bytes, bytes]]
+    def getSelectedPaths(self, tree: QTreeView) -> List[Tuple[bytes, bytes]]:
         paths = []
         if not tree.selectionModel():
             return paths
@@ -279,8 +278,7 @@ class ResolveDialog(QDialog):
             paths.append((root, wfile))
         return paths
 
-    def runCommand(self, tree, cmdline):
-        # type: (QTreeView, List[Text]) -> None
+    def runCommand(self, tree: QTreeView, cmdline: List[Text]) -> None:
         cmdlines = []
         selected = self.getSelectedPaths(tree)
         while selected:
@@ -324,8 +322,7 @@ class ResolveDialog(QDialog):
             abspaths = [os.path.join(r, w) for r, w in paths]
             qtlib.editfiles(self.repo, abspaths, parent=self)
 
-    def getVdiffFiles(self, tree):
-        # type: (QTreeView) -> List[bytes]
+    def getVdiffFiles(self, tree: QTreeView) -> List[bytes]:
         paths = self.getSelectedPaths(tree)
         if not paths:
             return []
@@ -487,13 +484,11 @@ class ResolveDialog(QDialog):
             c.setEnabled(enable and self.mergeState.active())
 
     @pyqtSlot(QPoint)
-    def utreeMenuRequested(self, point):
-        # type: (QPoint) -> None
+    def utreeMenuRequested(self, point: QPoint) -> None:
         self.utreecmenu.popup(self.utree.viewport().mapToGlobal(point))
 
     @pyqtSlot(QPoint)
-    def rtreeMenuRequested(self, point):
-        # type: (QPoint) -> None
+    def rtreeMenuRequested(self, point: QPoint) -> None:
         self.rtreecmenu.popup(self.rtree.viewport().mapToGlobal(point))
 
     def utreeDoubleClicked(self):
@@ -504,29 +499,32 @@ class ResolveDialog(QDialog):
 
 
 class PathsModel(QAbstractTableModel):
-    def __init__(self, pathlist, parent):
-        # type: (List[Tuple[bytes, bytes]], Optional[QWidget]) -> None
+
+    rows: List[Tuple[bytes, bytes, bytes]]
+
+    def __init__(self,
+                 pathlist: List[Tuple[bytes, bytes]],
+                 parent: Optional[QWidget]) -> None:
         QAbstractTableModel.__init__(self, parent)
         self.headers = (_('Path'), _('Ext'), _('Repository'))
-        self.rows = []  # type: List[Tuple[bytes, bytes, bytes]]
+        self.rows = []
         for root, path in pathlist:
             name, ext = os.path.splitext(path)
             self.rows.append((path, ext, root))
 
-    def rowCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def rowCount(self, parent: QModelIndex = QModelIndex()) -> int:
         if parent.isValid():
             return 0 # no child
         return len(self.rows)
 
-    def columnCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def columnCount(self, parent: QModelIndex = QModelIndex()) -> int:
         if parent.isValid():
             return 0 # no child
         return len(self.headers)
 
-    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
-        # type: (QModelIndex, int) -> Optional[Text]
+    def data(self,
+             index: QModelIndex,
+             role: int = Qt.ItemDataRole.DisplayRole) -> Optional[Text]:
         if not index.isValid():
             return None
         if role == Qt.ItemDataRole.DisplayRole:
@@ -534,33 +532,31 @@ class PathsModel(QAbstractTableModel):
             return hglib.tounicode(data)
         return None
 
-    def flags(self, index):
-        # type: (QModelIndex) -> Qt_ItemFlags
+    def flags(self, index: QModelIndex) -> Qt_ItemFlags:
         flags = super(PathsModel, self).flags(index)
         if not index.isValid():
             return flags
         flags |= Qt.ItemFlag.ItemIsDragEnabled
         return flags
 
-    def headerData(self, col, orientation, role=Qt.ItemDataRole.DisplayRole):
-        # type: (int, int, int) -> Optional[Text]
+    def headerData(self,
+                   col: int,
+                   orientation: int,
+                   role: int = Qt.ItemDataRole.DisplayRole) -> Optional[Text]:
         if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
             return self.headers[col]
 
-    def getPathForIndex(self, index):
-        # type: (QModelIndex) -> Tuple[bytes, bytes]
+    def getPathForIndex(self, index: QModelIndex) -> Tuple[bytes, bytes]:
         'return root, wfile for the given row'
         row = index.row()
         return self.rows[row][2], self.rows[row][0]
 
-    def mimeTypes(self):
-        # type: () -> List[Text]
+    def mimeTypes(self) -> List[Text]:
         return ['text/uri-list']
 
-    def mimeData(self, indexes):
-        # type: (List[QModelIndex]) -> QMimeData
+    def mimeData(self, indexes: List[QModelIndex]) -> QMimeData:
         paths = [hglib.tounicode(os.path.join(*self.getPathForIndex(i)))
                  for i in indexes if i.column() == 0]
         data = QMimeData()
@@ -583,8 +579,7 @@ class ToolsCombo(QComboBox):
         for t in self.repo.mergetools:
             self.addItem(hglib.tounicode(t))
 
-    def readValue(self):
-        # type: () -> Optional[bytes]
+    def readValue(self) -> Optional[bytes]:
         text = self.currentText()
         if text != self.default:
             return hglib.fromunicode(text)
