@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -310,7 +310,7 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
         'called by repowidget when repoview changes revisions'
         self.ctx = ctx = self.repo[rev]
         self.revpanel.set_revision(rev)
-        self.revpanel.update(repo=self.repo)
+        self.revpanel.updateItems(repo=self.repo)
         msg = ctx.description()
         inlinetags = self._repoagent.configBool(
             'tortoisehg', 'issue.inlinetags')
