@@ -6,11 +6,10 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 from mercurial import (
     cmdutil,
-    context,
     error,
 )
 
