@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qsci import (
     QsciAPIs,
@@ -342,8 +342,10 @@ class RevsetEntry(QsciScintilla):
         self.setAutoCompletionThreshold(2)
         self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsAPIs)
         self.setAutoCompletionFillupsEnabled(True)
+        font = qtlib.getfont('fontcomment').font()
+        self.setFont(font)
         self.setLexer(QsciLexerPython(self))
-        self.lexer().setFont(qtlib.getfont('fontcomment').font())
+        self.lexer().setFont(font)
         self.apis = QsciAPIs(self.lexer())
 
     def addCompletions(self, *lists):
