@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import, print_function
+from __future__ import annotations
 
 import getopt
 import os
@@ -14,6 +14,10 @@ import pdb
 import sys
 import subprocess
 
+from typing import (
+    Optional,
+)
+
 from mercurial import (
     cmdutil,
     encoding,
@@ -57,7 +61,7 @@ except ImportError:
     config_nofork = None
 
 shortlicense = b'''
-Copyright (C) 2008-2022 Steve Borho <steve@borho.org> and others.
+Copyright (C) 2008-2025 Steve Borho <steve@borho.org> and others.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 '''
@@ -153,7 +157,7 @@ def dispatch(args, u=None):
 
         return -1
     except KeyboardInterrupt:
-        print(_('\nCaught keyboard interrupt, aborting.\n'))
+        print(hglib.tounicode(_('\nCaught keyboard interrupt, aborting.\n')))
         return -1
 
 def portable_fork(ui, opts):
@@ -173,7 +177,8 @@ def portable_fork(ui, opts):
     try:
         _forkbg(ui)
     except OSError as inst:
-        ui.warn(_('failed to fork GUI process: %s\n') % inst.strerror)
+        ui.warn(_('failed to fork GUI process: %s\n')
+                % hglib.fromunicode(inst.strerror))
 
 # native window API can't be used after fork() on Mac OS X
 if os.name == 'posix' and sys.platform != 'darwin':
@@ -454,7 +459,7 @@ def _runcommand(ui, options, cmd, cmdfunc):
         if format not in [b'text', b'kcachegrind']:
             ui.warn(_("unrecognized profiling format '%s'"
                         " - Ignored\n") % format)
-            format = 'text'
+            format = b'text'
 
         output = ui.config(b'profiling', b'output')
 
@@ -477,12 +482,12 @@ def _runcommand(ui, options, cmd, cmdfunc):
         finally:
             p.disable()
 
-            if format == 'kcachegrind':
-                import lsprofcalltree
+            if format == b'kcachegrind':
+                from mercurial import lsprofcalltree
                 calltree = lsprofcalltree.KCacheGrind(p)
                 calltree.output(ostream)
             else:
-                # format == 'text'
+                # format == b'text'
                 stats = lsprof.Stats(p.getstats())
                 stats.sort(pycompat.sysstr(field))
                 stats.pprint(top=10, file=ostream, climit=5)
@@ -683,7 +688,7 @@ def debugblockmatcher(ui, *pats, **opts):
 @command(b'debugbugreport', [], _('thg debugbugreport [TEXT]'))
 def debugbugreport(ui, *pats, **opts):
     """open bugreport dialog by exception"""
-    raise Exception(' '.join(pats))
+    raise Exception(' '.join(map(hglib.tounicode, pats)))
 
 @command(b'debugconsole', [], _('thg debugconsole'))
 def debugconsole(ui, repoagent, *pats, **opts):
@@ -715,13 +720,15 @@ def debugruncommand(ui, repoagent, *cmdline, **opts):
 @command(b'drag_copy', [], _('thg drag_copy SOURCE... DEST'))
 def drag_copy(ui, repoagent, *pats, **opts):
     """copy the selected files to the desired directory"""
-    opts.update(alias='copy', headless=True)
+    # TODO: drop the disable comment after updating to pytype 2023.03.02+
+    opts.update(alias=b'copy', headless=True)  # pytype: disable=wrong-arg-types
     return quickop.run(ui, repoagent, *pats, **opts)
 
 @command(b'drag_move', [], _('thg drag_move SOURCE... DEST'))
 def drag_move(ui, repoagent, *pats, **opts):
     """move the selected files to the desired directory"""
-    opts.update(alias='move', headless=True)
+    # TODO: drop the disable comment after updating to pytype 2023.03.02+
+    opts.update(alias=b'move', headless=True)  # pytype: disable=wrong-arg-types
     return quickop.run(ui, repoagent, *pats, **opts)
 
 @command(b'email',
@@ -800,7 +807,7 @@ def guess(ui, repoagent, *pats, **opts):
 
 ### help management, adapted from mercurial.commands.help_()
 @command(b'help', [], _('thg help [COMMAND]'))
-def help_(ui, name=None, with_version=False, **opts):
+def help_(ui, name: Optional[bytes]=None, with_version=False, **opts):
     """show help for a command, extension, or list of commands
 
     With no arguments, print a list of commands and short help.
@@ -829,7 +836,7 @@ def help_(ui, name=None, with_version=False, **opts):
                 msg = _('use "thg -v help %s" to show global options') % name
             option_lists.append((msg, ()))
 
-    def helpcmd(name):
+    def helpcmd(name: bytes) -> None:
         if with_version:
             version(ui)
             ui.write(b'\n')
@@ -837,7 +844,8 @@ def help_(ui, name=None, with_version=False, **opts):
         try:
             aliases, i = cmdutil.findcmd(name, table, False)
         except error.AmbiguousCommand as inst:
-            select = lambda c: c.startswith(inst.prefix)
+            prefix = inst.prefix
+            select = lambda c: c.startswith(prefix)
             helplist(_('list of commands:\n\n'), select)
             return
 
@@ -853,7 +861,7 @@ def help_(ui, name=None, with_version=False, **opts):
         if doc:
             doc = hglib.fromunicode(doc)
             if ui.quiet:
-                doc = doc.splitlines(0)[0]
+                doc = doc.splitlines(False)[0]
         else:
             doc = _("(no help text available)")
         ui.write(b"\n%s\n" % doc.rstrip())
@@ -909,7 +917,7 @@ def help_(ui, name=None, with_version=False, **opts):
         if not ui.quiet:
             addglobalopts(True)
 
-    def helptopic(name):
+    def helptopic(name: bytes) -> None:
         from mercurial import help
         for topic in help.helptable:
             names, header, doc = topic[0:3]
@@ -922,7 +930,7 @@ def help_(ui, name=None, with_version=False, **opts):
         if not doc:
             doc = _("(no help text available)")
         if hasattr(doc, '__call__'):
-            doc = doc()
+            doc = doc(ui)
 
         ui.write(b"%s\n" % header)
         ui.write(b"%s\n" % doc.rstrip())
@@ -986,7 +994,7 @@ def help_(ui, name=None, with_version=False, **opts):
 def hgignore(ui, repoagent, *pats, **opts):
     """ignore filter editor"""
     from tortoisehg.hgqt import hgignore as hgignoremod
-    if pats and pats[0].endswith('.hgignore'):
+    if pats and pats[0].endswith(b'.hgignore'):
         pats = []
     return hgignoremod.HgignoreDialog(repoagent, None, *pats)
 
@@ -1134,11 +1142,13 @@ def prune(ui, repoagent, *revs, **opts):
     from tortoisehg.hgqt import prune as prunemod
     revs = list(revs)
     revs.extend(opts.get('rev'))
+    revs = pycompat.maplist(hglib.tounicode, revs)
+
     if len(revs) < 2:
         revspec = ''.join(revs)
     else:
         revspec = hglib.formatrevspec('%lr', revs)
-    return prunemod.createPruneDialog(repoagent, hglib.tounicode(revspec))
+    return prunemod.createPruneDialog(repoagent, revspec)
 
 @command(b'purge', [], _('thg purge'),
          helpbasic=True)
@@ -1194,7 +1204,7 @@ def rejects(ui, *pats, **opts):
     if len(pats) != 1:
         raise error.Abort(_('You must provide the path to a file'))
     path = pats[0]
-    if path.endswith('.rej'):
+    if path.endswith(b'.rej'):
         path = path[:-4]
     return rejectsmod.RejectsDialog(ui, path)
 
@@ -1213,7 +1223,7 @@ def rename(ui, repoagent, source=None, dest=None, **opts):
         source = hglib.tounicode(pathutil.canonpath(repo.root, cwd, source))
     if dest:
         dest = hglib.tounicode(pathutil.canonpath(repo.root, cwd, dest))
-    iscopy = (opts.get('alias') == 'copy')
+    iscopy = (opts.get('alias') == b'copy')
     return renamemod.RenameDialog(repoagent, None, source, dest, iscopy)
 
 @command(b'repoconfig',
@@ -1240,7 +1250,7 @@ def revdetails(ui, repoagent, *pats, **opts):
     from tortoisehg.hgqt import revdetails as revdetailsmod
     repo = repoagent.rawRepo()
     os.chdir(repo.root)
-    rev = opts.get('rev', '.')
+    rev = scmutil.revsingle(repo, opts.get('rev')).rev()
     return revdetailsmod.RevDetailsDialog(repoagent, rev=rev)
 
 @command(b'revert', [], _('thg revert [FILE]...'))
