@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 from typing import (
@@ -114,12 +114,15 @@ def hasExtension(extname):
     return False
 
 class SettingsCombo(QComboBox):
+
+    defaults: List[Text]
+
     def __init__(self, parent=None, **opts):
         QComboBox.__init__(self, parent, toolTip=opts['tooltip'])
         self.opts = opts
         self.setEditable(opts.get('canedit', False))
         self.setValidator(opts.get('validator', None))
-        self.defaults = opts.get('defaults', [])  # type: List[Text]
+        self.defaults = opts.get('defaults', [])
         if self.defaults and self.isEditable():
             self.setCompleter(QCompleter(self.defaults, self))
         self.curvalue = None
@@ -165,7 +168,7 @@ class SettingsCombo(QComboBox):
 
     def showPopup(self):
         if self.opts.get('defer') and not self.loaded:
-            self.defaults = self.opts['defer']()  # type: List[Text]
+            self.defaults = self.opts['defer']()
             self.loaded = True
             self.resetList()
         QComboBox.showPopup(self)
@@ -1322,7 +1325,7 @@ class SettingsDialog(QDialog):
             qtlib.ErrorMsgBox(_('Iniparse package not found'),
                          _("Can't change settings without iniparse package - "
                            'view is readonly.'), parent=self)
-            print('Please install https://code.google.com/archive/p/iniparse/')
+            print('Please install https://github.com/candlepin/python-iniparse')
 
         if not focus:
             focus = qtlib.readString(QSettings(), 'settings/lastpage', 'log')
@@ -1766,8 +1769,7 @@ class SettingsForm(QWidget):
         section, key = pycompat.sysbytes(cpath).split(b'.', 1)
         return self.ini.get(section, key)
 
-    def loadIniFile(self, rcpath):
-        # type: (List[str]) -> IniConfig
+    def loadIniFile(self, rcpath: List[str]) -> IniConfig:
         for fn in rcpath:
             if os.path.exists(fn):
                 break
