@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 from mercurial.windows import winreg
 
@@ -226,10 +226,10 @@ class ShellConfigWindow(QDialog):
         for name, info in vars.items():
             default, regkey, regtype, evalfunc, wrfunc, cbattr = info
             try:
-                hkey = OpenKey(HKEY_CURRENT_USER, 'Software\\' + regkey)
-                v = QueryValueEx(hkey, name)[0]
-                vars[name][0] = evalfunc(v)
-            except (WindowsError, EnvironmentError):
+                with OpenKey(HKEY_CURRENT_USER, 'Software\\' + regkey) as hkey:
+                    v = QueryValueEx(hkey, name)[0]
+                    vars[name][0] = evalfunc(v)
+            except OSError:
                 pass
             if cbattr is not None:
                 checkbutton = getattr(self, cbattr)
