@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import os
 import time
@@ -316,7 +316,7 @@ class ShelveDialog(QDialog):
                 return
         try:
             fn = os.path.join('shelves', shelve)
-            shelfpath = self.repo.vfs.join(hglib.fromunicode(fn))  # type: bytes
+            shelfpath: bytes = self.repo.vfs.join(hglib.fromunicode(fn))
             if os.path.exists(shelfpath):
                 qtlib.ErrorMsgBox(_('File already exists'),
                                   _('A shelf file of that name already exists'))
@@ -327,7 +327,7 @@ class ShelveDialog(QDialog):
             if shelfpath in self.shelves:
                 self.combob.setCurrentIndex(self.shelves.index(shelfpath))
         except EnvironmentError as e:
-            self.showMessage(hglib.tounicode(str(e)))
+            self.showMessage(hglib.exception_str(e))
 
     @pyqtSlot()
     def deleteShelfA(self):
@@ -340,7 +340,7 @@ class ShelveDialog(QDialog):
             os.unlink(shelf)
             self.showMessage(_('Shelf deleted'))
         except EnvironmentError as e:
-            self.showMessage(hglib.tounicode(str(e)))
+            self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
     @pyqtSlot()
@@ -354,7 +354,7 @@ class ShelveDialog(QDialog):
                 commands.revert(self.repo.ui, self.repo, all=True)
                 self.repo.ui.quiet = False
             except (EnvironmentError, error.Abort) as e:
-                self.showMessage(hglib.tounicode(str(e)))
+                self.showMessage(hglib.exception_str(e))
                 self.refreshCombos()
             return
         shelf = self.currentPatchA()
@@ -367,7 +367,7 @@ class ShelveDialog(QDialog):
             f.close()
             self.showMessage(_('Shelf cleared'))
         except EnvironmentError as e:
-            self.showMessage(hglib.tounicode(str(e)))
+            self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
     @pyqtSlot()
@@ -381,7 +381,7 @@ class ShelveDialog(QDialog):
             os.unlink(shelf)
             self.showMessage(_('Shelf deleted'))
         except EnvironmentError as e:
-            self.showMessage(hglib.tounicode(str(e)))
+            self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
     @pyqtSlot()
@@ -396,7 +396,7 @@ class ShelveDialog(QDialog):
             f.close()
             self.showMessage(_('Shelf cleared'))
         except EnvironmentError as e:
-            self.showMessage(hglib.tounicode(str(e)))
+            self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
     def currentPatchA(self):
