@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import collections
 import weakref
@@ -46,7 +46,7 @@ if hglib.TYPE_CHECKING:
     ]
     _KeySequencesDefs = Union[_KeySequencesD, List[_KeySequencesD], None]
 
-_ACTIONS_TABLE = {
+_ACTIONS_TABLE: Dict[Text, Tuple[Text, _KeySequencesDefs]] = {
     # MQ operations:
     # TODO: merge or give better name to deletePatches_, pushMovePatch_,
     # and renamePatch_
@@ -169,7 +169,7 @@ _ACTIONS_TABLE = {
     'Workbench.showRepoRegistry': (_('Sh&ow Repository Registry'),
                                    'Ctrl+Shift+O'),
     'Workbench.webServer': (_('&Web Server'), None),
-}  # type: Dict[Text, Tuple[Text, _KeySequencesDefs]]
+}
 
 _SETTINGS_GROUP = 'KeyboardShortcuts'
 
@@ -177,8 +177,7 @@ _TOOLTIP_SHORTCUT_START_TAG = '<span class="shortcut" style="color: gray">'
 _TOOLTIP_SHORTCUT_END_TAG = '</span>'
 
 
-def _parseDefaultKeySequences(data):
-    # type: (_KeySequencesDefs) -> List[QKeySequence]
+def _parseDefaultKeySequences(data: _KeySequencesDefs) -> List[QKeySequence]:
     if data is None:
         return []
     if isinstance(data, list):
@@ -194,16 +193,15 @@ def _parseDefaultKeySequences(data):
         return [QKeySequence('%s+%s' % (mod, kstr), QKeySequence.SequenceFormat.PortableText)]
     return QKeySequence.keyBindings(data)
 
-def _parseUserKeySequences(data):
-    # type: (List[Text]) -> List[QKeySequence]
+def _parseUserKeySequences(data: List[Text]) -> List[QKeySequence]:
     return [QKeySequence(s, QKeySequence.SequenceFormat.PortableText) for s in data]
 
-def _formatKeySequences(seqs):
-    # type: (List[QKeySequence]) -> List[Text]
+def _formatKeySequences(seqs: List[QKeySequence]) -> List[Text]:
     return [b.toString(QKeySequence.SequenceFormat.PortableText) for b in seqs]
 
-def _formatToolTip(label, toolTip, seqs):
-    # type: (Text, Text, List[QKeySequence]) -> Text
+def _formatToolTip(label: Text,
+                   toolTip: Text,
+                   seqs: List[QKeySequence]) -> Text:
     """Build tool tip from current label/toolTip and shortcuts
 
     >>> stext = '%s(%s)%s' % (_TOOLTIP_SHORTCUT_START_TAG, 'A',
@@ -247,20 +245,20 @@ class ShortcutRegistry(object):
     and QAction instances.
     """
 
+    _userKeys: Dict[Text, List[QKeySequence]]
+
     def __init__(self):
         self._defaultKeys = {name: _parseDefaultKeySequences(seq)
                              for name, (_label, seq) in _ACTIONS_TABLE.items()}
-        self._userKeys = {}  # type: Dict[Text, List[QKeySequence]]
+        self._userKeys = {}
 
-    def copyShortcuts(self):
-        # type: () -> ShortcutRegistry
+    def copyShortcuts(self) -> ShortcutRegistry:
         """Creates new registry by copying the shortcut configuration"""
         registry = ShortcutRegistry()
         registry._userKeys = self._userKeys.copy()
         return registry
 
-    def updateShortcuts(self, registry):
-        # type: (ShortcutRegistry) -> None
+    def updateShortcuts(self, registry: ShortcutRegistry) -> None:
         """Copies shortcut configuration back from the given registry"""
         self._userKeys = registry._userKeys.copy()
 
@@ -287,33 +285,29 @@ class ShortcutRegistry(object):
                 qs.remove(name)
         qs.endGroup()
 
-    def allNames(self):
-        # type: () -> List[Text]
+    def allNames(self) -> List[Text]:
         """List of all known action names"""
         return sorted(_ACTIONS_TABLE)
 
-    def actionLabel(self, name):
-        # type: (Text) -> Text
+    def actionLabel(self, name: Text) -> Text:
         label, _default = _ACTIONS_TABLE[name]
         return label
 
-    def defaultKeySequences(self, name):
-        # type: (Text) -> List[QKeySequence]
+    def defaultKeySequences(self, name: Text) -> List[QKeySequence]:
         return self._defaultKeys[name]
 
-    def keySequences(self, name):
-        # type: (Text) -> List[QKeySequence]
+    def keySequences(self, name: Text) -> List[QKeySequence]:
         if name in self._userKeys:
             return self._userKeys[name]
         return self.defaultKeySequences(name)
 
-    def hasUserKeySequences(self, name):
-        # type: (Text) -> bool
+    def hasUserKeySequences(self, name: Text) -> bool:
         assert name in _ACTIONS_TABLE, name
         return name in self._userKeys
 
-    def setUserKeySequences(self, name, seqs):
-        # type: (Text, List[QKeySequence]) -> None
+    def setUserKeySequences(self,
+                            name: Text,
+                            seqs: List[QKeySequence]) -> None:
         """Stores new shortcuts of the specified action
 
         To remove the shortcuts, specify []. To restore the default key
@@ -324,8 +318,7 @@ class ShortcutRegistry(object):
         assert name in _ACTIONS_TABLE, name
         self._userKeys[name] = seqs
 
-    def unsetUserKeySequences(self, name):
-        # type: (Text) -> None
+    def unsetUserKeySequences(self, name: Text) -> None:
         """Restores the shortcuts of the specified action to default
 
         You'll also want to call saveSettings() and applyChangesToActions().
@@ -337,28 +330,28 @@ class ShortcutRegistry(object):
 class ActionRegistry(ShortcutRegistry):
     """Manages user-configurable shortcuts and QAction instances"""
 
+    _actionsMap: Dict[Text, weakref.WeakSet[QAction]]
+
     def __init__(self):
         super(ActionRegistry, self).__init__()
         # QAction instances are owned by QWidget and will be destroyed when
         # C++ object is deleted. Since QAction will be instantiated per
         # context (e.g. window), more than one instances may be registered
         # to the same slot.
-        self._actionsMap = collections.defaultdict(weakref.WeakSet)  # type: Dict[Text, weakref.WeakSet[QAction]]
+        self._actionsMap = collections.defaultdict(weakref.WeakSet)
 
     def applyChangesToActions(self):
         """Applies changes to registered QAction instances"""
         for name, actions in self._actionsMap.items():
             self._updateActions(name, actions)
 
-    def registerAction(self, name, action):
-        # type: (Text, QAction) -> None
+    def registerAction(self, name: Text, action: QAction) -> None:
         """Register QAction instance to be updated on applyChangesToActions()"""
         assert name in _ACTIONS_TABLE, name
         self._actionsMap[name].add(action)
         self._updateActions(name, [action])
 
-    def _updateActions(self, name, actions):
-        # type: (Text, Iterable[QAction]) -> None
+    def _updateActions(self, name: Text, actions: Iterable[QAction]) -> None:
         label = self.actionLabel(name)
         seqs = self.keySequences(name)
         for a in actions:
