@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -55,6 +55,7 @@ from mercurial import (
     context,
     error,
     hg,
+    mergestate as mergestatemod,
     pycompat,
     scmutil,
     util,
@@ -70,6 +71,10 @@ from . import (
     qtlib,
 )
 
+from typing import (
+    Dict,
+)
+
 # This widget can be used as the basis of the commit tool or any other
 # working copy browser.
 
@@ -460,7 +465,13 @@ class StatusWidget(QWidget):
     def canExit(self):
         return not self.isRefreshingWctx()
 
-    def updateModel(self, wctx, wstatus, patchecked, amending):
+    def updateModel(
+        self,
+        wctx,
+        wstatus: scmutil.status,
+        patchecked: Dict[bytes, bool],
+        amending,
+    ) -> None:
         self.tv.setSortingEnabled(False)
         oldtm = self.tv.model()
         if oldtm:
@@ -695,13 +706,13 @@ class StatusThread(QThread):
         self.opts = opts
         self.wctx = None
         self.wstatus = None
-        self.patchecked = {}
+        self.patchecked: Dict[bytes, bool] = {}
         self.amending = set()
 
     def run(self):
         extract = lambda x, y: dict(zip(x, pycompat.maplist(y.get, x)))
         stopts = extract(('unknown', 'ignored', 'clean'), self.opts)
-        patchecked = {}
+        patchecked: Dict[bytes, bool] = {}
         try:
             if self.pats:
                 if self.opts.get('checkall'):
@@ -779,23 +790,32 @@ class WctxModel(QAbstractTableModel):
     checkCountChanged = pyqtSignal()
     checkToggled = pyqtSignal(str, bool)
 
-    def __init__(self, repoagent, wctx, wstatus, ms, pctx, savechecks, opts,
-                 checked, parent, checkable=True, defcheck='MAR!S',
-                 amending=None):
+    def __init__(self, repoagent, wctx,
+                 wstatus: scmutil.status,
+                 ms: mergestatemod.mergestate,
+                 pctx,
+                 savechecks: bool,
+                 opts,
+                 checked: Dict[bytes, bool],
+                 parent,
+                 checkable: bool=True,
+                 defcheck: str='MAR!S',
+                 amending=None,
+    ) -> None:
         QAbstractTableModel.__init__(self, parent)
         self._repoagent = repoagent
         self._pctx = pctx
         self.partials = parent.partials
         self.checkCount = 0
         rows = []
-        nchecked = {}
+        nchecked: Dict[bytes, bool] = {}
         excludestr = opts.get('ciexclude', '')
         assert isinstance(excludestr, str)
-        excludes = [f.strip() for f in excludestr.split(',')]
+        excludes = [f.strip() for f in hglib.fromunicode(excludestr).split(b',')]
         if amending is None:
             amending = set()
 
-        def mkrow(fname, st):
+        def mkrow(fname: bytes, st: str):
             ext, sizek = '', ''
             try:
                 mst = fname in ms and pycompat.sysstr(ms[fname].upper()) or ""
@@ -804,9 +824,10 @@ class WctxModel(QAbstractTableModel):
                 sizek = (sizebytes + 1023) // 1024
             except EnvironmentError:
                 pass
-            return [fname, st, mst, hglib.tounicode(fname), ext[1:], sizek]
+            return [fname, st, mst, hglib.tounicode(fname),
+                    hglib.tounicode(ext[1:]), sizek]
         if not savechecks:
-            checked = {}
+            checked: Dict[bytes, bool] = {}
         if pctx:
             # Currently, having a patch context means it's a qrefresh, so only
             # auto-check files in pctx.files()
@@ -1107,11 +1128,11 @@ class WctxModel(QAbstractTableModel):
         self.layoutChanged.emit()
         self.endResetModel()
 
-    def getChecked(self):
+    def getChecked(self) -> Dict[bytes, bool]:
         assert len(self.checked) == len(self.unfiltered)
         return self.checked.copy()
 
-def statusMessage(status, mst, upath):
+def statusMessage(status: str, mst: str, upath: str):
     tip = ''
     if status in statusTypes:
         upath = "<span style='font-family:Courier'>%s </span>" % upath
@@ -1124,7 +1145,9 @@ def statusMessage(status, mst, upath):
 
 class StatusType(object):
     preferredOrder = 'MAR!?ICS'
-    def __init__(self, name, icon, desc, uilabel, trname):
+    def __init__(
+        self, name: str, icon: str, desc: str, uilabel: str, trname: str
+    ) -> None:
         self.name = name
         self.icon = icon
         self.desc = desc
