@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import shutil
@@ -49,8 +49,7 @@ from . import (
 _FILE_FILTER = "%s;;%s" % (_("Patch files (*.diff *.patch)"),
                            _("All files (*)"))
 
-def _writetempfile(text):
-    # type: (bytes) -> str
+def _writetempfile(text: bytes) -> str:
     fd, filename = tempfile.mkstemp(suffix=b'.patch', prefix=b'thg-import-',
                                     dir=qtlib.gettempdir())
     try:
@@ -246,7 +245,7 @@ class ImportDialog(QDialog):
         if not patches:
             self.cslist.clear()
         else:
-            self.cslist.update([os.path.abspath(p) for p in patches])
+            self.cslist.updateItems([os.path.abspath(p) for p in patches])
         self.updatestatus()
         self._updateUi()
 
