@@ -8,7 +8,7 @@
 # See mercurial/extensions.py, comments to wrapfunction, for this approach
 # to extending repositories and change contexts.
 
-
+from __future__ import annotations
 
 import os
 import sys
@@ -451,28 +451,34 @@ class RepoAgent(QObject):
     def rootPath(self):
         return hglib.tounicode(self._repo.root)
 
-    def configBool(self, section, name, default=hgconfig.UNSET_DEFAULT):
-        # type: (Text, Text, bool) -> bool
+    def configBool(self,
+                   section: Text,
+                   name: Text,
+                   default: bool = hgconfig.UNSET_DEFAULT) -> bool:
         return self._config.configBool(section, name, default)
 
-    def configInt(self, section, name, default=hgconfig.UNSET_DEFAULT):
-        # type: (Text, Text, int) -> int
+    def configInt(self,
+                  section: Text,
+                  name: Text,
+                  default: int = hgconfig.UNSET_DEFAULT) -> int:
         return self._config.configInt(section, name, default)
 
-    def configString(self, section, name, default=hgconfig.UNSET_DEFAULT):
-        # type: (Text, Text, Text) -> Text
+    def configString(self,
+                     section: Text,
+                     name: Text,
+                     default: Text = hgconfig.UNSET_DEFAULT) -> Text:
         return self._config.configString(section, name, default)
 
-    def configStringList(self, section, name, default=hgconfig.UNSET_DEFAULT):
-        # type: (Text, Text, List[Text]) -> List[Text]
+    def configStringList(self,
+                         section: Text,
+                         name: Text,
+                         default: List[Text] = hgconfig.UNSET_DEFAULT) -> List[Text]:
         return self._config.configStringList(section, name, default)
 
-    def configStringItems(self, section):
-        # type: (Text) -> List[Tuple[Text, Text]]
+    def configStringItems(self, section: Text) -> List[Tuple[Text, Text]]:
         return self._config.configStringItems(section)
 
-    def hasConfig(self, section, name):
-        # type: (Text, Text) -> bool
+    def hasConfig(self, section: Text, name: Text) -> bool:
         return self._config.hasConfig(section, name)
 
     def displayName(self):
@@ -583,8 +589,7 @@ class RepoAgent(QObject):
         self._watcher.stopMonitoring()
         self.repositoryDestroyed.emit()
 
-    def isBusy(self):
-        # type: () -> bool
+    def isBusy(self) -> bool:
         return self._cmdagent.isBusy()
 
     def _preinvalidateCache(self):
@@ -607,28 +612,30 @@ class RepoAgent(QObject):
             self._flushRepositoryChanged()
         self.busyChanged.emit(busy)
 
-    def runCommand(self, cmdline, uihandler=None, overlay=True):
-        # type: (List[Text], Optional[Union[QWidget, cmdcore.UiHandler]], bool) -> cmdcore.CmdSession
+    def runCommand(self,
+                   cmdline: List[Text],
+                   uihandler: Optional[Union[QWidget, cmdcore.UiHandler]] = None,
+                   overlay: bool = True) -> cmdcore.CmdSession:
         """Executes a single command asynchronously in this repository"""
         cmdline = self._extendCmdline(cmdline, overlay)
         return self._cmdagent.runCommand(cmdline, uihandler)
 
-    def runCommandSequence(self, cmdlines, uihandler=None, overlay=True):
-        # type: (List[List[Text]], Optional[Union[QWidget, cmdcore.UiHandler]], bool) -> cmdcore.CmdSession
+    def runCommandSequence(self,
+                           cmdlines: List[List[Text]],
+                           uihandler: Optional[Union[QWidget, cmdcore.UiHandler]] = None,
+                           overlay: bool = True) -> cmdcore.CmdSession:
         """Executes a series of commands asynchronously in this repository"""
         cmdlines = [self._extendCmdline(l, overlay) for l in cmdlines]
         return self._cmdagent.runCommandSequence(cmdlines, uihandler)
 
-    def _extendCmdline(self, cmdline, overlay):
-        # type: (List[Text], bool) -> List[Text]
+    def _extendCmdline(self, cmdline: List[Text], overlay: bool) -> List[Text]:
         if self.hiddenRevsIncluded():
             cmdline = ['--hidden'] + cmdline
         if overlay and self._overlayurl:
             cmdline = ['-R', self._overlayurl] + cmdline
         return cmdline
 
-    def abortCommands(self):
-        # type: () -> None
+    def abortCommands(self) -> None:
         """Abort running and queued commands"""
         self._cmdagent.abortCommands()
 
@@ -995,8 +1002,7 @@ def _extendrepo(repo):
                 if localrepo.hasunfilteredcache(self, a):
                     delattr(self.unfiltered(), a)
 
-        def thg_reload_hggit_data(self):
-            # type: () -> None
+        def thg_reload_hggit_data(self) -> None:
             """Reload hg-git specific data structures.
 
             This function forces the reload of hg-git specific files, so that
