@@ -7,7 +7,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 from .qtcore import (
     pyqtSlot,
@@ -55,8 +55,11 @@ if hglib.TYPE_CHECKING:
 
 class UpdateWidget(cmdui.AbstractCmdWidget):
 
-    def __init__(self, repoagent, rev=None, parent=None, opts=None):
-        # type: (RepoAgent, Optional[Union[Text, pycompat.unicode]], Optional[QWidget], Optional[UpdateOpts]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 rev: Optional[Union[Text, pycompat.unicode]] = None,
+                 parent: Optional[QWidget] = None,
+                 opts: Optional[UpdateOpts] = None) -> None:
         # TODO: unify the `rev` type
         super(UpdateWidget, self).__init__(parent)
         if opts is None:
@@ -172,8 +175,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
             # need to change rev
             self.rev_combo.lineEdit().selectAll()
 
-    def readSettings(self, qs):
-        # type: (QSettings) -> None
+    def readSettings(self, qs: QSettings) -> None:
         self.merge_chk.setChecked(qtlib.readBool(qs, 'merge'))
         self.autoresolve_chk.setChecked(
             self._repoagent.configBool('tortoisehg', 'autoresolve',
@@ -183,8 +185,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
         # expand options if a hidden one is checked
         self.optexpander.set_expanded(self.hiddenSettingIsChecked())
 
-    def writeSettings(self, qs):
-        # type: (QSettings) -> None
+    def writeSettings(self, qs: QSettings) -> None:
         qs.setValue('merge', self.merge_chk.isChecked())
         qs.setValue('autoresolve', self.autoresolve_chk.isChecked())
         qs.setValue('verbose', self.verbose_chk.isChecked())
@@ -193,18 +194,16 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def hiddenSettingIsChecked(self):
-        # type: () -> bool
+    def hiddenSettingIsChecked(self) -> bool:
         return (self.merge_chk.isChecked()
                 or self.autoresolve_chk.isChecked())
 
     @pyqtSlot()
-    def update_info(self):
-        # type: () -> None
-        self.p1_info.update(self.ctxs[0].node())
+    def update_info(self) -> None:
+        self.p1_info.updateItems(self.ctxs[0].node())
         merge = len(self.ctxs) == 2
         if merge:
-            self.p2_info.update(self.ctxs[1].node())
+            self.p2_info.updateItems(self.ctxs[1].node())
         new_rev = hglib.fromunicode(self.rev_combo.currentText())
         if new_rev == b'null':
             self.target_info.setText(_('remove working directory'))
@@ -217,7 +216,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                     and not new_ctx.bookmarks():
                 self.target_info.setText(_('(same as parent)'))
             else:
-                self.target_info.update(new_ctx)
+                self.target_info.updateItems(new_ctx)
             # only show the path combo when there are multiple paths
             # and the target revision has subrepos
             showpathcombo = self.path_combo.count() > 1 and \
@@ -228,8 +227,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
             self.target_info.setText(_('unknown revision!'))
         self.commandChanged.emit()
 
-    def canRunCommand(self):
-        # type: () -> bool
+    def canRunCommand(self) -> bool:
         new_rev = hglib.fromunicode(self.rev_combo.currentText())
         try:
             new_ctx = hglib.revsymbol(self.repo, new_rev)
@@ -241,19 +239,18 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                 or new_ctx.rev() != self.ctxs[0].rev()
                 or bool(new_ctx.bookmarks()))
 
-    def runCommand(self):
-        # type: () -> cmdcore.CmdSession
+    def runCommand(self) -> cmdcore.CmdSession:
         cmdline = ['update']
         if self.verbose_chk.isChecked():
             cmdline += ['--verbose']
         cmdline += ['--config', 'ui.merge=internal:' +
                     (self.autoresolve_chk.isChecked() and 'merge' or 'fail')]
-        rev = self.rev_combo.currentText()  # type: Text
+        rev: Text = self.rev_combo.currentText()
 
         activatebookmarkmode = self._repoagent.configString(
             'tortoisehg', 'activatebookmarks')
         if activatebookmarkmode != 'never':
-            brev = hglib.fromunicode(rev)  # type: bytes
+            brev: bytes = hglib.fromunicode(rev)
             bookmarks = hglib.revsymbol(self.repo, brev).bookmarks()
 
             if bookmarks and brev not in bookmarks:
@@ -328,14 +325,13 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
         if self.discard_chk.isChecked():
             cmdline.append('--clean')
         else:
-            cur = self.repo.hgchangectx(b'.')  # type: context.changectx
+            cur: context.changectx = self.repo.hgchangectx(b'.')
             try:
                 node = self.repo.hgchangectx(
                     hglib.revsymbol(self.repo, hglib.fromunicode(rev)).rev())
             except (error.LookupError, error.RepoError, EnvironmentError):
                 return cmdcore.nullCmdSession()
-            def isclean():
-                # type: () -> bool
+            def isclean() -> bool:
                 '''whether WD is changed'''
                 try:
                     wc = self.repo[None]
@@ -347,20 +343,19 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                 except EnvironmentError:
                     return False
                 return True
-            def ismergedchange():
-                # type: () -> bool
+            def ismergedchange() -> bool:
                 '''whether the local changes are merged (have 2 parents)'''
                 wc = self.repo[None]
                 return len(wc.parents()) == 2
-            def islocalmerge(p1, p2, clean=None):
-                # type: (context.changectx, context.changectx, Optional[bool]) -> bool
+            def islocalmerge(p1: context.changectx,
+                             p2: context.changectx,
+                             clean: Optional[bool] = None) -> bool:
                 if clean is None:
                     clean = isclean()
                 pa = p1.ancestor(p2)
                 return not clean \
                     and (p1.rev() == pa.rev() or p2.rev() == pa.rev())
-            def confirmupdate():
-                # type: () -> Optional[Text]
+            def confirmupdate() -> Optional[Text]:
                 msg = _('Detected uncommitted local changes in working tree.\n'
                         'Please select to continue:\n')
                 data = {'discard': (_('&Discard'),
@@ -418,21 +413,22 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
         return self._repoagent.runCommand(cmdline, self)
 
     @pyqtSlot(bool)
-    def show_options(self, visible):
-        # type: (bool) -> None
+    def show_options(self, visible: bool) -> None:
         self.merge_chk.setVisible(visible)
         self.autoresolve_chk.setVisible(visible)
 
     @pyqtSlot(int)
-    def _updatePathComboTooltip(self, idx):
-        # type: (int) -> None
+    def _updatePathComboTooltip(self, idx: int) -> None:
         self.path_combo.setToolTip(self.path_combo.itemData(idx))
 
 
 class UpdateDialog(cmdui.CmdControlDialog):
 
-    def __init__(self, repoagent, rev=None, parent=None, opts=None):
-        # type: (RepoAgent, Optional[Union[Text, pycompat.unicode]], Optional[QWidget], Optional[UpdateOpts]) -> None
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 rev: Optional[Union[Text, pycompat.unicode]] = None,
+                 parent: Optional[QWidget] = None,
+                 opts: Optional[UpdateOpts] = None) -> None:
         super(UpdateDialog, self).__init__(parent)
         if opts is None:
             opts = {}
@@ -446,8 +442,7 @@ class UpdateDialog(cmdui.CmdControlDialog):
         self.commandFinished.connect(self._checkMergeConflicts)
 
     @pyqtSlot(int)
-    def _checkMergeConflicts(self, ret):
-        # type: (int) -> None
+    def _checkMergeConflicts(self, ret: int) -> None:
         if ret != 1:
             return
         qtlib.InfoMsgBox(_('Merge caused file conflicts'),
