@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import re
@@ -88,8 +88,12 @@ _nonexistant = _('[non-existant]')
 # It ensures that the names for snapshots created do not collide.
 _diffCount = 0
 
-def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
-    # type: (localrepo.localrepository, Sequence[HgContext], List[Set[bytes]], List[Set[bytes]], Dict[bytes, bytes], bool) -> Tuple[List[Optional[bytes]], List[bytes], List[List[FnsAndMtime]]]
+def snapshotset(repo: localrepo.localrepository,
+                ctxs: Sequence[HgContext],
+                sa: List[Set[bytes]],
+                sb: List[Set[bytes]],
+                copies: Dict[bytes, bytes],
+                copyworkingdir: bool = False) -> Tuple[List[Optional[bytes]], List[bytes], List[List[FnsAndMtime]]]:
     '''snapshot files from parent-child set of revisions'''
     ctx1a, ctx1b, ctx2 = ctxs
     mod_a, add_a, rem_a = sa
@@ -115,7 +119,7 @@ def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
         label1b = b'@%d:%s' % (ctx1b.rev(), ctx1b)
     else:
         dir1b = None
-        fns_mtime1b = []  # type: List[FnsAndMtime]
+        fns_mtime1b: List[FnsAndMtime] = []
         label1b = b''
 
     # Either make a copy of ctx2, or use working dir directly if relevant.
@@ -125,7 +129,7 @@ def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
             dir2, fns_mtime2 = snapshot(repo, files2, ctx2)
         else:
             dir2 = repo.root
-            fns_mtime2 = []  # type: List[FnsAndMtime]
+            fns_mtime2: List[FnsAndMtime] = []
         # If ctx2 is working copy, use empty label.
         label2 = b''
     else:
@@ -137,8 +141,9 @@ def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
     fns_and_mtimes = [fns_mtime1a, fns_mtime1b, fns_mtime2]
     return dirs, labels, fns_and_mtimes
 
-def snapshot(repo, files, ctx):
-    # type: (localrepo.localrepository, Iterable[bytes], HgContext) -> Tuple[bytes, List[FnsAndMtime]]
+def snapshot(repo: localrepo.localrepository,
+             files: Iterable[bytes],
+             ctx: HgContext) -> Tuple[bytes, List[FnsAndMtime]]:
     '''snapshot repo files as of some revision, returning a tuple with the
     created temporary snapshot dir and tuples of file info if using working
     copy.'''
@@ -180,8 +185,10 @@ def snapshot(repo, files, ctx):
             pass
     return base, fns_and_mtime
 
-def launchtool(cmd, opts, replace, block):
-    # type: (bytes, Sequence[bytes], Dict[Text, Union[bytes, Text]], bool) -> None
+def launchtool(cmd: bytes,
+               opts: Sequence[bytes],
+               replace: Dict[Text, Union[bytes, Text]],
+               block: bool) -> None:
     # TODO: fix up the bytes vs str in the replacement mapping
     def quote(match):
         key = pycompat.sysstr(match.group()[1:])
@@ -203,8 +210,7 @@ def launchtool(cmd, opts, replace, block):
                 _('Tool launch failure'),
                 _('%s : %s') % (hglib.tounicode(cmd), hglib.exception_str(e)))
 
-def filemerge(ui, fname, patchedfname):
-    # type: (uimod.ui, Text, Text) -> None
+def filemerge(ui: uimod.ui, fname: Text, patchedfname: Text) -> None:
     'Launch the preferred visual diff tool for two text files'
     detectedtools = hglib.difftools(ui)
     if not detectedtools:
@@ -228,8 +234,9 @@ def filemerge(ui, fname, patchedfname):
     launchtool(diffcmd, diffopts, replace, True)
 
 
-def besttool(ui, tools, force=None):
-    # type: (uimod.ui, DiffTools, Optional[bytes]) -> bytes
+def besttool(ui: uimod.ui,
+             tools: DiffTools,
+             force: Optional[bytes] = None) -> bytes:
     'Select preferred or highest priority tool from dictionary'
     preferred = force or ui.config(b'tortoisehg', b'vdiff') or \
                          ui.config(b'ui', b'merge')
@@ -248,8 +255,10 @@ def besttool(ui, tools, force=None):
     return sorted(pris)[0][1]
 
 
-def visualdiff(ui, repo, pats, opts):
-    # type: (uimod.ui, localrepo.localrepository, Sequence[bytes], Dict[Text, Any]) -> Optional[FileSelectionDialog]
+def visualdiff(ui: uimod.ui,
+               repo: localrepo.localrepository,
+               pats: Sequence[bytes],
+               opts: Dict[Text, Any]) -> Optional[FileSelectionDialog]:
     revs = opts.get('rev', [])
     change = opts.get('change')
 
@@ -284,9 +293,8 @@ def visualdiff(ui, repo, pats, opts):
     return visual_diff(ui, repo, pats, ctx1a, ctx1b, ctx2, opts.get('tool'),
                        opts.get('mainapp'), revs)
 
-def visual_diff(ui, repo, pats, ctx1a, ctx1b, ctx2, tool, mainapp=False,
-                revs=None):
-    # type: (uimod.ui, localrepo.localrepository, Sequence[bytes], HgContext, Optional[HgContext], HgContext, bytes, bool, Optional[Sequence[int]]) -> Optional[FileSelectionDialog]
+def visual_diff(ui: uimod.ui, repo: localrepo.localrepository, pats: Sequence[bytes], ctx1a: HgContext, ctx1b: Optional[HgContext], ctx2: HgContext, tool: bytes, mainapp: bool = False,
+                revs: Optional[Sequence[int]] = None) -> Optional[FileSelectionDialog]:
     """Opens the visual diff tool on the given file patterns in the given
     contexts.  If a ``tool`` is provided, it is used, otherwise the diff tool
     launched is determined by the configuration.  For a 2-way diff, ``ctx1a`` is
@@ -302,8 +310,7 @@ def visual_diff(ui, repo, pats, ctx1a, ctx1b, ctx2, tool, mainapp=False,
     m = match.match(repo.root, b'', pats, None, None, b'relpath', ctx=ctx2)
     n2 = ctx2.node()
 
-    def _status(ctx):
-        # type: (HgContext) -> Tuple[List[bytes], List[bytes], List[bytes]]
+    def _status(ctx: HgContext) -> Tuple[List[bytes], List[bytes], List[bytes]]:
         status = repo.status(ctx.node(), n2, m)
         return status.modified, status.added, status.removed
 
@@ -481,8 +488,18 @@ def visual_diff(ui, repo, pats, ctx1a, ctx1b, ctx2, tool, mainapp=False,
 
 class FileSelectionDialog(QDialog):
     'Dialog for selecting visual diff candidates'
-    def __init__(self, repo, pats, ctx1a, sa, ctx1b, sb, ctx2, cpy):
-        # type: (localrepo.localrepository, Sequence[bytes], HgContext, List[Set[bytes]], Optional[HgContext], List[Set[bytes]], HgContext, Dict[bytes, bytes]) -> None
+
+    curFile: Optional[bytes]
+
+    def __init__(self,
+                 repo: localrepo.localrepository,
+                 pats: Sequence[bytes],
+                 ctx1a: HgContext,
+                 sa: List[Set[bytes]],
+                 ctx1b: Optional[HgContext],
+                 sb: List[Set[bytes]],
+                 ctx2: HgContext,
+                 cpy: Dict[bytes, bytes]) -> None:
         'Initialize the Dialog'
         QDialog.__init__(self)
 
@@ -508,7 +525,7 @@ class FileSelectionDialog(QDialog):
         self.filesets = (sa, sb)
         self.copies = cpy
         self.repo = repo
-        self.curFile = None  # type: Optional[bytes]
+        self.curFile = None
 
         layout = QVBoxLayout()
         self.setLayout(layout)
@@ -570,14 +587,15 @@ class FileSelectionDialog(QDialog):
         QTimer.singleShot(0, self.fillmodel)
 
     @pyqtSlot()
-    def fillmodel(self):
-        # type: () -> None
+    def fillmodel(self) -> None:
         repo = self.repo
         sa, sb = self.filesets
         self.dirs, self.revs = snapshotset(repo, self.ctxs, sa, sb, self.copies)[:2]
 
-        def get_status(file, mod, add, rem):
-            # type: (bytes, Set[bytes], Set[bytes], Set[bytes]) -> Text
+        def get_status(file: bytes,
+                       mod: Set[bytes],
+                       add: Set[bytes],
+                       rem: Set[bytes]) -> Text:
             if file in mod:
                 return 'M'
             if file in add:
@@ -593,8 +611,7 @@ class FileSelectionDialog(QDialog):
             self.list.addItem(row)
 
     @pyqtSlot(str)
-    def onToolSelected(self, tool):
-        # type: (Text) -> None
+    def onToolSelected(self, tool: Text) -> None:
         'user selected a tool from the tool combo'
         tool = hglib.fromunicode(tool)  # pytype: disable=annotation-type-mismatch
         assert tool in self.tools, tool
@@ -602,8 +619,7 @@ class FileSelectionDialog(QDialog):
         self.updateDiffButtons(tool)
 
     @pyqtSlot(int)
-    def updateToolSelection(self, row):
-        # type: (int) -> None
+    def updateToolSelection(self, row: int) -> None:
         'user selected a file, pick an appropriate tool from combo'
         if row == -1:
             return
@@ -628,20 +644,17 @@ class FileSelectionDialog(QDialog):
             if name == selected:
                 self.toolCombo.setCurrentIndex(i)
 
-    def activateCurrent(self):
-        # type: () -> None
+    def activateCurrent(self) -> None:
         'CTRL+D has been pressed'
         row = self.list.currentRow()
         if row >= 0:
             self.launch(self.list.item(row).text()[2:])
 
-    def itemActivated(self, item):
-        # type: (QListWidgetItem) -> None
+    def itemActivated(self, item: QListWidgetItem) -> None:
         'A QListWidgetItem has been activated'
         self.launch(item.text()[2:])
 
-    def updateDiffButtons(self, tool):
-        # type: (bytes) -> None
+    def updateDiffButtons(self, tool: bytes) -> None:
         # hg>=4.4: configbool() may return None as the default is set to None
         if hasattr(self, 'p1button'):
             d2 = self.repo.ui.configbool(b'merge-tools', tool + b'.dirdiff')
@@ -653,8 +666,7 @@ class FileSelectionDialog(QDialog):
             d2 = self.repo.ui.configbool(b'merge-tools', tool + b'.dirdiff')
             self.dbutton.setEnabled(bool(d2))
 
-    def launch(self, fname):
-        # type: (Text) -> None
+    def launch(self, fname: Text) -> None:
         fname = hglib.fromunicode(fname)  # pytype: disable=annotation-type-mismatch
         source = self.copies.get(fname, None)
         dir1a, dir1b, dir2 = self.dirs
@@ -662,8 +674,10 @@ class FileSelectionDialog(QDialog):
         ctx1a, ctx1b, ctx2 = self.ctxs
 
         # pytype: disable=redundant-function-type-comment
-        def getfile(ctx, dir, fname, source):
-            # type: (HgContext, bytes, bytes, Optional[bytes]) -> Tuple[bytes, bytes]
+        def getfile(ctx: HgContext,
+                    dir: bytes,
+                    fname: bytes,
+                    source: Optional[bytes]) -> Tuple[bytes, bytes]:
             m = ctx.manifest()
             if fname in m:
                 path = os.path.join(dir, util.localpath(fname))
@@ -710,8 +724,7 @@ class FileSelectionDialog(QDialog):
         args = ctx1b and self.mergeopts or self.diffopts
         launchtool(self.diffpath, args, replace, False)
 
-    def p1dirdiff(self):
-        # type: () -> None
+    def p1dirdiff(self) -> None:
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
@@ -731,8 +744,7 @@ class FileSelectionDialog(QDialog):
         }
         launchtool(self.diffpath, self.diffopts, replace, False)
 
-    def p2dirdiff(self):
-        # type: () -> None
+    def p2dirdiff(self) -> None:
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
@@ -752,8 +764,7 @@ class FileSelectionDialog(QDialog):
         }
         launchtool(self.diffpath, self.diffopts, replace, False)
 
-    def threewaydirdiff(self):
-        # type: () -> None
+    def threewaydirdiff(self) -> None:
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
