@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -61,8 +61,9 @@ _FILE_FILTER = ';;'.join([_('Config files (*.conf *.config *.ini)'),
 
 class WebconfForm(QWidget):
     """Widget to show/edit webconf"""
-    def __init__(self, parent=None, webconf=None):
-        # type: (Optional[QWidget], Optional[IniConfig]) -> None
+    def __init__(self,
+                 parent: Optional[QWidget] = None,
+                 webconf: Optional[IniConfig] = None) -> None:
         super(WebconfForm, self).__init__(parent, acceptDrops=True)
         self._qui = Ui_WebconfForm()
         self._qui.setupUi(self)
@@ -74,8 +75,7 @@ class WebconfForm(QWidget):
         self.setwebconf(webconf or wconfig.config())
         self._updateform()
 
-    def _initicons(self):
-        # type: () -> None
+    def _initicons(self) -> None:
         def setstdicon(w, name):
             w.setIcon(self.style().standardIcon(name))
 
@@ -103,8 +103,7 @@ class WebconfForm(QWidget):
         if m.hasFormat('text/uri-list') and len(m.urls()) == 1:
             return m.urls()[0].toLocalFile()
 
-    def setwebconf(self, webconf):
-        # type: (IniConfig) -> None
+    def setwebconf(self, webconf: IniConfig) -> None:
         """set current webconf object"""
         path = hglib.tounicode(getattr(webconf, 'path', None) or '')
         i = self._qui.path_edit.findText(path)
@@ -114,8 +113,7 @@ class WebconfForm(QWidget):
         self._qui.path_edit.setCurrentIndex(i)
 
     @property
-    def webconf(self):
-        # type: () -> IniConfig
+    def webconf(self) -> IniConfig:
         """current webconf object"""
         def curconf(w):
             i = w.currentIndex()
@@ -125,23 +123,20 @@ class WebconfForm(QWidget):
         return curconf(self._qui.path_edit)
 
     @property
-    def _webconfmodel(self):
-        # type: () -> WebconfModel
+    def _webconfmodel(self) -> WebconfModel:
         """current model object of webconf"""
         m = self._qui.repos_view.model()
         assert isinstance(m, WebconfModel)
         return m
 
     @pyqtSlot()
-    def _updateview(self):
-        # type: () -> None
+    def _updateview(self) -> None:
         m = WebconfModel(config=self.webconf, parent=self)
         self._qui.repos_view.setModel(m)
         self._qui.repos_view.selectionModel().currentChanged.connect(
             self._updateform)
 
-    def _updateform(self):
-        # type: () -> None
+    def _updateform(self) -> None:
         """Update availability of each widget"""
         self._qui.repos_view.setEnabled(hasattr(self.webconf, 'write'))
         self._qui.add_button.setEnabled(hasattr(self.webconf, 'write'))
@@ -153,16 +148,14 @@ class WebconfForm(QWidget):
             and self._qui.repos_view.currentIndex().isValid())
 
     @pyqtSlot()
-    def on_open_button_clicked(self):
-        # type: () -> None
+    def on_open_button_clicked(self) -> None:
         path, _filter = QFileDialog.getOpenFileName(
             self, _('Open hgweb config'),
             getattr(self.webconf, 'path', None) or '', _FILE_FILTER)
         if path:
             self.openwebconf(path)
 
-    def openwebconf(self, path):
-        # type: (Text) -> None
+    def openwebconf(self, path: Text) -> None:
         """load the specified webconf file"""
         path = hglib.fromunicode(path)
         c = wconfig.readfile(path)
@@ -170,23 +163,22 @@ class WebconfForm(QWidget):
         self.setwebconf(c)
 
     @pyqtSlot()
-    def on_save_button_clicked(self):
-        # type: () -> None
+    def on_save_button_clicked(self) -> None:
         path, _filter = QFileDialog.getSaveFileName(
             self, _('Save hgweb config'),
             getattr(self.webconf, 'path', None) or '', _FILE_FILTER)
         if path:
             self.savewebconf(path)
 
-    def savewebconf(self, path):
-        # type: (Text) -> None
+    def savewebconf(self, path: Text) -> None:
         """save current webconf to the specified file"""
         wconfig.writefile(self.webconf, hglib.fromunicode(path))
         self.openwebconf(path)  # reopen in case file path changed
 
     @pyqtSlot()
-    def _addpathmap(self, path=None, localpath=None):
-        # type: (Optional[Text], Optional[Text]) -> None
+    def _addpathmap(self,
+                    path: Optional[Text] = None,
+                    localpath: Optional[Text] = None) -> None:
         path, localpath = _PathDialog.getaddpathmap(
             self, path=path, localpath=localpath,
             invalidpaths=self._webconfmodel.paths)
@@ -194,13 +186,11 @@ class WebconfForm(QWidget):
             self._webconfmodel.addpathmap(path, localpath)
 
     @pyqtSlot()
-    def on_edit_button_clicked(self):
-        # type: () -> None
+    def on_edit_button_clicked(self) -> None:
         self.on_repos_view_doubleClicked(self._qui.repos_view.currentIndex())
 
     @pyqtSlot(QModelIndex)
-    def on_repos_view_doubleClicked(self, index):
-        # type: (QModelIndex) -> None
+    def on_repos_view_doubleClicked(self, index: QModelIndex) -> None:
         assert index.isValid()
         origpath, origlocalpath = self._webconfmodel.getpathmapat(index.row())
         path, localpath = _PathDialog.geteditpathmap(
@@ -216,8 +206,7 @@ class WebconfForm(QWidget):
             self._webconfmodel.setpathmap(path, localpath)
 
     @pyqtSlot()
-    def on_remove_button_clicked(self):
-        # type: () -> None
+    def on_remove_button_clicked(self) -> None:
         index = self._qui.repos_view.currentIndex()
         assert index.isValid()
         path, _localpath = self._webconfmodel.getpathmapat(index.row())
@@ -225,9 +214,8 @@ class WebconfForm(QWidget):
 
 class _PathDialog(QDialog):
     """Dialog to add/edit path mapping"""
-    def __init__(self, title, acceptlabel, path=None, localpath=None,
-                 invalidpaths=None, parent=None):
-        # type: (Text, Text, Optional[Text], Optional[Text], Optional[Iterable[Text]], Optional[QWidget]) -> None
+    def __init__(self, title: Text, acceptlabel: Text, path: Optional[Text] = None, localpath: Optional[Text] = None,
+                 invalidpaths: Optional[Iterable[Text]] = None, parent: Optional[QWidget] = None) -> None:
         super(_PathDialog, self).__init__(parent)
         self.setWindowFlags((self.windowFlags() | Qt.WindowType.WindowMinimizeButtonHint)
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
@@ -241,8 +229,7 @@ class _PathDialog(QDialog):
         self._localpath_edit.setText(localpath or '')
         self._updateform()
 
-    def _initfields(self):
-        # type: () -> None
+    def _initfields(self) -> None:
         """initialize input fields"""
         def addfield(key, label, *extras):
             edit = QLineEdit(self)
@@ -263,8 +250,7 @@ class _PathDialog(QDialog):
         addfield('localpath', _('Local Path:'), self._localpath_browse_button)
         self._localpath_browse_button.clicked.connect(self._browse_localpath)
 
-    def _initbuttons(self, acceptlabel):
-        # type: (Text) -> None
+    def _initbuttons(self, acceptlabel: Text) -> None:
         """initialize dialog buttons"""
         self._buttons = QDialogButtonBox(self)
         self._accept_button = self._buttons.addButton(QDialogButtonBox.StandardButton.Ok)
@@ -275,20 +261,17 @@ class _PathDialog(QDialog):
         self.layout().addRow(self._buttons)
 
     @property
-    def path(self):
-        # type: () -> Text
+    def path(self) -> Text:
         """value of path field"""
         return self._path_edit.text()
 
     @property
-    def localpath(self):
-        # type: () -> Text
+    def localpath(self) -> Text:
         """value of localpath field"""
         return self._localpath_edit.text()
 
     @pyqtSlot()
-    def _browse_localpath(self):
-        # type: () -> None
+    def _browse_localpath(self) -> None:
         path = QFileDialog.getExistingDirectory(self, _('Select Repository'),
                                                 self.localpath)
         if not path:
@@ -302,19 +285,20 @@ class _PathDialog(QDialog):
             self._path_edit.setText(os.path.basename(path))
 
     @pyqtSlot()
-    def _updateform(self):
-        # type: () -> None
+    def _updateform(self) -> None:
         """update availability of form elements"""
         self._accept_button.setEnabled(self._isacceptable())
 
-    def _isacceptable(self):
-        # type: () -> bool
+    def _isacceptable(self) -> bool:
         return bool(self.path and self.localpath
                     and self.path not in self._invalidpaths)
 
     @classmethod
-    def getaddpathmap(cls, parent, path=None, localpath=None, invalidpaths=None):
-        # type: (Optional[QWidget], Optional[Text], Optional[Text], Optional[Iterable[Text]]) -> Tuple[Optional[Text], Optional[Text]]
+    def getaddpathmap(cls,
+                      parent: Optional[QWidget],
+                      path: Optional[Text] = None,
+                      localpath: Optional[Text] = None,
+                      invalidpaths: Optional[Iterable[Text]] = None) -> Tuple[Optional[Text], Optional[Text]]:
         d = cls(title=_('Add Path to Serve'), acceptlabel=_('Add'),
                 path=path, localpath=localpath,
                 invalidpaths=invalidpaths, parent=parent)
@@ -324,8 +308,11 @@ class _PathDialog(QDialog):
             return None, None
 
     @classmethod
-    def geteditpathmap(cls, parent, path=None, localpath=None, invalidpaths=None):
-        # type: (Optional[QWidget], Optional[Text], Optional[Text], Optional[Iterable[Text]]) -> Tuple[Optional[Text], Optional[Text]]
+    def geteditpathmap(cls,
+                       parent: Optional[QWidget],
+                       path: Optional[Text] = None,
+                       localpath: Optional[Text] = None,
+                       invalidpaths: Optional[Iterable[Text]] = None) -> Tuple[Optional[Text], Optional[Text]]:
         d = cls(title=_('Edit Path to Serve'), acceptlabel=_('Edit'),
                 path=path, localpath=localpath,
                 invalidpaths=invalidpaths, parent=parent)
@@ -339,13 +326,13 @@ class WebconfModel(QAbstractTableModel):
     _COLUMNS = [(_('Path'),),
                 (_('Local Path'),)]
 
-    def __init__(self, config, parent=None):
-        # type: (IniConfig, Optional[QObject]) -> None
+    def __init__(self,
+                 config: IniConfig,
+                 parent: Optional[QObject] = None) -> None:
         super(WebconfModel, self).__init__(parent)
         self._config = config
 
-    def data(self, index, role):
-        # type: (QModelIndex, int) -> Any
+    def data(self, index: QModelIndex, role: int) -> Any:
         if not index.isValid():
             return None
         if role == Qt.ItemDataRole.DisplayRole:
@@ -353,39 +340,33 @@ class WebconfModel(QAbstractTableModel):
             return hglib.tounicode(v)
         return None
 
-    def rowCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def rowCount(self, parent: QModelIndex = QModelIndex()) -> int:
         if parent.isValid():
             return 0  # no child
         return len(self._config[b'paths'])
 
-    def columnCount(self, parent=QModelIndex()):
-        # type: (QModelIndex) -> int
+    def columnCount(self, parent: QModelIndex = QModelIndex()) -> int:
         if parent.isValid():
             return 0  # no child
         return len(self._COLUMNS)
 
-    def headerData(self, section, orientation, role):
-        # type: (int, int, int) -> Any
+    def headerData(self, section: int, orientation: int, role: int) -> Any:
         if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         return self._COLUMNS[section][0]
 
     @property
-    def paths(self):
-        # type: () -> List[Text]
+    def paths(self) -> List[Text]:
         """return list of known paths"""
         return [hglib.tounicode(e) for e in self._config[b'paths']]
 
-    def getpathmapat(self, row):
-        # type: (int) -> Tuple[Text, ...]
+    def getpathmapat(self, row: int) -> Tuple[Text, ...]:
         """return pair of (path, localpath) at the specified index"""
         assert 0 <= row and row < self.rowCount(), row
         return tuple(hglib.tounicode(e)
                      for e in self._config.items(b'paths')[row])
 
-    def addpathmap(self, path, localpath):
-        # type: (Text, Text) -> None
+    def addpathmap(self, path: Text, localpath: Text) -> None:
         """add path mapping to serve"""
         assert path not in self.paths, path
         self.beginInsertRows(QModelIndex(), self.rowCount(), self.rowCount())
@@ -395,8 +376,7 @@ class WebconfModel(QAbstractTableModel):
         finally:
             self.endInsertRows()
 
-    def setpathmap(self, path, localpath):
-        # type: (Text, Text) -> None
+    def setpathmap(self, path: Text, localpath: Text) -> None:
         """change path mapping at the specified index"""
         self._config.set(b'paths', hglib.fromunicode(path),
                          hglib.fromunicode(localpath))
@@ -404,8 +384,7 @@ class WebconfModel(QAbstractTableModel):
         self.dataChanged.emit(self.index(row, 0),
                               self.index(row, self.columnCount()))
 
-    def removepathmap(self, path):
-        # type: (Text) -> None
+    def removepathmap(self, path: Text) -> None:
         """remove path from mapping"""
         row = self._indexofpath(path)
         self.beginRemoveRows(QModelIndex(), row, row)
@@ -414,8 +393,7 @@ class WebconfModel(QAbstractTableModel):
         finally:
             self.endRemoveRows()
 
-    def _indexofpath(self, path):
-        # type: (Text) -> int
+    def _indexofpath(self, path: Text) -> int:
         path = hglib.fromunicode(path)
         assert path in self._config[b'paths'], path
         return list(self._config[b'paths']).index(path)
