@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 import os
 
 from mercurial import hg, error, pycompat, scmutil
@@ -25,8 +27,8 @@ if hglib.TYPE_CHECKING:
 debugging = False
 enabled = True
 localonly = False
-includepaths = []  # type: List[Text]
-excludepaths = []  # type: List[Text]
+includepaths: List[Text] = []
+excludepaths: List[Text] = []
 
 try:
     from mercurial.windows import winreg
@@ -77,14 +79,13 @@ ROOT = "r"
 UNRESOLVED = 'U'
 
 # file status cache
-overlay_cache = {}  # type: Dict[Optional[Text], Optional[Text]]
+overlay_cache: Dict[Optional[Text], Optional[Text]] = {}
 cache_tick_count = 0
-cache_root = None  # type: Optional[Text]
-cache_pdir = None  # type: Optional[Text]
+cache_root: Optional[Text] = None
+cache_pdir: Optional[Text] = None
 
 
-def add_dirs(list):
-    # type: (List[bytes]) -> None
+def add_dirs(list: List[bytes]) -> None:
     dirs = set()
     if list:
         dirs.add(b'')
@@ -98,8 +99,8 @@ def add_dirs(list):
     list.extend(dirs)
 
 
-def get_state(upath, repo=None):
-    # type: (Text, Optional[localrepo.localrepository]) -> Text
+def get_state(upath: Text,
+              repo: Optional[localrepo.localrepository] = None) -> Text:
     """
     Get the state of a given path in source control.
     """
@@ -107,8 +108,8 @@ def get_state(upath, repo=None):
     return states and states[0] or NOT_IN_REPO
 
 
-def get_states(path, repo=None):
-    # type: (Text, Optional[localrepo.localrepository]) -> Text
+def get_states(path: Text,
+               repo: Optional[localrepo.localrepository] = None) -> Text:
     """
     Get the states of a given path in source control.
     """
@@ -261,6 +262,5 @@ def get_states(path, repo=None):
     return status
 
 
-def add(path, state):
-    # type: (Text, Text) -> None
+def add(path: Text, state: Text) -> None:
     overlay_cache[path] = overlay_cache.get(path, '') + state
