@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os, sys
 from mercurial import (
     match,
@@ -19,8 +21,7 @@ if pycompat.TYPE_CHECKING:
     )
 
 
-def _getplatformexecutablekey():
-    # type: () -> bytes
+def _getplatformexecutablekey() -> bytes:
     if sys.platform == 'darwin':
         key = b'executable-osx'
     elif os.name == 'nt':
@@ -31,15 +32,16 @@ def _getplatformexecutablekey():
 
 _platformexecutablekey = _getplatformexecutablekey()
 
-def _toolstr(ui, tool, part, default=b""):
-    # type: (uimod.ui, bytes, bytes, Optional[bytes]) -> bytes
+def _toolstr(ui: uimod.ui,
+             tool: bytes,
+             part: bytes,
+             default: Optional[bytes] = b"") -> bytes:
     val = ui.config(b"editor-tools", tool + b"." + part, default)
     assert val is not None  # help pytype
     return val
 
 toolcache = {}
-def _findtool(ui, tool):
-    # type: (uimod.ui, bytes) -> Optional[bytes]
+def _findtool(ui: uimod.ui, tool: bytes) -> Optional[bytes]:
     global toolcache
     if tool in toolcache:
         return toolcache[tool]
@@ -68,8 +70,8 @@ def _findtool(ui, tool):
     toolcache[tool] = None
     return None
 
-def _findeditor(repo, files):
-    # type: (localrepo.localrepository, List[bytes]) -> Tuple[Optional[bytes], bytes]
+def _findeditor(repo: localrepo.localrepository,
+                files: List[bytes]) -> Tuple[Optional[bytes], bytes]:
     '''returns tuple of editor name and editor path.
 
     tools matched by pattern are returned as (name, toolpath)
@@ -120,8 +122,8 @@ def _findeditor(repo, files):
     editor = ui.geteditor()
     return None, editor
 
-def detecteditor(repo, files):
-    # type: (localrepo.localrepository, List[bytes]) -> Tuple[bytes, Optional[bytes], Optional[bytes], Optional[bytes]]
+def detecteditor(repo: localrepo.localrepository,
+                 files: List[bytes]) -> Tuple[bytes, Optional[bytes], Optional[bytes], Optional[bytes]]:
     'returns tuple of editor tool path and arguments'
     name, pathorconfig = _findeditor(repo, files)
     if name is None:
@@ -132,8 +134,7 @@ def detecteditor(repo, files):
         argssearch = _toolstr(repo.ui, name, b"argssearch")
         return pathorconfig, args, argsln, argssearch
 
-def findeditors(ui):
-    # type: (uimod.ui) -> List[bytes]
+def findeditors(ui: uimod.ui) -> List[bytes]:
     seen = set()
     for key, value in ui.configitems(b'editor-tools'):
         t = key.split(b'.')[0]
