@@ -4,6 +4,9 @@
 #
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
+
+from __future__ import annotations
+
 import os
 
 from . import hglib
@@ -20,8 +23,7 @@ if hglib.TYPE_CHECKING:
 if os.name == 'nt':
     from mercurial.windows import winreg
 
-    def findgpg(ui):
-        # type: (uimod.ui) -> List[Text]
+    def findgpg(ui: uimod.ui) -> List[Text]:
         path = []
         for key in (r"Software\GNU\GnuPG", r"Software\Wow6432Node\GNU\GnuPG"):
             try:
@@ -40,6 +42,5 @@ if os.name == 'nt':
         return path
 
 else:
-    def findgpg(ui):
-        # type: (uimod.ui) -> List[Text]
+    def findgpg(ui: uimod.ui) -> List[Text]:
         return []
