@@ -5,6 +5,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 import re
 from typing import (
     List,
@@ -25,7 +27,7 @@ try:
 except ImportError:
     pass
 
-testedwith = b'5.9 6.0 6.1 6.2 6.3 6.4 6.5 6.6'
+testedwith = b'6.3 6.4 6.5 6.6 6.7 6.8'
 
 def _splitversion(v: bytes) -> Optional[List[bytes]]:
     """Extract (major, minor) version components as bytes, or None"""
