@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -30,8 +30,7 @@ if hglib.TYPE_CHECKING:
     MenuT = List[Union["TortoiseMenu", "TortoiseMenuSep"]]
 
 
-def _(msgid):
-    # type: (Text) -> Dict[Text, Text]
+def _(msgid: Text) -> Dict[Text, Text]:
     return {'id': msgid, 'str': gettext(msgid)}
 
 thgcmenu = {
@@ -115,8 +114,12 @@ _ALWAYS_DEMOTE_ = ('about', 'userconf', 'repoconf')
 
 class TortoiseMenu(object):
 
-    def __init__(self, menutext, helptext, hgcmd, icon=None, state=True):
-        # type: (Text, Text, Optional[Text], Optional[Text], bool) -> None
+    def __init__(self,
+                 menutext: Text,
+                 helptext: Text,
+                 hgcmd: Optional[Text],
+                 icon: Optional[Text] = None,
+                 state: bool = True) -> None:
         self.menutext = menutext
         self.helptext = helptext
         self.hgcmd = hgcmd
@@ -132,15 +135,22 @@ class TortoiseMenu(object):
 
 class TortoiseSubmenu(TortoiseMenu):
 
-    def __init__(self, menutext, helptext, menus=None, icon=None):
-        # type: (Text, Text, Optional[MenuT], Optional[Text]) -> None
+    def __init__(self,
+                 menutext: Text,
+                 helptext: Text,
+                 menus: Optional[MenuT] = None,
+                 icon: Optional[Text] = None) -> None:
         TortoiseMenu.__init__(self, menutext, helptext, None, icon)
         if menus is None:
-            menus = []  # type: MenuT
+            menus: MenuT = []
         self.menus = menus[:]
 
-    def add_menu(self, menutext, helptext, hgcmd, icon=None, state=True):
-        # type: (Text, Text, Optional[Text], Optional[Text], bool) -> None
+    def add_menu(self,
+                 menutext: Text,
+                 helptext: Text,
+                 hgcmd: Optional[Text],
+                 icon: Optional[Text] = None,
+                 state: bool = True) -> None:
         self.menus.append(TortoiseMenu(menutext, helptext,
                 hgcmd, icon, state))
 
@@ -170,16 +180,22 @@ class TortoiseMenuSep(object):
 
 class thg_menu(object):
 
-    def __init__(self, ui, promoted, name = "TortoiseHg"):
-        # type: (uimod.ui, List[Text], Text) -> None
-        self.menus = [[]]  # type: List[MenuT]
+    menus: List[MenuT]
+
+    def __init__(self,
+                 ui: uimod.ui,
+                 promoted: List[Text],
+                 name: Text = "TortoiseHg") -> None:
+        self.menus = [[]]
         self.ui = ui
         self.name = name
         self.sep = [False]
         self.promoted = promoted
 
-    def add_menu(self, hgcmd, icon=None, state=True):
-        # type: (Text, Optional[Text], bool) -> None
+    def add_menu(self,
+                 hgcmd: Text,
+                 icon: Optional[Text] = None,
+                 state: bool = True) -> None:
         if hgcmd in self.promoted:
             pos = 0
         else:
@@ -199,8 +215,7 @@ class thg_menu(object):
     def add_sep(self):
         self.sep = [True for _s in self.sep]
 
-    def get(self):
-        # type: () -> MenuT
+    def get(self) -> MenuT:
         menu = self.menus[0][:]
         for submenu in self.menus[1:]:
             menu.append(TortoiseSubmenu(self.name, 'Mercurial', submenu, "hg.ico"))
@@ -211,8 +226,7 @@ class thg_menu(object):
         return iter(self.get())
 
 
-def open_repo(path):
-    # type: (Text) -> Optional[localrepo.localrepository]
+def open_repo(path: Text) -> Optional[localrepo.localrepository]:
     root = paths.find_root(path)
     if root:
         try:
@@ -230,8 +244,7 @@ def open_repo(path):
 class menuThg:
     """shell extension that adds context menu items"""
 
-    def __init__(self, internal=False):
-        # type: (bool) -> None
+    def __init__(self, internal: bool = False) -> None:
         self.name = "TortoiseHg"
         promoted = []
         pl = hglib.loadui().config(b'tortoisehg', b'promoteditems', b'commit,log')
@@ -249,8 +262,9 @@ class menuThg:
         self.promoted = promoted
 
 
-    def get_commands_dragdrop(self, srcfiles, destfolder):
-        # type: (List[Text], Text) -> Union[List[Text], thg_menu]
+    def get_commands_dragdrop(self,
+                              srcfiles: List[Text],
+                              destfolder: Text) -> Union[List[Text], thg_menu]:
         """
         Get a list of commands valid for the current selection.
 
@@ -281,8 +295,7 @@ class menuThg:
             menu.add_menu('dndsynch')
         return menu
 
-    def get_norepo_commands(self, cwd, files):
-        # type: (Text, List[Text]) -> thg_menu
+    def get_norepo_commands(self, cwd: Text, files: List[Text]) -> thg_menu:
         menu = thg_menu(hglib.loadui(), self.promoted, self.name)
         menu.add_menu('clone')
         menu.add_menu('init')
@@ -292,8 +305,10 @@ class menuThg:
         menu.add_sep()
         return menu
 
-    def get_commands(self, repo, cwd, files):
-        # type: (localrepo.localrepository, Text, List[Text]) -> thg_menu
+    def get_commands(self,
+                     repo: localrepo.localrepository,
+                     cwd: Text,
+                     files: List[Text]) -> thg_menu:
         """
         Get a list of commands valid for the current selection.
 
