@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import shlex
@@ -40,12 +40,10 @@ if pycompat.TYPE_CHECKING:
     )
 
     @overload
-    def _find_root(p, dn):
-        # type: (Text, Text) -> Optional[Text]
+    def _find_root(p: Text, dn: Text) -> Optional[Text]:
         pass
     @overload
-    def _find_root(p, dn):
-        # type: (bytes, bytes) -> Optional[bytes]
+    def _find_root(p: bytes, dn: bytes) -> Optional[bytes]:
         pass
 
 
@@ -59,16 +57,13 @@ def _find_root(p, dn):
             return None
     return p
 
-def find_root(path=None):
-    # type: (Optional[Text]) -> Optional[Text]
+def find_root(path: Optional[Text] = None) -> Optional[Text]:
     return _find_root(path or os.getcwd(), '.hg')
 
-def find_root_bytes(path=None):
-    # type: (Optional[bytes]) -> Optional[bytes]
+def find_root_bytes(path: Optional[bytes] = None) -> Optional[bytes]:
     return _find_root(path or encoding.getcwd(), b'.hg')
 
-def get_tortoise_icon(icon):
-    # type: (Text) -> Optional[Text]
+def get_tortoise_icon(icon: Text) -> Optional[Text]:
     "Find a tortoisehg icon"
     icopath = os.path.join(get_icon_path(), icon)
     if os.path.isfile(icopath):
@@ -77,27 +72,22 @@ def get_tortoise_icon(icon):
         print('icon not found', icon)
         return None
 
-def get_icon_path():
-    # type: () -> Text
+def get_icon_path() -> Text:
     global icon_path
     return icon_path or os.path.join(get_prog_root(), 'icons')
 
-def get_license_path():
-    # type: () -> Text
+def get_license_path() -> Text:
     global license_path
     return license_path or os.path.join(get_prog_root(), 'COPYING.txt')
 
-def get_locale_path():
-    # type: () -> Text
+def get_locale_path() -> Text:
     global locale_path
     return locale_path or os.path.join(get_prog_root(), 'locale')
 
-def _get_hg_path():
-    # type: () -> Text
+def _get_hg_path() -> Text:
     return os.path.abspath(os.path.join(mercurial.__file__, '..', '..'))
 
-def get_hg_command():
-    # type: () -> List[Text]
+def get_hg_command() -> List[Text]:
     """List of command to execute hg (equivalent to mercurial.util.hgcmd)"""
     global _hg_command
     if _hg_command is None:
@@ -114,8 +104,7 @@ def get_hg_command():
 if os.name == 'nt':
     import win32file  # pytype: disable=import-error
 
-    def find_in_path(pgmname):
-        # type: (Text) -> Optional[Text]
+    def find_in_path(pgmname: Text) -> Optional[Text]:
         "return first executable found in search path"
         global bin_path
         ospath = os.environ['PATH'].split(os.pathsep)
@@ -129,8 +118,7 @@ if os.name == 'nt':
                     return ppath + ext
         return None
 
-    def _find_hg_command():
-        # type: () -> List[Text]
+    def _find_hg_command() -> List[Text]:
         if hasattr(sys, 'frozen'):
             progdir = get_prog_root()
             exe = os.path.join(progdir, 'hg.exe')
@@ -155,25 +143,21 @@ if os.name == 'nt':
             return [python, exe[:-4]]
         return [exe]
 
-    def get_prog_root():
-        # type: () -> Text
+    def get_prog_root() -> Text:
         if getattr(sys, 'frozen', False):
             return os.path.dirname(sys.executable)
         return os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
 
-    def get_thg_command():
-        # type: () -> List[Text]
+    def get_thg_command() -> List[Text]:
         if getattr(sys, 'frozen', False):
             return [sys.executable]
         return [sys.executable] + sys.argv[:1]
 
-    def is_unc_path(path):
-        # type: (bytes) -> bool
+    def is_unc_path(path: bytes) -> bool:
         unc, rest = os.path.splitdrive(path)
         return len(unc) > 2
 
-    def is_on_fixed_drive(path):
-        # type: (bytes) -> bool
+    def is_on_fixed_drive(path: bytes) -> bool:
         if is_unc_path(path):
             # All UNC paths (\\host\mount) are considered not-fixed
             return False
@@ -186,8 +170,7 @@ if os.name == 'nt':
 
 else: # Not Windows
 
-    def find_in_path(pgmname):
-        # type: (Text) -> Optional[Text]
+    def find_in_path(pgmname: Text) -> Optional[Text]:
         """ return first executable found in search path """
         global bin_path
         ospath = os.environ['PATH'].split(os.pathsep)
@@ -198,8 +181,7 @@ else: # Not Windows
                 return ppath
         return None
 
-    def _find_hg_command():
-        # type: () -> List[Text]
+    def _find_hg_command() -> List[Text]:
         # look for in-place build, i.e. "make local"
         exe = os.path.join(_get_hg_path(), 'hg')
         if os.path.exists(exe):
@@ -210,20 +192,16 @@ else: # Not Windows
             return ['hg']
         return [exe]
 
-    def get_prog_root():
-        # type: () -> Text
+    def get_prog_root() -> Text:
         path = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
         return path
 
-    def get_thg_command():
-        # type: () -> List[Text]
+    def get_thg_command() -> List[Text]:
         return sys.argv[:1]
 
-    def is_unc_path(path):
-        # type: (bytes) -> bool
+    def is_unc_path(path: bytes) -> bool:
         return False
 
-    def is_on_fixed_drive(path):
-        # type: (bytes) -> bool
+    def is_on_fixed_drive(path: bytes) -> bool:
         return True
 
