@@ -6,6 +6,8 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
+from __future__ import annotations
+
 import os
 import time
 
@@ -29,8 +31,7 @@ if pycompat.TYPE_CHECKING:
     )
 
 if os.name == 'nt':
-    def shell_notify(paths, noassoc=False):
-        # type: (List[bytes], bool) -> None
+    def shell_notify(paths: List[bytes], noassoc: bool = False) -> None:
         try:
             from win32com.shell import (  # pytype: disable=import-error
                 shell, shellcon
@@ -98,9 +99,8 @@ if os.name == 'nt':
         with lfutil.lfstatus(repo):
             repostate = repo.status() # will update dirstate as a side effect
 
-        dirstatus = {}  # type: Dict[bytes, bytes]
-        def dirname(f):
-            # type: (bytes) -> bytes
+        dirstatus: Dict[bytes, bytes] = {}
+        def dirname(f: bytes) -> bytes:
             return b'/'.join(f.split(b'/')[:-1])
         for fn in repostate.added:
             dirstatus[dirname(fn)] = b'a'
@@ -115,7 +115,7 @@ if os.name == 'nt':
             with repo.vfs(b'thgstatus', b'rb') as f:
                 for dn in sorted(dirstatus):
                     s = dirstatus[dn]
-                    e = f.readline()  # type: bytes
+                    e: bytes = f.readline()
                     if e.startswith(b'@@noicons'):
                         break
                     if e == b'' or e[0:1] != s or e[1:-1] != dn:
@@ -136,8 +136,7 @@ if os.name == 'nt':
         return update
 
 else:
-    def shell_notify(paths, noassoc=False):
-        # type: (List[bytes], bool) -> None
+    def shell_notify(paths: List[bytes], noassoc: bool = False) -> None:
         if not paths:
             return
         notify = os.environ.get('THG_NOTIFY', '.tortoisehg/notify')
