@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os, sys
 from mercurial import util
 from mercurial.utils import procutil
@@ -14,8 +16,7 @@ if hglib.TYPE_CHECKING:
     )
 
 
-def defaultshell():
-    # type: () -> Optional[bytes]
+def defaultshell() -> Optional[bytes]:
     if sys.platform == 'darwin':
         shell = None # Terminal.App does not support open-to-folder
     elif os.name == 'nt':
@@ -26,8 +27,7 @@ def defaultshell():
 
 _defaultshell = defaultshell()
 
-def _getplatformexecutablekey():
-    # type: () -> bytes
+def _getplatformexecutablekey() -> bytes:
     if sys.platform == 'darwin':
         key = b'executable-osx'
     elif os.name == 'nt':
@@ -38,15 +38,16 @@ def _getplatformexecutablekey():
 
 _platformexecutablekey = _getplatformexecutablekey()
 
-def _toolstr(ui, tool, part, default=b""):
-    # type: (uimod.ui, bytes, bytes, bytes) -> bytes
+def _toolstr(ui: uimod.ui,
+             tool: bytes,
+             part: bytes,
+             default: bytes = b"") -> bytes:
     val = ui.config(b"terminal-tools", tool + b"." + part, default)
     assert val is not None  # help pytype
     return val
 
 toolcache = {}
-def _findtool(ui, tool):
-    # type: (uimod.ui, bytes) -> Optional[bytes]
+def _findtool(ui: uimod.ui, tool: bytes) -> Optional[bytes]:
     global toolcache
     if tool in toolcache:
         return toolcache[tool]
@@ -75,8 +76,7 @@ def _findtool(ui, tool):
     toolcache[tool] = None
     return None
 
-def _findterminal(ui):
-    # type: (uimod.ui) -> Tuple[Optional[bytes], Optional[bytes]]
+def _findterminal(ui: uimod.ui) -> Tuple[Optional[bytes], Optional[bytes]]:
     '''returns tuple of terminal name and terminal path.
 
     tools matched by pattern are returned as (name, toolpath)
@@ -117,8 +117,7 @@ def _findterminal(ui):
     global _defaultshell
     return None, _defaultshell
 
-def detectterminal(ui_):
-    # type: (uimod.ui) -> Tuple[Optional[bytes], Optional[bytes]]
+def detectterminal(ui_: uimod.ui) -> Tuple[Optional[bytes], Optional[bytes]]:
     'returns tuple of terminal tool path and arguments'
     if ui_ is None:
         ui_ = hglib.loadui()
@@ -129,8 +128,7 @@ def detectterminal(ui_):
         args = _toolstr(ui_, name, b"args")
         return pathorconfig, args
 
-def findterminals(ui):
-    # type: (uimod.ui) -> List[bytes]
+def findterminals(ui: uimod.ui) -> List[bytes]:
     seen = set()
     for key, value in ui.configitems(b'terminal-tools'):
         t = key.split(b'.')[0]
