@@ -34,6 +34,8 @@ Caveats:
   effect.
 """
 
+from __future__ import annotations
+
 import atexit, ctypes, os, threading
 
 from mercurial import (
@@ -175,8 +177,7 @@ if os.name == 'nt':
 
 class messageserver(object):
 
-    def __init__(self, logfile):
-        # type: (Optional[BinaryIO]) -> None
+    def __init__(self, logfile: Optional[BinaryIO]) -> None:
         self._logfile = logfile
         self._thread = threading.Thread(target=self._mainloop)
         self._thread.setDaemon(True)  # skip global join before atexit
@@ -203,8 +204,7 @@ class messageserver(object):
             _PostMessage(hwnd, _WM_STOPMESSAGELOOP, 0, 0)
             self._thread.join()
 
-    def _log(self, msg):
-        # type: (bytes) -> None
+    def _log(self, msg: bytes) -> None:
         if not self._logfile:
             return
         self._logfile.write(msg + b'\n')
@@ -251,16 +251,14 @@ class messageserver(object):
             return 0
         return _DefWindowProc(hwnd, msg, wparam, lparam)
 
-def _openlogfile(ui):
-    # type: (uimod.ui) -> Optional[BinaryIO]
+def _openlogfile(ui: uimod.ui) -> Optional[BinaryIO]:
     log = ui.config(b'win32ill', b'log')
     if log == b'-':
         return ui.ferr
     elif log:
         return open(log, 'ab')
 
-def uisetup(ui):
-    # type: (uimod.ui) -> None
+def uisetup(ui: uimod.ui) -> None:
     if os.name != 'nt':
         ui.warn(_('win32ill: unsupported platform: %s\n') % os.name)
         return
